Soil - Wikipedia

# Soil

From Wikipedia, the free encyclopedia
Jump to navigation Jump to search
mixture of organic matter, minerals, gases, liquids, and organisms that together support life

| Look up soil in Wiktionary, the free dictionary.

A, B, and C represent the soil profile, a notation firstly coined by Vasily Dokuchaev (1846–1903), the father of pedology; A is the topsoil; B is a regolith; C is a saprolite (a less-weathered regolith); the bottom-most layer represents the bedrock.
Surface-water-gley developed in glacial till, Northern Ireland.

Soil is a mixture of organic matter, minerals, gases, liquids, and organisms that together support life. Earth's body of soil, called the pedosphere, has four important functions:

- as a medium for plant growth
- as a means of water storage, supply and purification
- as a modifier of Earth's atmosphere
- as a habitat for organisms

All of these functions, in their turn, modify the soil.

The pedosphere interfaces with the lithosphere, the hydrosphere, the atmosphere, and the biosphere.[1] The term pedolith, used commonly to refer to the soil, translates to ground stone in the sense "fundamental stone".[2] Soil consists of a solid phase of minerals and organic matter (the soil matrix), as well as a porous phase that holds gases (the soil atmosphere) and water (the soil solution).[3][4][5] Accordingly, soil scientists can envisage soils as a three-state system of solids, liquids, and gases.[6]

Soil is a product of several factors: the influence of climate, relief (elevation, orientation, and slope of terrain), organisms, and the soil's parent materials (original minerals) interacting over time.[7] It continually undergoes development by way of numerous physical, chemical and biological processes, which include weathering with associated erosion. Given its complexity and strong internal connectedness, soil ecologists regard soil as an ecosystem.[8]

Most soils have a dry bulk density (density of soil taking into account voids when dry) between 1.1 and 1.6 g/cm3, while the soil particle density is much higher, in the range of 2.6 to 2.7 g/cm3.[9] Little of the soil of planet Earth is older than the Pleistocene and none is older than the Cenozoic,[10] although fossilized soils are preserved from as far back as the Archean.[11]

Soil science has two basic branches of study: edaphology and pedology. Edaphology studies the influence of soils on living things.[12] Pedology focuses on the formation, description (morphology), and classification of soils in their natural environment.[13] In engineering terms, soil is included in the broader concept of regolith, which also includes other loose material that lies above the bedrock, as can be found on the Moon and on other celestial objects as well.[14] Soil is also commonly referred to as earth or dirt; some scientific definitions distinguish dirt from soil by restricting the former term specifically to displaced soil.[15]

## Overview[edit]

Soil profile: Darkened topsoil and reddish subsoil layers are typical in some regions.

### Functions[edit]

Soil is a major component of the Earth's ecosystem. The world's ecosystems are impacted in far-reaching ways by the processes carried out in the soil, from ozone depletion and global warming to rainforest destruction and water pollution. With respect to Earth's carbon cycle, soil is an important carbon reservoir, and it is potentially one of the most reactive to human disturbance[16] and climate change.[17] As the planet warms, it has been predicted that soils will add carbon dioxide to the atmosphere due to increased biological activity at higher temperatures, a positive feedback (amplification).[18] This prediction has, however, been questioned on consideration of more recent knowledge on soil carbon turnover.[19]

Soil acts as an engineering medium, a habitat for soil organisms, a recycling system for nutrients and organic wastes, a regulator of water quality, a modifier of atmospheric composition, and a medium for plant growth, making it a critically important provider of ecosystem services.[20] Since soil has a tremendous range of available niches and habitats, it contains most of the Earth's genetic diversity. A gram of soil can contain billions of organisms, belonging to thousands of species, mostly microbial and largely still unexplored.[21][22] Soil has a mean prokaryotic density of roughly 108 organisms per gram,[23] whereas the ocean has no more than 107 prokaryotic organisms per milliliter (gram) of seawater.[24] Organic carbon held in soil is eventually returned to the atmosphere through the process of respiration carried out by heterotrophic organisms, but a substantial part is retained in the soil in the form of soil organic matter; tillage usually increases the rate of soil respiration, leading to the depletion of soil organic matter.[25] Since plant roots need oxygen, ventilation is an important characteristic of soil. This ventilation can be accomplished via networks of interconnected soil pores, which also absorb and hold rainwater making it readily available for uptake by plants. Since plants require a nearly continuous supply of water, but most regions receive sporadic rainfall, the water-holding capacity of soils is vital for plant survival.[26]

Soils can effectively remove impurities,[27] kill disease agents,[28] and degrade contaminants, this latter property being called natural attenuation.[29] Typically, soils maintain a net absorption of oxygen and methane and undergo a net release of carbon dioxide and nitrous oxide.[30] Soils offer plants physical support, air, water, temperature moderation, nutrients, and protection from toxins.[31] Soils provide readily available nutrients to plants and animals by converting dead organic matter into various nutrient forms.[32]

### Description[edit]

Components of a loam soil by percent volume

Water (25%)
Gases (25%)
Sand (18%)
Silt (18%)
Clay (9%)
Organic matter (5%)

A typical soil is about 50% solids (45% mineral and 5% organic matter), and 50% voids (or pores) of which half is occupied by water and half by gas.[33] The percent soil mineral and organic content can be treated as a constant (in the short term), while the percent soil water and gas content is considered highly variable whereby a rise in one is simultaneously balanced by a reduction in the other.[34] The pore space allows for the infiltration and movement of air and water, both of which are critical for life existing in soil.[35] Compaction, a common problem with soils, reduces this space, preventing air and water from reaching plant roots and soil organisms.[36]

Given sufficient time, an undifferentiated soil will evolve a soil profile which consists of two or more layers, referred to as soil horizons, that differ in one or more properties such as in their texture, structure, density, porosity, consistency, temperature, color, and reactivity.[10] The horizons differ greatly in thickness and generally lack sharp boundaries; their development is dependent on the type of parent material, the processes that modify those parent materials, and the soil-forming factors that influence those processes. The biological influences on soil properties are strongest near the surface, while the geochemical influences on soil properties increase with depth. Mature soil profiles typically include three basic master horizons: A, B, and C. The solum normally includes the A and B horizons. The living component of the soil is largely confined to the solum, and is generally more prominent in the A horizon.[37]

The soil texture is determined by the relative proportions of the individual particles of sand, silt, and clay that make up the soil. The interaction of the individual mineral particles with organic matter, water, gases via biotic and abiotic processes causes those particles to flocculate (stick together) to form aggregates or peds.[38] Where these aggregates can be identified, a soil can be said to be developed, and can be described further in terms of color, porosity, consistency, reaction (acidity), etc.

Water is a critical agent in soil development due to its involvement in the dissolution, precipitation, erosion, transport, and deposition of the materials of which a soil is composed.[39] The mixture of water and dissolved or suspended materials that occupy the soil pore space is called the soil solution. Since soil water is never pure water, but contains hundreds of dissolved organic and mineral substances, it may be more accurately called the soil solution. Water is central to the dissolution, precipitation and leaching of minerals from the soil profile. Finally, water affects the type of vegetation that grows in a soil, which in turn affects the development of the soil, a complex feedback which is exemplified in the dynamics of banded vegetation patterns in semi-arid regions.[40]

Soils supply plants with nutrients, most of which are held in place by particles of clay and organic matter (colloids)[41] The nutrients may be adsorbed on clay mineral surfaces, bound within clay minerals (absorbed), or bound within organic compounds as part of the living organisms or dead soil organic matter. These bound nutrients interact with soil water to buffer the soil solution composition (attenuate changes in the soil solution) as soils wet up or dry out, as plants take up nutrients, as salts are leached, or as acids or alkalis are added.[42][43]

Plant nutrient availability is affected by soil pH, which is a measure of the hydrogen ion activity in the soil solution. Soil pH is a function of many soil forming factors, and is generally lower (more acid) where weathering is more advanced.[44]

Most plant nutrients, with the exception of nitrogen, originate from the minerals that make up the soil parent material. Some nitrogen originates from rain as dilute nitric acid and ammonia,[45] but most of the nitrogen is available in soils as a result of nitrogen fixation by bacteria. Once in the soil-plant system, most nutrients are recycled through living organisms, plant and microbial residues (soil organic matter), mineral-bound forms, and the soil solution. Both living microorganisms and soil organic matter are of critical importance to this recycling, and thereby to soil formation and soil fertility.[46] Microbial activity in soils may release nutrients from minerals or organic matter for use by plants and other microorganisms, sequester (incorporate) them into living cells, or cause their loss from the soil by volatilisation (loss to the atmosphere as gases) or leaching.

## History of studies[edit]

### Fertility[edit]

The history of the study of soil is intimately tied to humans' urgent need to provide food for themselves and forage for their animals. Throughout history, civilizations have prospered or declined as a function of the availability and productivity of their soils.[47]

The Greek historian Xenophon (450–355 BCE) is credited with being the first to expound upon the merits of green-manuring crops: "But then whatever weeds are upon the ground, being turned into earth, enrich the soil as much as dung."[48]

Columella's "Husbandry," circa 60 CE, advocated the use of lime and that clover and alfalfa (green manure) should be turned under, and was used by 15 generations (450 years) under the Roman Empire until its collapse.[48][49] From the fall of Rome to the French Revolution, knowledge of soil and agriculture was passed on from parent to child and as a result, crop yields were low. During the European Middle Ages, Yahya Ibn al-'Awwam's handbook,[50] with its emphasis on irrigation, guided the people of North Africa, Spain and the Middle East; a translation of this work was finally carried to the southwest of the United States when under Spanish influence.[51] Olivier de Serres, considered as the father of French agronomy, was the first to suggest the abandonment of fallowing and its replacement by hay meadows within crop rotations, and he highlighted the importance of soil (the French terroir) in the management of vineyards. His famous book Le Théâtre d'Agriculture et mesnage des champs[52] contributed to the rise of modern, sustainable agriculture and to the collapse of old agricultural practices such as soil improvement (amendment) for crops by the lifting of forest litter and assarting, which ruined the soils of western Europe during Middle Ages and even later on according to regions.[53]

Experiments into what made plants grow first led to the idea that the ash left behind when plant matter was burned was the essential element but overlooked the role of nitrogen, which is not left on the ground after combustion, a belief which prevailed until the 19th century.[54] In about 1635, the Flemish chemist Jan Baptist van Helmont thought he had proved water to be the essential element from his famous five years' experiment with a willow tree grown with only the addition of rainwater. His conclusion came from the fact that the increase in the plant's weight had apparently been produced only by the addition of water, with no reduction in the soil's weight.[55][56] John Woodward (d. 1728) experimented with various types of water ranging from clean to muddy and found muddy water the best, and so he concluded that earthy matter was the essential element. Others concluded it was humus in the soil that passed some essence to the growing plant. Still others held that the vital growth principal was something passed from dead plants or animals to the new plants. At the start of the 18th century, Jethro Tull demonstrated that it was beneficial to cultivate (stir) the soil, but his opinion that the stirring made the fine parts of soil available for plant absorption was erroneous.[55][57]

As chemistry developed, it was applied to the investigation of soil fertility. The French chemist Antoine Lavoisier showed in about 1778 that plants and animals must [combust] oxygen internally to live and was able to deduce that most of the 165-pound weight of van Helmont's willow tree derived from air.[58] It was the French agriculturalist Jean-Baptiste Boussingault who by means of experimentation obtained evidence showing that the main sources of carbon, hydrogen and oxygen for plants were air and water, while nitrogen was taken from soil.[59] Justus von Liebig in his book Organic chemistry in its applications to agriculture and physiology (published 1840), asserted that the chemicals in plants must have come from the soil and air and that to maintain soil fertility, the used minerals must be replaced.[60] Liebig nevertheless believed the nitrogen was supplied from the air. The enrichment of soil with guano by the Incas was rediscovered in 1802, by Alexander von Humboldt. This led to its mining and that of Chilean nitrate and to its application to soil in the United States and Europe after 1840.[61]

The work of Liebig was a revolution for agriculture, and so other investigators started experimentation based on it. In England John Bennet Lawes and Joseph Henry Gilbert worked in the Rothamsted Experimental Station, founded by the former, and (re)discovered that plants took nitrogen from the soil, and that salts needed to be in an available state to be absorbed by plants. Their investigations also produced the "superphosphate", consisting in the acid treatment of phosphate rock.[62] This led to the invention and use of salts of potassium (K) and nitrogen (N) as fertilizers. Ammonia generated by the production of coke was recovered and used as fertiliser.[63] Finally, the chemical basis of nutrients delivered to the soil in manure was understood and in the mid-19th century chemical fertilisers were applied. However, the dynamic interaction of soil and its life forms still awaited discovery.

In 1856 J. Thomas Way discovered that ammonia contained in fertilisers was transformed into nitrates,[64] and twenty years later Robert Warington proved that this transformation was done by living organisms.[65] In 1890 Sergei Winogradsky announced he had found the bacteria responsible for this transformation.[66]

It was known that certain legumes could take up nitrogen from the air and fix it to the soil but it took the development of bacteriology towards the end of the 19th century to lead to an understanding of the role played in nitrogen fixation by bacteria. The symbiosis of bacteria and leguminous roots, and the fixation of nitrogen by the bacteria, were simultaneously discovered by the German agronomist Hermann Hellriegel and the Dutch microbiologist Martinus Beijerinck.[62]

Crop rotation, mechanisation, chemical and natural fertilisers led to a doubling of wheat yields in western Europe between 1800 and 1900.[67]

### Formation[edit]

The scientists who studied the soil in connection with agricultural practices had considered it mainly as a static substrate. However, soil is the result of evolution from more ancient geological materials, under the action of biotic and abiotic (not associated with life) processes. After studies of the improvement of the soil commenced, others began to study soil genesis and as a result also soil types and classifications.

In 1860, in Mississippi, Eugene W. Hilgard studied the relationship among rock material, climate, and vegetation, and the type of soils that were developed. He realised that the soils were dynamic, and considered soil types classification.[68] Unfortunately his work was not continued. At about the same time, Friedrich Albert Fallou was describing soil profiles and relating soil characteristics to their formation as part of his professional work evaluating forest and farm land for the principality of Saxony. His 1857 book, Anfangsgründe der Bodenkunde (First principles of soil science) established modern soil science.[69] Contemporary with Fallou's work, and driven by the same need to accurately assess land for equitable taxation, Vasily Dokuchaev led a team of soil scientists in Russia who conducted an extensive survey of soils, observing that similar basic rocks, climate and vegetation types lead to similar soil layering and types, and established the concepts for soil classifications. Due to language barriers, the work of this team was not communicated to western Europe until 1914 through a publication in German by Konstantin Dmitrievich Glinka, a member of the Russian team.[70]

Curtis F. Marbut was influenced by the work of the Russian team, translated Glinka's publication into English,[71] and as he was placed in charge of the U.S. National Cooperative Soil Survey, applied it to a national soil classification system.[55]

## Formation[edit]

Soil formation, or pedogenesis, is the combined effect of physical, chemical, biological and anthropogenic processes working on soil parent material. Soil is said to be formed when organic matter has accumulated and colloids are washed downward, leaving deposits of clay, humus, iron oxide, carbonate, and gypsum, producing a distinct layer called the B horizon. This is a somewhat arbitrary definition as mixtures of sand, silt, clay and humus will support biological and agricultural activity before that time. These constituents are moved from one level to another by water and animal activity. As a result, layers (horizons) form in the soil profile. The alteration and movement of materials within a soil causes the formation of distinctive soil horizons. However, more recent definitions of soil embrace soils without any organic matter, such as those regoliths that formed on Mars[72] and analogous conditions in planet Earth deserts.[73]

An example of the development of a soil would begin with the weathering of lava flow bedrock, which would produce the purely mineral-based parent material from which the soil texture forms. Soil development would proceed most rapidly from bare rock of recent flows in a warm climate, under heavy and frequent rainfall. Under such conditions, plants (in a first stage nitrogen-fixing lichens and cyanobacteria then epilithic higher plants) become established very quickly on basaltic lava, even though there is very little organic material. The plants are supported by the porous rock as it is filled with nutrient-bearing water that carries minerals dissolved from the rocks. Crevasses and pockets, local topography of the rocks, would hold fine materials and harbour plant roots. The developing plant roots are associated with mineral-weathering mycorrhizal fungi[74] that assist in breaking up the porous lava, and by these means organic matter and a finer mineral soil accumulate with time. Such initial stages of soil development have been described on volcanoes,[75] inselbergs,[76] and glacial moraines.[77]

### Factors[edit]

How soil formation proceeds is influenced by at least five classic factors that are intertwined in the evolution of a soil. They are: parent material, climate, topography (relief), organisms, and time.[78] When reordered to climate, relief, organisms, parent material, and time, they form the acronym CROPT.[79]

#### Parent material[edit]

The mineral material from which a soil forms is called parent material. Rock, whether its origin is igneous, sedimentary, or metamorphic, is the source of all soil mineral materials and the origin of all plant nutrients with the exceptions of nitrogen, hydrogen and carbon. As the parent material is chemically and physically weathered, transported, deposited and precipitated, it is transformed into a soil.

Typical soil parent mineral materials are:[80]

- Quartz: SiO2
- Calcite: CaCO3
- Feldspar: KAlSi3O8
- Mica (biotite): K(Mg,Fe)3AlSi3O10(OH)2

Soil, on an agricultural field in Germany, which has formed on loess parent material.

Parent materials are classified according to how they came to be deposited. Residual materials are mineral materials that have weathered in place from primary bedrock. Transported materials are those that have been deposited by water, wind, ice or gravity. Cumulose material is organic matter that has grown and accumulates in place.

Residual soils are soils that develop from their underlying parent rocks and have the same general chemistry as those rocks. The soils found on mesas, plateaux, and plains are residual soils. In the United States as little as three percent of the soils are residual.[81]

Most soils derive from transported materials that have been moved many miles by wind, water, ice and gravity.

- Aeolian processes (movement by wind) are capable of moving silt and fine sand many hundreds of miles, forming loess soils (60–90 percent silt),[82] common in the Midwest of North America, north-western Europe, Argentina and Central Asia. Clay is seldom moved by wind as it forms stable aggregates.
- Water-transported materials are classed as either alluvial, lacustrine, or marine. Alluvial materials are those moved and deposited by flowing water. Sedimentary deposits settled in lakes are called lacustrine. Lake Bonneville and many soils around the Great Lakes of the United States are examples. Marine deposits, such as soils along the Atlantic and Gulf Coasts and in the Imperial Valley of California of the United States, are the beds of ancient seas that have been revealed as the land uplifted.
- Ice moves parent material and makes deposits in the form of terminal and lateral moraines in the case of stationary glaciers. Retreating glaciers leave smoother ground moraines and in all cases, outwash plains are left as alluvial deposits are moved downstream from the glacier.
- Parent material moved by gravity is obvious at the base of steep slopes as talus cones and is called colluvial material.

Cumulose parent material is not moved but originates from deposited organic material. This includes peat and muck soils and results from preservation of plant residues by the low oxygen content of a high water table. While peat may form sterile soils, muck soils may be very fertile.

##### Weathering[edit]

The weathering of parent material takes the form of physical weathering (disintegration), chemical weathering (decomposition) and chemical transformation. Generally, minerals that are formed under high temperatures and pressures at great depths within the Earth's mantle are less resistant to weathering, while minerals formed at low temperature and pressure environment of the surface are more resistant to weathering.[citation needed] Weathering is usually confined to the top few meters of geologic material, because physical, chemical, and biological stresses and fluctuations generally decrease with depth.[83] Physical disintegration begins as rocks that have solidified deep in the Earth are exposed to lower pressure near the surface and swell and become mechanically unstable. Chemical decomposition is a function of mineral solubility, the rate of which doubles with each 10 °C rise in temperature, but is strongly dependent on water to effect chemical changes. Rocks that will decompose in a few years in tropical climates will remain unaltered for millennia in deserts.[7] Structural changes are the result of hydration, oxidation, and reduction. Chemical weathering mainly results from the excretion of organic acids and chelating compounds by bacteria[84] and fungi,[85] thought to increase under present-day greenhouse effect.[86]

- Physical disintegration is the first stage in the transformation of parent material into soil. Temperature fluctuations cause expansion and contraction of the rock, splitting it along lines of weakness. Water may then enter the cracks and freeze and cause the physical splitting of material along a path toward the center of the rock, while temperature gradients within the rock can cause exfoliation of "shells". Cycles of wetting and drying cause soil particles to be abraded to a finer size, as does the physical rubbing of material as it is moved by wind, water, and gravity. Water can deposit within rocks minerals that expand upon drying, thereby stressing the rock. Finally, organisms reduce parent material in size and create crevices and pores through the mechanical action of plant roots and the digging activity of animals.[87] Grinding of parent material by rock-eating animals also contributes to incipient soil formation.[88]
- Chemical decomposition and structural changes result when minerals are made soluble by water or are changed in structure. The first three of the following list are solubility changes and the last three are structural changes.[89]

1. The solution of salts in water results from the action of bipolar water molecules on ionic salt compounds producing a solution of ions and water, removing those minerals and reducing the rock's integrity, at a rate depending on water flow and pore channels.[90]
2. Hydrolysis is the transformation of minerals into polar molecules by the splitting of intervening water. This results in soluble acid-base pairs. For example, the hydrolysis of orthoclase-feldspar transforms it to acid silicate clay and basic potassium hydroxide, both of which are more soluble.[91]
3. In carbonation, the solution of carbon dioxide in water forms carbonic acid. Carbonic acid will transform calcite into more soluble calcium bicarbonate.[92]
4. Hydration is the inclusion of water in a mineral structure, causing it to swell and leaving it stressed and easily decomposed.[93]
5. Oxidation of a mineral compound is the inclusion of oxygen in a mineral, causing it to increase its oxidation number and swell due to the relatively large size of oxygen, leaving it stressed and more easily attacked by water (hydrolysis) or carbonic acid (carbonation).[94]
6. Reduction, the opposite of oxidation, means the removal of oxygen, hence the oxidation number of some part of the mineral is reduced, which occurs when oxygen is scarce. The reduction of minerals leaves them electrically unstable, more soluble and internally stressed and easily decomposed. It mainly occurs in waterlogged conditions.[95]

Of the above, hydrolysis and carbonation are the most effective, in particular in regions of high rainfall, temperature and physical erosion.[96] Chemical weathering becomes more effective as the surface area of the rock increases, thus is favoured by physical disintegration.[97] This stems in latitudinal and altitudinal climate gradients in regolith formation.[98][99]

Saprolite is a particular example of a residual soil formed from the transformation of granite, metamorphic and other types of bedrock into clay minerals. Often called [weathered granite], saprolite is the result of weathering processes that include: hydrolysis, chelation from organic compounds, hydration (the solution of minerals in water with resulting cation and anion pairs) and physical processes that include freezing and thawing. The mineralogical and chemical composition of the primary bedrock material, its physical features, including grain size and degree of consolidation, and the rate and type of weathering transforms the parent material into a different mineral. The texture, pH and mineral constituents of saprolite are inherited from its parent material. This process is also called arenization, resulting in the formation of sandy soils (granitic arenas), thanks to the much higher resistance of quartz compared to other mineral components of granite (micas, amphiboles, feldspars).[100]

#### Climate[edit]

The principal climatic variables influencing soil formation are effective precipitation (i.e., precipitation minus evapotranspiration) and temperature, both of which affect the rates of chemical, physical, and biological processes. Temperature and moisture both influence the organic matter content of soil through their effects on the balance between primary production and decomposition: the colder or drier the climate the lesser atmospheric carbon is fixed as organic matter while the lesser organic matter is decomposed.[101]

Climate is the dominant factor in soil formation, and soils show the distinctive characteristics of the climate zones in which they form, with a feedback to climate through transfer of carbon stocked in soil horizons back to the atmosphere.[17] If warm temperatures and abundant water are present in the profile at the same time, the processes of weathering, leaching, and plant growth will be maximized. According to the climatic determination of biomes, humid climates favor the growth of trees. In contrast, grasses are the dominant native vegetation in subhumid and semiarid regions, while shrubs and brush of various kinds dominate in arid areas.[102]

Water is essential for all the major chemical weathering reactions. To be effective in soil formation, water must penetrate the regolith. The seasonal rainfall distribution, evaporative losses, site topography, and soil permeability interact to determine how effectively precipitation can influence soil formation. The greater the depth of water penetration, the greater the depth of weathering of the soil and its development. Surplus water percolating through the soil profile transports soluble and suspended materials from the upper layers (eluviation) to the lower layers (illuviation), including clay particles[103] and dissolved organic matter.[104] It may also carry away soluble materials in the surface drainage waters. Thus, percolating water stimulates weathering reactions and helps differentiate soil horizons. Likewise, a deficiency of water is a major factor in determining the characteristics of soils of dry regions. Soluble salts are not leached from these soils, and in some cases they build up to levels that curtail plant[105] and microbial growth.[106] Soil profiles in arid and semi-arid regions are also apt to accumulate carbonates and certain types of expansive clays (calcrete or caliche horizons).[107][108] In tropical soils, when the soil has been deprived of vegetation (e.g. by deforestation) and thereby is submitted to intense evaporation, the upward capillary movement of water, which has dissolved iron and aluminum salts, is responsible for the formation of a superficial hard pan of laterite or bauxite, respectively, which is improper for cutivation, a known case of irreversible soil degradation (lateritization, bauxitization).[109]

The direct influences of climate include:[110]

- A shallow accumulation of lime in low rainfall areas as caliche
- Formation of acid soils in humid areas
- Erosion of soils on steep hillsides
- Deposition of eroded materials downstream
- Very intense chemical weathering, leaching, and erosion in warm and humid regions where soil does not freeze

Climate directly affects the rate of weathering and leaching. Wind moves sand and smaller particles (dust), especially in arid regions where there is little plant cover, depositing it close[111] or far from the entrainment source.[112] The type and amount of precipitation influence soil formation by affecting the movement of ions and particles through the soil, and aid in the development of different soil profiles. Soil profiles are more distinct in wet and cool climates, where organic materials may accumulate, than in wet and warm climates, where organic materials are rapidly consumed.[113] The effectiveness of water in weathering parent rock material depends on seasonal and daily temperature fluctuations, which favour tensile stresses in rock minerals, and thus their mechanical disaggregation, a process called thermal fatigue.[114] By the same process freeze-thaw cycles are an effective mechanism which breaks up rocks and other consolidated materials.[115]

Climate also indirectly influences soil formation through the effects of vegetation cover and biological activity, which modify the rates of chemical reactions in the soil.[116]

#### Topography[edit]

The topography, or relief, is characterized by the inclination (slope), elevation, and orientation of the terrain. Topography determines the rate of precipitation or runoff and rate of formation or erosion of the surface soil profile. The topographical setting may either hasten or retard the work of climatic forces.

Steep slopes encourage rapid soil loss by erosion and allow less rainfall to enter the soil before running off and hence, little mineral deposition in lower profiles. In semiarid regions, the lower effective rainfall on steeper slopes also results in less complete vegetative cover, so there is less plant contribution to soil formation. For all of these reasons, steep slopes prevent the formation of soil from getting very far ahead of soil destruction. Therefore, soils on steep terrain tend to have rather shallow, poorly developed profiles in comparison to soils on nearby, more level sites.[117]

In swales and depressions where runoff water tends to concentrate, the regolith is usually more deeply weathered and soil profile development is more advanced. However, in the lowest landscape positions, water may saturate the regolith to such a degree that drainage and aeration are restricted. Here, the weathering of some minerals and the decomposition of organic matter are retarded, while the loss of iron and manganese is accelerated. In such low-lying topography, special profile features characteristic of wetland soils may develop. Depressions allow the accumulation of water, minerals and organic matter and in the extreme, the resulting soils will be saline marshes or peat bogs. Intermediate topography affords the best conditions for the formation of an agriculturally productive soil.

#### Organisms[edit]

Soil is the most abundant ecosystem on Earth, but the vast majority of organisms in soil are microbes, a great many of which have not been described.[118][119] There may be a population limit of around one billion cells per gram of soil, but estimates of the number of species vary widely from 50,000 per gram to over a million per gram of soil.[118][120] The total number of organisms and species can vary widely according to soil type, location, and depth.[119][120]

Plants, animals, fungi, bacteria and humans affect soil formation (see soil biomantle and stonelayer). Soil animals, including soil macrofauna and soil mesofauna, mix soils as they form burrows and pores, allowing moisture and gases to move about, a process called bioturbation.[121] In the same way, plant roots penetrate soil horizons and open channels upon decomposition.[122] Plants with deep taproots can penetrate many metres through the different soil layers to bring up nutrients from deeper in the profile.[123] Plants have fine roots that excrete organic compounds (sugars, organic acids, mucigel), slough off cells (in particular at their tip) and are easily decomposed, adding organic matter to soil, a process called rhizodeposition.[124] Micro-organisms, including fungi and bacteria, effect chemical exchanges between roots and soil and act as a reserve of nutrients in a soil biological hotspot called rhizosphere.[125] The growth of roots through the soil stimulates microbial populations, stimulating in turn the activity of their predators (notably amoeba), thereby increasing the mineralization rate, and in last turn root growth, a positive feedback called the soil microbial loop.[126] Out of root influence, in the bulk soil, most bacteria are in a quiescent stage, forming microaggregates, i.e. mucilaginous colonies to which clay particles are glued, offering them a protection against desiccation and predation by soil microfauna (bacteriophagous protozoa and nematodes).[127] Microaggregates (20-250 μm) are ingested by soil mesofauna and macrofauna, and bacterial bodies are partly or totally digested in their guts.[128]

Humans impact soil formation by removing vegetation cover with erosion, waterlogging, lateritization or podzolization (according to climate and topography) as the result.[129] Their tillage also mixes the different soil layers, restarting the soil formation process as less weathered material is mixed with the more developed upper layers, resulting in net increased rate of mineral weathering.[130]

Earthworms, ants, termites, moles, gophers, as well as some millipedes and tenebrionid beetles mix the soil as they burrow, significantly affecting soil formation.[131] Earthworms ingest soil particles and organic residues, enhancing the availability of plant nutrients in the material that passes through their bodies.[132] They aerate and stir the soil and create stable soil aggregates, after having disrupted links between soil particles during the intestinal transit of ingested soil,[133] thereby assuring ready infiltration of water.[134] In addition, as ants and termites build mounds, they transport soil materials from one horizon to another.[135] Other important functions are fulfilled by earthworms in the soil ecosystem, in particular their intense mucus production, both within the intestine and as a lining in their galleries,[136] exert a priming effect on soil microflora,[137] giving them the status of ecosystem engineers, which they share with ants and termites.[138]

In general, the mixing of the soil by the activities of animals, sometimes called pedoturbation, tends to undo or counteract the tendency of other soil-forming processes that create distinct horizons.[139] Termites and ants may also retard soil profile development by denuding large areas of soil around their nests, leading to increased loss of soil by erosion.[140] Large animals such as gophers, moles, and prairie dogs bore into the lower soil horizons, bringing materials to the surface.[141] Their tunnels are often open to the surface, encouraging the movement of water and air into the subsurface layers. In localized areas, they enhance mixing of the lower and upper horizons by creating, and later refilling the tunnels. Old animal burrows in the lower horizons often become filled with soil material from the overlying A horizon, creating profile features known as crotovinas.[142]

Vegetation impacts soils in numerous ways. It can prevent erosion caused by excessive rain that might result from surface runoff.[143] Plants shade soils, keeping them cooler[144] and slow evaporation of soil moisture,[145] or conversely, by way of transpiration, plants can cause soils to lose moisture, resulting in complex and highly variable relationships between leaf area index (measuring light interception) and moisture loss: more generally plants prevent soil from desiccation during driest months while they dry it during moister months, thereby acting as a buffer against strong moisture variation.[146] Plants can form new chemicals that can break down minerals, both directly[147] and indirectly through mycorrhizal fungi[85] and rhizosphere bacteria,[148] and improve the soil structure.[149] The type and amount of vegetation depends on climate, topography, soil characteristics and biological factors, mediated or not by human activities.[150][151] Soil factors such as density, depth, chemistry, pH, temperature and moisture greatly affect the type of plants that can grow in a given location. Dead plants and fallen leaves and stems begin their decomposition on the surface. There, organisms feed on them and mix the organic material with the upper soil layers; these added organic compounds become part of the soil formation process.[152]

Human activities widely influence soil formation.[153] For example, it is believed that Native Americans regularly set fires to maintain several large areas of prairie grasslands in Indiana and Michigan, although climate and mammalian grazers (e.g. bisons) are also advocated to explain the maintenance of the Great Plains of North America.[154] In more recent times, human destruction of natural vegetation and subsequent tillage of the soil for crop production has abruptly modified soil formation.[155] Likewise, irrigating soil in an arid region drastically influences soil-forming factors,[156] as does adding fertilizer and lime to soils of low fertility.[157]

#### Time[edit]

Time is a factor in the interactions of all the above.[78] While a mixture of sand, silt and clay constitute the texture of a soil and the aggregation of those components produces peds, the development of a distinct B horizon marks the development of a soil or pedogenesis.[158] With time, soils will evolve features that depend on the interplay of the prior listed soil-forming factors.[78] It takes decades[159] to several thousand years for a soil to develop a profile,[160] although the notion of soil development has been criticized, soil being in a constant state-of-change under the influence of fluctuating soil-forming factors.[161] That time period depends strongly on climate, parent material, relief, and biotic activity.[162][163] For example, recently deposited material from a flood exhibits no soil development as there has not been enough time for the material to form a structure that further defines soil.[164] The original soil surface is buried, and the formation process must begin anew for this deposit. Over time the soil will develop a profile that depends on the intensities of biota and climate. While a soil can achieve relative stability of its properties for extended periods,[160] the soil life cycle ultimately ends in soil conditions that leave it vulnerable to erosion.[165] Despite the inevitability of soil retrogression and degradation, most soil cycles are long.[160]

Soil-forming factors continue to affect soils during their existence, even on "stable" landscapes that are long-enduring, some for millions of years.[160] Materials are deposited on top[166] or are blown or washed from the surface.[167] With additions, removals and alterations, soils are always subject to new conditions. Whether these are slow or rapid changes depends on climate, topography and biological activity.[168]

Time as a soil-forming factor may be investigated by studying soil chronosequences, in which soils of different ages but with minor differences in other soil-forming factors can be compared.[169]

## Physical properties[edit]

The physical properties of soils, in order of decreasing importance for ecosystem services such as crop production, are texture, structure, bulk density, porosity, consistency, temperature, colour and resistivity.[170] Soil texture is determined by the relative proportion of the three kinds of soil mineral particles, called soil separates: sand, silt, and clay. At the next larger scale, soil structures called peds or more commonly soil aggregates are created from the soil separates when iron oxides, carbonates, clay, silica and humus, coat particles and cause them to adhere into larger, relatively stable secondary structures.[171] Soil bulk density, when determined at standardized moisture conditions, is an estimate of soil compaction.[172] Soil porosity consists of the void part of the soil volume and is occupied by gases or water. Soil consistency is the ability of soil materials to stick together. Soil temperature and colour are self-defining. Resistivity refers to the resistance to conduction of electric currents and affects the rate of corrosion of metal and concrete structures which are buried in soil.[173] These properties vary through the depth of a soil profile, i.e. through soil horizons. Most of these properties determine the aeration of the soil and the ability of water to infiltrate and to be held within the soil.[174]

Influence of Soil Texture Separates on Some Properties of Soils[55]
Property/behavior | Sand | Silt | Clay
--- | --- | --- | ---
Water-holding capacity | Low | Medium to high | High
Aeration | Good | Medium | Poor
Drainage rate | High | Slow to medium | Very slow
Soil organic matter level | Low | Medium to high | High to medium
Decomposition of organic matter | Rapid | Medium | Slow
Warm-up in spring | Rapid | Moderate | Slow
Compactability | Low | Medium | High
Susceptibility to wind erosion | Moderate (High if fine sand) | High | Low
Susceptibility to water erosion | Low (unless fine sand) | High | Low if aggregated, otherwise high
Shrink/Swell Potential | Very Low | Low | Moderate to very high
Sealing of ponds, dams, and landfills | Poor | Poor | Good
Suitability for tillage after rain | Good | Medium | Poor
Pollutant leaching potential | High | Medium | Low (unless cracked)
Ability to store plant nutrients | Poor | Medium to High | High
Resistance to pH change | Low | Medium | High

### Texture[edit]

Soil types by clay, silt, and sand composition as used by the USDA
Iron-rich soil near Paint Pots in Kootenay National Park, Canada

The mineral components of soil are sand, silt and clay, and their relative proportions determine a soil's texture. Properties that are influenced by soil texture include porosity, permeability, infiltration, shrink-swell rate, water-holding capacity, and susceptibility to erosion. In the illustrated USDA textural classification triangle, the only soil in which neither sand, silt nor clay predominates is called loam. While even pure sand, silt or clay may be considered a soil, from the perspective of conventional agriculture a loam soil with a small amount of organic material is considered "ideal", inasmuch as fertilizers or manure are currently used to mitigate nutrient losses due to crop yields in the long term.[175] The mineral constituents of a loam soil might be 40% sand, 40% silt and the balance 20% clay by weight. Soil texture affects soil behaviour, in particular, its retention capacity for nutrients (e.g., cation exchange capacity)[176] and water.

Sand and silt are the products of physical and chemical weathering of the parent rock;[78] clay, on the other hand, is most often the product of the precipitation of the dissolved parent rock as a secondary mineral, except when derived from the weathering of mica.[177] It is the surface area to volume ratio (specific surface area) of soil particles and the unbalanced ionic electric charges within those that determine their role in the fertility of soil, as measured by its cation exchange capacity.[178][179] Sand is least active, having the least specific surface area, followed by silt; clay is the most active. Sand's greatest benefit to soil is that it resists compaction and increases soil porosity, although this property stands only for pure sand, not for sand mixed with smaller minerals which fill the voids among sand grains.[180] Silt is mineralogically like sand but with its higher specific surface area it is more chemically and physically active than sand. But it is the clay content of soil, with its very high specific surface area and generally large number of negative charges, that gives a soil its high retention capacity for water and nutrients.[178] Clay soils also resist wind and water erosion better than silty and sandy soils, as the particles bond tightly to each other,[181] and that with a strong mitigation effect of organic matter.[182]

Sand is the most stable of the mineral components of soil; it consists of rock fragments, primarily quartz particles, ranging in size from 2.0 to 0.05 mm (0.0787 to 0.0020 in) in diameter. Silt ranges in size from 0.05 to 0.002 mm (0.001969 to 7.9×10−5 in). Clay cannot be resolved by optical microscopes as its particles are 0.002 mm (7.9×10−5 in) or less in diameter and a thickness of only 10 angstroms (10−10 m).[183][184] In medium-textured soils, clay is often washed downward through the soil profile (a process called eluviation) and accumulates in the subsoil (a process called illuviation). There is no clear relationship between the size of soil mineral components and their mineralogical nature: sand and silt particles can be calcareous as well as siliceous,[185] while textural clay (0.002 mm (7.9×10−5 in)) can be made of very fine quartz particles as well as of multi-layered secondary minerals.[186] Soil mineral components belonging to a given textural class may thus share properties linked to their specific surface area (e.g. moisture retention) but not those linked to their chemical composition (e.g. cation exchange capacity).

Soil components larger than 2.0 mm (0.079 in) are classed as rock and gravel and are removed before determining the percentages of the remaining components and the textural class of the soil, but are included in the name. For example, a sandy loam soil with 20% gravel would be called gravelly sandy loam.

When the organic component of a soil is substantial, the soil is called organic soil rather than mineral soil. A soil is called organic if:

1. Mineral fraction is 0% clay and organic matter is 20% or more
2. Mineral fraction is 0% to 50% clay and organic matter is between 20% and 30%
3. Mineral fraction is 50% or more clay and organic matter 30% or more.[187]

### Structure[edit]

The clumping of the soil textural components of sand, silt and clay causes aggregates to form and the further association of those aggregates into larger units creates soil structures called peds (a contraction of the word pedolith). The adhesion of the soil textural components by organic substances, iron oxides, carbonates, clays, and silica, the breakage of those aggregates from expansion-contraction caused by freezing-thawing and wetting-drying cycles,[188] and the build-up of aggregates by soil animals, microbial colonies and root tips[189] shape soil into distinct geometric forms.[38][131] The peds evolve into units which have various shapes, sizes and degrees of development.[190] A soil clod, however, is not a ped but rather a mass of soil that results from mechanical disturbance of the soil such as cultivation. Soil structure affects aeration, water movement, conduction of heat, plant root growth and resistance to erosion.[191] Water, in turn, has a strong effect on soil structure, directly via the dissolution and precipitation of minerals, the mechanical destruction of aggregates (slaking)[192] and indirectly by promoting plant, animal and microbial growth.

Soil structure often gives clues to its texture, organic matter content, biological activity, past soil evolution, human use, and the chemical and mineralogical conditions under which the soil formed. While texture is defined by the mineral component of a soil and is an innate property of the soil that does not change with agricultural activities, soil structure can be improved or destroyed by the choice and timing of farming practices.[38]

Soil structural classes:[193]

1. Types: Shape and arrangement of peds
   1. Platy: Peds are flattened one atop the other 1–10 mm thick. Found in the A-horizon of forest soils and lake sedimentation.
   2. Prismatic and Columnar: Prismlike peds are long in the vertical dimension, 10–100 mm wide. Prismatic peds have flat tops, columnar peds have rounded tops. Tend to form in the B-horizon in high sodium soil where clay has accumulated.
   3. Angular and subangular: Blocky peds are imperfect cubes, 5–50 mm, angular have sharp edges, subangular have rounded edges. Tend to form in the B-horizon where clay has accumulated and indicate poor water penetration.
   4. Granular and Crumb: Spheroid peds of polyhedrons, 1–10 mm, often found in the A-horizon in the presence of organic material. Crumb peds are more porous and are considered ideal.
2. Classes: Size of peds whose ranges depend upon the above type
   1. Very fine or very thin: <1 mm platy and spherical; <5 mm blocky; <10 mm prismlike.
   2. Fine or thin: 1–2 mm platy, and spherical; 5–10 mm blocky; 10–20 mm prismlike.
   3. Medium: 2–5 mm platy, granular; 10–20 mm blocky; 20–50 prismlike.
   4. Coarse or thick: 5–10 mm platy, granular; 20–50 mm blocky; 50–100 mm prismlike.
   5. Very coarse or very thick: >10 mm platy, granular; >50 mm blocky; >100 mm prismlike.
3. Grades: Is a measure of the degree of development or cementation within the peds that results in their strength and stability.
   1. Weak: Weak cementation allows peds to fall apart into the three textural constituents, sand, silt and clay.
   2. Moderate: Peds are not distinct in undisturbed soil but when removed they break into aggregates, some broken aggregates and little unaggregated material. This is considered ideal.
   3. Strong:Peds are distinct before removed from the profile and do not break apart easily.
   4. Structureless: Soil is entirely cemented together in one great mass such as slabs of clay or no cementation at all such as with sand.

At the largest scale, the forces that shape a soil's structure result from swelling and shrinkage that initially tend to act horizontally, causing vertically oriented prismatic peds. This mechanical process is mainly exemplified in the development of vertisols.[194] Clayey soil, due to its differential drying rate with respect to the surface, will induce horizontal cracks, reducing columns to blocky peds.[195] Roots, rodents, worms, and freezing-thawing cycles further break the peds into smaller peds of a more or less spherical shape.[189]

At a smaller scale, plant roots extend into voids (macropores) and remove water[196] causing macroporosity to increase and microporosity to decrease,[197] thereby decreasing aggregate size.[198] At the same time, root hairs and fungal hyphae create microscopic tunnels that break up peds.[199][200]

At an even smaller scale, soil aggregation continues as bacteria and fungi exude sticky polysaccharides which bind soil into smaller peds.[201] The addition of the raw organic matter that bacteria and fungi feed upon encourages the formation of this desirable soil structure.[202]

At the lowest scale, the soil chemistry affects the aggregation or dispersal of soil particles. The clay particles contain polyvalent cations which give the faces of clay layers localized negative charges.[203] At the same time, the edges of the clay plates have a slight positive charge, thereby allowing the edges to adhere to the negative charges on the faces of other clay particles or to flocculate (form clumps).[204] On the other hand, when monovalent ions, such as sodium, invade and displace the polyvalent cations, they weaken the positive charges on the edges, while the negative surface charges are relatively strengthened. This leaves negative charge on the clay faces that repel other clay, causing the particles to push apart, and by doing so deflocculate clay suspensions.[205] As a result, the clay disperses and settles into voids between peds, causing those to close. In this way the open structure of the soil is destroyed and the soil is made impenetrable to air and water.[206] Such sodic soil (also called haline soil) tends to form columnar peds near the surface.[207]

### Density[edit]

Representative bulk densities of soils. The percentage pore space was calculated using 2.7 g/cm3 for particle density except for the peat soil, which is estimated.[208]
Soil treatment and identification | Bulk density (g/cm3) | Pore space (%)
--- | --- | ---
Tilled surface soil of a cotton field | 1.3 | 51
Trafficked inter-rows where wheels passed surface | 1.67 | 37
Traffic pan at 25 cm deep | 1.7 | 36
Undisturbed soil below traffic pan, clay loam | 1.5 | 43
Rocky silt loam soil under aspen forest | 1.62 | 40
Loamy sand surface soil | 1.5 | 43
Decomposed peat | 0.55 | 65

Soil particle density is typically 2.60 to 2.75 grams per cm3 and is usually unchanging for a given soil.[9] Soil particle density is lower for soils with high organic matter content,[209] and is higher for soils with high iron-oxides content.[210] Soil bulk density is equal to the dry mass of the soil divided by the volume of the soil; i.e., it includes air space and organic materials of the soil volume. Thereby soil bulk density is always less than soil particle density and is a good indicator of soil compaction.[211] The soil bulk density of cultivated loam is about 1.1 to 1.4 g/cm3 (for comparison water is 1.0 g/cm3).[212] Contrary to particle density, soil bulk density is highly variable for a given soil, with a strong causal relationship with soil biological activity and management strategies.[213] However, it has been shown that, depending on species and the size of their aggregates (faeces), earthworms may either increase or decrease soil bulk density.[214] A lower bulk density by itself does not indicate suitability for plant growth due to the confounding influence of soil texture and structure.[215] A high bulk density is indicative of either soil compaction or a mixture of soil textural classes in which small particles fill the voids among coarser particles.[216] Hence the positive correlation between the fractal dimension of soil, considered as a porous medium, and its bulk density,[217] that explains the poor hydraulic conductivity of silty clay loam in the absence of a faunal structure.[218]

### Porosity[edit]

Pore space is that part of the bulk volume of soil that is not occupied by either mineral or organic matter but is open space occupied by either gases or water. In a productive, medium-textured soil the total pore space is typically about 50% of the soil volume.[219] Pore size varies considerably; the smallest pores (cryptopores; <0.1 μm) hold water too tightly for use by plant roots; plant-available water is held in ultramicropores, micropores and mesopores (0.1–75 μm); and macropores (>75 μm) are generally air-filled when the soil is at field capacity.

Soil texture determines total volume of the smallest pores;[220] clay soils have smaller pores, but more total pore space than sands,[221] despite of a much lower permeability.[222] Soil structure has a strong influence on the larger pores that affect soil aeration, water infiltration and drainage.[223] Tillage has the short-term benefit of temporarily increasing the number of pores of largest size, but these can be rapidly degraded by the destruction of soil aggregation.[224]

The pore size distribution affects the ability of plants and other organisms to access water and oxygen; large, continuous pores allow rapid transmission of air, water and dissolved nutrients through soil, and small pores store water between rainfall or irrigation events.[225] Pore size variation also compartmentalizes the soil pore space such that many microbial and faunal organisms are not in direct competition with one another, which may explain not only the large number of species present, but the fact that functionally redundant organisms (organisms with the same ecological niche) can co-exist within the same soil.[226]

### Consistency[edit]

Consistency is the ability of soil to stick to itself or to other objects (cohesion and adhesion, respectively) and its ability to resist deformation and rupture. It is of approximate use in predicting cultivation problems[227] and the engineering of foundations.[228] Consistency is measured at three moisture conditions: air-dry, moist, and wet.[229] In those conditions the consistency quality depends upon the clay content. In the wet state, the two qualities of stickiness and plasticity are assessed. A soil's resistance to fragmentation and crumbling is assessed in the dry state by rubbing the sample. Its resistance to shearing forces is assessed in the moist state by thumb and finger pressure. Additionally, the cemented consistency depends on cementation by substances other than clay, such as calcium carbonate, silica, oxides and salts; moisture content has little effect on its assessment. The measures of consistency border on subjective compared to other measures such as pH, since they employ the apparent feel of the soil in those states.

The terms used to describe the soil consistency in three moisture states and a last not affected by the amount of moisture are as follows:

1. Consistency of Dry Soil: loose, soft, slightly hard, hard, very hard, extremely hard
2. Consistency of Moist Soil: loose, very friable, friable, firm, very firm, extremely firm
3. Consistency of Wet Soil: nonsticky, slightly sticky, sticky, very sticky; nonplastic, slightly plastic, plastic, very plastic
4. Consistency of Cemented Soil: weakly cemented, strongly cemented, indurated (requires hammer blows to break up)[230]

Soil consistency is useful in estimating the ability of soil to support buildings and roads. More precise measures of soil strength are often made prior to construction.

### Temperature[edit]

Soil temperature depends on the ratio of the energy absorbed to that lost.[231] Soil has a temperature range between -20 to 60 °C,[citation needed] with a mean annual temperature from -10 to 26 °C according to biomes.[232] Soil temperature regulates seed germination,[233] breaking of seed dormancy,[234][235] plant and root growth[236] and the availability of nutrients.[237] Soil temperature has important seasonal, monthly and daily variations, fluctuations in soil temperature being much lower with increasing soil depth.[238] Heavy mulching (a type of soil cover) can slow the warming of soil in summer, and, at the same time, reduce fluctuations in surface temperature.[239]

Most often, agricultural activities must adapt to soil temperatures by:

1. maximizing germination and growth by timing of planting (also determined by photoperiod)[240]
2. optimizing use of anhydrous ammonia by applying to soil below 10 °C (50 °F)[241]
3. preventing heaving and thawing due to frosts from damaging shallow-rooted crops[242]
4. preventing damage to desirable soil structure by freezing of saturated soils[243]
5. improving uptake of phosphorus by plants[244]

Soil temperatures can be raised by drying soils[245] or the use of clear plastic mulches.[246] Organic mulches slow the warming of the soil.[239]

There are various factors that affect soil temperature, such as water content,[247] soil color,[248] and relief (slope, orientation, and elevation),[249] and soil cover (shading and insulation), in addition to air temperature.[250] The color of the ground cover and its insulating properties have a strong influence on soil temperature.[251] Whiter soil tends to have a higher albedo than blacker soil cover, which encourages whiter soils to have lower soil temperatures.[248] The specific heat of soil is the energy required to raise the temperature of soil by 1 °C. The specific heat of soil increases as water content increases, since the heat capacity of water is greater than that of dry soil.[252] The specific heat of pure water is ~ 1 calorie per gram, the specific heat of dry soil is ~ 0.2 calories per gram, hence, the specific heat of wet soil is ~ 0.2 to 1 calories per gram (0.8 to 4.2 kJ per kilogram).[253] Also, a tremendous energy (~584 cal/g or 2442 kJ/kg at 25 ℃) is required to evaporate water (known as the heat of vaporization). As such, wet soil usually warms more slowly than dry soil – wet surface soil is typically 3 to 6 °C colder than dry surface soil.[254]

Soil heat flux refers to the rate at which heat energy moves through the soil in response to a temperature difference between two points in the soil. The heat flux density is the amount of energy that flows through soil per unit area per unit time and has both magnitude and direction. For the simple case of conduction into or out of the soil in the vertical direction, which is most often applicable the heat flux density is:

  q x = − k δ T δ x {\displaystyle q_{x}=-k{\frac {\delta T}{\delta x}}}

In SI units

  q {\displaystyle q} is the heat flux density, in SI the units are W·m−2
  k {\displaystyle k} is the soils' conductivity, W·m−1·K−1. The thermal conductivity is sometimes a constant, otherwise an average value of conductivity for the soil condition between the surface and the point at depth is used.
  δ T {\displaystyle \delta T} is the temperature difference (temperature gradient) between the two points in the soil between which the heat flux density is to be calculated. In SI the units are kelvin, K.
  δ x {\displaystyle \delta x} is the distance between the two points within the soil, at which the temperatures are measured and between which the heat flux density is being calculated. In SI the units are meters m, and where x is measured positive downward.

Heat flux is in the direction opposite the temperature gradient, hence the minus sign. That is to say, if the temperature of the surface is higher than at depth x the negative sign will result in a positive value for the heat flux q, and which is interpreted as the heat being conducted into the soil.

[55]
Component | Thermal Conductivity (W·m‐1·K‐1)
--- | ---
Quartz | 8.8
Clay | 2.9
Organic matter | 0.25
Water | 0.57
Ice | 2.4
Air | 0.025
Dry soil | 0.2‐0.4
Wet soil | 1–3

Soil temperature is important for the survival and early growth of seedlings.[255] Soil temperatures affect the anatomical and morphological character of root systems.[256] All physical, chemical, and biological processes in soil and roots are affected in particular because of the increased viscosities of water and protoplasm at low temperatures.[257] In general, climates that do not preclude survival and growth of white spruce above ground are sufficiently benign to provide soil temperatures able to maintain white spruce root systems. In some northwestern parts of the range, white spruce occurs on permafrost sites[258] and although young unlignified roots of conifers may have little resistance to freezing,[259] the root system of containerized white spruce was not affected by exposure to a temperature of 5 to 20 °C.[260]

Optimum temperatures for tree root growth range between 10 °C and 25 °C in general[261] and for spruce in particular.[262] In 2-week-old white spruce seedlings that were then grown for 6 weeks in soil at temperatures of 15 °C, 19 °C, 23 °C, 27 °C, and 31 °C; shoot height, shoot dry weight, stem diameter, root penetration, root volume, and root dry weight all reached maxima at 19 °C.[263]

However, whereas strong positive relationships between soil temperature (5 °C to 25 °C) and growth have been found in trembling aspen and balsam poplar, white and other spruce species have shown little or no changes in growth with increasing soil temperature.[262][264][265][266][267] Such insensitivity to soil low temperature may be common among a number of western and boreal conifers.[268]

Soil temperatures are increasing worldwide under the influence of present-day global climate warming, with opposing views about expected effects on carbon capture and storage and feedback loops to climate change[269] Most threats are about permafrost thawing and attended effects on carbon destocking[270] and ecosystem collapse.[271]

### Color[edit]

Soil colour is often the first impression one has when viewing soil. Striking colours and contrasting patterns are especially noticeable. The Red River of the South carries sediment eroded from extensive reddish soils like Port Silt Loam in Oklahoma. The Yellow River in China carries yellow sediment from eroding loess soils. Mollisols in the Great Plains of North America are darkened and enriched by organic matter. Podsols in boreal forests have highly contrasting layers due to acidity and leaching.

In general, color is determined by the organic matter content, drainage conditions, and degree of oxidation. Soil color, while easily discerned, has little use in predicting soil characteristics.[272] It is of use in distinguishing boundaries of horizons within a soil profile,[273] determining the origin of a soil's parent material,[274] as an indication of wetness and waterlogged conditions,[275] and as a qualitative means of measuring organic,[276] iron oxide[277] and clay contents of soils.[278] Color is recorded in the Munsell color system as for instance 10YR3/4 Dusky Red, with 10YR as hue, 3 as value and 4 as chroma. Munsell color dimensions (hue, value and chroma) can be averaged among samples and treated as quantitative parameters, displaying significant correlations with various soil[279] and vegetation properties.[280]

Soil color is primarily influenced by soil mineralogy. Many soil colours are due to various iron minerals.[277] The development and distribution of colour in a soil profile result from chemical and biological weathering, especially redox reactions.[275] As the primary minerals in soil parent material weather, the elements combine into new and colourful compounds. Iron forms secondary minerals of a yellow or red colour,[281] organic matter decomposes into black and brown humic compounds,[282] and manganese[283] and sulfur[284] can form black mineral deposits. These pigments can produce various colour patterns within a soil. Aerobic conditions produce uniform or gradual colour changes, while reducing environments (anaerobic) result in rapid colour flow with complex, mottled patterns and points of colour concentration.[285]

### Resistivity[edit]

Soil resistivity is a measure of a soil's ability to retard the conduction of an electric current. The electrical resistivity of soil can affect the rate of galvanic corrosion of metallic structures in contact with the soil.[citation needed] Higher moisture content or increased electrolyte concentration can lower resistivity and increase conductivity, thereby increasing the rate of corrosion.[286][287] Soil resistivity values typically range from about 1 to 100000 Ω·m, extreme values being for saline soils and dry soils overlaying cristalline rocks, respectively.[288]

## Water[edit]

Soil moisture refers to the water content of the soil. It can be expressed in terms of volumes or weights. Soil moisture measurement can be based on in situ probes or remote sensing methods.

Water that enters a field is removed from a field by runoff, drainage, evaporation or transpiration.[289] Runoff is the water that flows on the surface to the edge of the field; drainage is the water that flows through the soil downward or toward the edge of the field underground; evaporative water loss from a field is that part of the water that evaporates into the atmosphere directly from the field's surface; transpiration is the loss of water from the field by its evaporation from the plant itself.

Water affects soil formation, structure, stability and erosion but is of primary concern with respect to plant growth.[290] Water is essential to plants for four reasons:

1. It constitutes 80%-95% of the plant's protoplasm.
2. It is essential for photosynthesis.
3. It is the solvent in which nutrients are carried to, into and throughout the plant.
4. It provides the turgidity by which the plant keeps itself in proper position.[291]

In addition, water alters the soil profile by dissolving and re-depositing minerals, often at lower levels.[292] In a loam soil, solids constitute half the volume, gas one-quarter of the volume, and water one-quarter of the volume[33] of which only half will be available to most plants, with a strong variation according to matric potential.[293]

A flooded field will drain the gravitational water under the influence of gravity until water's adhesive and cohesive forces resist further drainage at which point it is said to have reached field capacity.[294] At that point, plants must apply suction[294][295] to draw water from a soil. The water that plants may draw from the soil is called the available water.[294][296] Once the available water is used up the remaining moisture is called unavailable water as the plant cannot produce sufficient suction to draw that water in. At 15 bar suction, wilting point, seeds will not germinate,[297][294][298] plants begin to wilt and then die. Water moves in soil under the influence of gravity, osmosis and capillarity.[299] When water enters the soil, it displaces air from interconnected macropores by buoyancy, and breaks aggregates into which air is entrapped, a process called slaking.[300]

The rate at which a soil can absorb water depends on the soil and its other conditions. As a plant grows, its roots remove water from the largest pores (macropores) first. Soon the larger pores hold only air, and the remaining water is found only in the intermediate- and smallest-sized pores (micropores). The water in the smallest pores is so strongly held to particle surfaces that plant roots cannot pull it away. Consequently, not all soil water is available to plants, with a strong dependence on texture.[301] When saturated, the soil may lose nutrients as the water drains.[302] Water moves in a draining field under the influence of pressure where the soil is locally saturated and by capillarity pull to drier parts of the soil.[303] Most plant water needs are supplied from the suction caused by evaporation from plant leaves (transpiration) and a lower fraction is supplied by suction created by osmotic pressure differences between the plant interior and the soil solution.[304][305] Plant roots must seek out water and grow preferentially in moister soil microsites,[306] but some parts of the root system are also able to remoisten dry parts of the soil.[307] Insufficient water will damage the yield of a crop.[308] Most of the available water is used in transpiration to pull nutrients into the plant.[309]

Soil water is also important for climate modeling and numerical weather prediction. Global Climate Observing System specified soil water as one of the 50 Essential Climate Variables (ECVs).[310] Soil water can be measured in situ with soil moisture sensor or can be estimated from satellite data and hydrological models. Each method exhibits pros and cons, and hence, the integration of different techniques may decrease the drawbacks of a single given method.[311]

### Water retention[edit]

Water is retained in a soil when the adhesive force of attraction that water's hydrogen atoms have for the oxygen of soil particles is stronger than the cohesive forces that water's hydrogen feels for other water oxygen atoms.[312] When a field is flooded, the soil pore space is completely filled by water. The field will drain under the force of gravity until it reaches what is called field capacity, at which point the smallest pores are filled with water and the largest with water and gases.[313] The total amount of water held when field capacity is reached is a function of the specific surface area of the soil particles.[314] As a result, high clay and high organic soils have higher field capacities.[315] The potential energy of water per unit volume relative to pure water in reference conditions is called water potential. Total water potential is a sum of matric potential which results from capillary action, osmotic potential for saline soil, and gravitational potential when dealing with vertical direction of water movement. Water potential in soil usually has negative values, and therefore it is also expressed in suction, which is defined as the minus of water potential. Suction has a positive value and can be regarded as the total force required to pull or push water out of soil. Water potential or suction is expressed in units of kPa (103 pascal), bar (100 kPa), or cm H2O (approximately 0.098 kPa). Common logarithm of suction in cm H2O is called pF.[316] Therefore, pF 3 = 1000 cm = 98 kPa = 0.98 bar.

The forces with which water is held in soils determine its availability to plants. Forces of adhesion hold water strongly to mineral and humus surfaces and less strongly to itself by cohesive forces. A plant's root may penetrate a very small volume of water that is adhering to soil and be initially able to draw in water that is only lightly held by the cohesive forces. But as the droplet is drawn down, the forces of adhesion of the water for the soil particles produce increasingly higher suction, finally up to 1500 kPa (pF = 4.2).[317] At 1500 kPa suction, the soil water amount is called wilting point. At that suction the plant cannot sustain its water needs as water is still being lost from the plant by transpiration, the plant's turgidity is lost, and it wilts, although stomatal closure may decrease transpiration and thus may retard wilting below the wilting point, in particular under adaptation or acclimatization to drought.[318] The next level, called air-dry, occurs at 100,000 kPa suction (pF = 6). Finally the oven dry condition is reached at 1,000,000 kPa suction (pF = 7). All water below wilting point is called unavailable water.[319]

When the soil moisture content is optimal for plant growth, the water in the large and intermediate size pores can move about in the soil and be easily used by plants.[301] The amount of water remaining in a soil drained to field capacity and the amount that is available are functions of the soil type. Sandy soil will retain very little water, while clay will hold the maximum amount.[315] The available water for the silt loam might be 20% whereas for the sand it might be only 6% by volume, as shown in this table.

Wilting point, field capacity, and available water of various soil textures (unit: % by volume)[320]
Soil Texture | Wilting Point | Field Capacity | Available water
--- | --- | --- | ---
Sand | 3.3 | 9.1 | 5.8
Sandy loam | 9.5 | 20.7 | 11.2
Loam | 11.7 | 27.0 | 15.3
Silt loam | 13.3 | 33.0 | 19.7
Clay loam | 19.7 | 31.8 | 12.1
Clay | 27.2 | 39.6 | 12.4

The above are average values for the soil textures.

### Water flow[edit]

Water moves through soil due to the force of gravity, osmosis and capillarity. At zero to 33 kPa suction (field capacity), water is pushed through soil from the point of its application under the force of gravity and the pressure gradient created by the pressure of the water; this is called saturated flow. At higher suction, water movement is pulled by capillarity from wetter toward drier soil. This is caused by water's adhesion to soil solids, and is called unsaturated flow.[321][322]

Water infiltration and movement in soil is controlled by six factors:

1. Soil texture
2. Soil structure. Fine-textured soils with granular structure are most favourable to infiltration of water.
3. The amount of organic matter. Coarse matter is best and if on the surface helps prevent the destruction of soil structure and the creation of crusts.
4. Depth of soil to impervious layers such as hardpans or bedrock
5. The amount of water already in the soil
6. Soil temperature. Warm soils take in water faster while frozen soils may not be able to absorb depending on the type of freezing.[323]

Water infiltration rates range from 0.25 cm per hour for high clay soils to 2.5 cm per hour for sand and well stabilized and aggregated soil structures.[324] Water flows through the ground unevenly, in the form of so-called "gravity fingers", because of the surface tension between water particles.[325][326]

Tree roots, whether living or dead, create preferential channels for rainwater flow through soil,[327] magnifying infiltration rates of water up to 27 times.[328]

Flooding temporarily increases soil permeability in river beds, helping to recharge aquifers.[329]

Water applied to a soil is pushed by pressure gradients from the point of its application where it is saturated locally, to less saturated areas, such as the vadose zone.[330][331] Once soil is completely wetted, any more water will move downward, or percolate out of the range of plant roots, carrying with it clay, humus, nutrients, primarily cations, and various contaminants, including pesticides, pollutants, viruses and bacteria, potentially causing groundwater contamination.[332][333] In order of decreasing solubility, the leached nutrients are:

- Calcium
- Magnesium, Sulfur, Potassium; depending upon soil composition
- Nitrogen; usually little, unless nitrate fertiliser was applied recently
- Phosphorus; very little as its forms in soil are of low solubility.[334]

In the United States percolation water due to rainfall ranges from almost zero centimeters just east of the Rocky Mountains to fifty or more centimeters per day in the Appalachian Mountains and the north coast of the Gulf of Mexico.[335]

Water is pulled by capillary action due to the adhesion force of water to the soil solids, producing a suction gradient from wet towards drier soil[336] and from macropores to micropores.[citation needed] Richards equation represents the movement of water in unsaturated soils.[337] The analysis of unsaturated water flow and solute transport is available by using a readily available software such as Hydrus,[338] by giving soil hydraulic parameters of hydraulic functions (water retention function and unsaturated hydraulic conductivity function) and initial and boundary conditions. Preferential flow occurs along interconnected macropores, crevices, root and worm channels, which drain water under gravity.[339][340] Many models based on soil physics now allow for some representation of preferential flow as a dual continuum, dual porosity or dual permeability options, but these have generally been "bolted on" to the Richards solution without any rigorous physical underpinning.[341]

### Water uptake by plants[edit]

Of equal importance to the storage and movement of water in soil is the means by which plants acquire it and their nutrients. Most soil water is taken up by plants as passive absorption caused by the pulling force of water evaporating (transpiring) from the long column of water (xylem sap flow) that leads from the plant's roots to its leaves, according to the cohesion-tension theory.[342] The upward movement of water and solutes (hydraulic lift) is regulated in the roots by the endodermis[343] and in the plant foliage by stomatal conductance,[344] and can be interrupted in root and shoot xylem vessels by cavitation, also called xylem embolism.[345] In addition, the high concentration of salts within plant roots creates an osmotic pressure gradient that pushes soil water into the roots.[346] Osmotic absorption becomes more important during times of low water transpiration caused by lower temperatures (for example at night) or high humidity, and the reverse occurs under high temperature or low humidity. It is these process that cause guttation and wilting, respectively.[347][348]

Root extension is vital for plant survival. A study of a single winter rye plant grown for four months in one cubic foot (0.0283 cubic meters) of loam soil showed that the plant developed 13,800,000 roots, a total of 620 km in length with 237 square meters in surface area; and 14 billion hair roots of 10,620 km total length and 400 square meters total area; for a total surface area of 638 square meters. The total surface area of the loam soil was estimated to be 52,000 square meters.[349] In other words, the roots were in contact with only 1.2% of the soil. However, root extension should be viewed as a dynamic process, allowing new roots to explore a new volume of soil each day, increasing dramatically the total volume of soil explored over a given growth period, and thus the volume of water taken up by the root system over this period.[350] Root architecture, i.e. the spatial configuration of the root system, plays a prominent role in the adaptation of plants to soil water and nutrient availabiity, and thus in plant productivity.[351]

Roots must seek out water as the unsaturated flow of water in soil can move only at a rate of up to 2.5 cm per day; as a result they are constantly dying and growing as they seek out high concentrations of soil moisture.[352] Insufficient soil moisture, to the point of causing wilting, will cause permanent damage and crop yields will suffer. When grain sorghum was exposed to soil suction as low as 1300 kPa during the seed head emergence through bloom and seed set stages of growth, its production was reduced by 34%.[353]

### Consumptive use and water use efficiency[edit]

Only a small fraction (0.1% to 1%) of the water used by a plant is held within the plant. The majority is ultimately lost via transpiration, while evaporation from the soil surface is also substantial, the transpiration:evaporation ratio varying according to vegetation type and climate, peaking in tropical rainforests and dipping in steppes and deserts.[354] Transpiration plus evaporative soil moisture loss is called evapotranspiration. Evapotranspiration plus water held in the plant totals to consumptive use, which is nearly identical to evapotranspiration.[353][355]

The total water used in an agricultural field includes surface runoff, drainage and consumptive use. The use of loose mulches will reduce evaporative losses for a period after a field is irrigated, but in the end the total evaporative loss (plant plus soil) will approach that of an uncovered soil, while more water is immediately available for plant growth.[356] Water use efficiency is measured by the transpiration ratio, which is the ratio of the total water transpired by a plant to the dry weight of the harvested plant. Transpiration ratios for crops range from 300 to 700. For example, alfalfa may have a transpiration ratio of 500 and as a result 500 kilograms of water will produce one kilogram of dry alfalfa.[357]

## Atmosphere[edit]

The atmosphere of soil, or soil gas, is very different from the atmosphere above. The consumption of oxygen by microbes and plant roots, and their release of carbon dioxide, decrease oxygen and increase carbon dioxide concentration. Atmospheric CO2 concentration is 0.04%, but in the soil pore space it may range from 10 to 100 times that level, thus potentially contributing to the inhibition of root respiration.[358] Calcareous soils regulate CO2 concentration by carbonate buffering, contrary to acid soils in which all CO2 respired accumulates in the soil pore system.[359] At extreme levels CO2 is toxic.[360] This suggests a possible negative feedback control of soil CO2 concentration through its inhibitory effects on root and microbial respiration (also called 'soil respiration').[361] In addition, the soil voids are saturated with water vapour, at least until the point of maximal hygroscopicity, beyond which a vapour-pressure deficit occurs in the soil pore space.[35] Adequate porosity is necessary, not just to allow the penetration of water, but also to allow gases to diffuse in and out. Movement of gases is by diffusion from high concentrations to lower, the diffusion coefficient decreasing with soil compaction.[362] Oxygen from above atmosphere diffuses in the soil where it is consumed and levels of carbon dioxide in excess of above atmosphere diffuse out with other gases (including greenhouse gases) as well as water.[363] Soil texture and structure strongly affect soil porosity and gas diffusion. It is the total pore space (porosity) of soil, not the pore size, and the degree of pore interconnection (or conversely pore sealing), together with water content, air turbulence and temperature, that determine the rate of diffusion of gases into and out of soil.[364][363] Platy soil structure and soil compaction (low porosity) impede gas flow, and a deficiency of oxygen may encourage anaerobic bacteria to reduce (strip oxygen) from nitrate NO3 to the gases N2, N2O, and NO, which are then lost to the atmosphere, thereby depleting the soil of nitrogen.[365] Aerated soil is also a net sink of methane CH4[366] but a net producer of methane (a strong heat-absorbing greenhouse gas) when soils are depleted of oxygen and subject to elevated temperatures.[367]

Soil atmosphere is also the seat of emissions of volatiles other than carbon and nitrogen oxides from various soil organisms, e.g. roots,[368] bacteria,[369] fungi,[370] animals.[371] These volatiles are used as chemical cues, making soil atmosphere the seat of interaction networks[372][373] playing a decisive role in the stability, dynamics and evolution of soil ecosystems.[374] Biogenic soil volatile organic compounds are exchanged with the aboveground atmosphere, in which they are just 1–2 orders of magnitude lower than those from aboveground vegetation.[375]

We humans can get some idea of the soil atmosphere through the well-known 'after-the-rain' scent, when infiltering rainwater flushes out the whole soil atmosphere after a drought period, or when soil is excavated,[376] a bulk property attributed in a reductionist manner to particular biochemical compounds such as petrichor or geosmin.

## Composition of the solid phase (soil matrix)[edit]

Soil particles can be classified by their chemical composition (mineralogy) as well as their size. The particle size distribution of a soil, its texture, determines many of the properties of that soil, in particular hydraulic conductivity and water potential,[377] but the mineralogy of those particles can strongly modify those properties. The mineralogy of the finest soil particles, clay, is especially important.[378]

### Gravel, sand and silt[edit]

Gravel, sand and silt are the larger soil particles, and their mineralogy is often inherited from the parent material of the soil, but may include products of weathering (such as concretions of calcium carbonate or iron oxide), or residues of plant and animal life (such as silica phytoliths).[379][380] Quartz is the most common mineral in the sand or silt fraction as it is resistant to chemical weathering, except under hot climate;[381] other common minerals are feldspars, micas and ferromagnesian minerals such as pyroxenes, amphiboles and olivines, which are dissolved or transformed in clay under the combined influence of physico-chemical and biological processes.[379][382]

### Mineral colloids; soil clays[edit]

Due to its high specific surface area and its unbalanced negative electric charges, clay is the most active mineral component of soil.[383][384] It is a colloidal and most often a crystalline material.[385] In soils, clay is a soil textural class and is defined in a physical sense as any mineral particle less than 2 μm (8×10−5 in) in effective diameter. Many soil minerals, such as gypsum, carbonates, or quartz, are small enough to be classified as clay based on their physical size, but chemically they do not afford the same utility as do mineralogically-defined clay minerals.[386] Chemically, clay minerals are a range of phyllosilicate minerals with certain reactive properties.[387]

Before the advent of X-ray diffraction clay was thought to be very small particles of quartz, feldspar, mica, hornblende or augite, but it is now known to be (with the exception of mica-based clays) a precipitate with a mineralogical composition that is dependent on but different from its parent materials and is classed as a secondary mineral.[388] The type of clay that is formed is a function of the parent material and the composition of the minerals in solution.[389] Clay minerals continue to be formed as long as the soil exists.[390] Mica-based clays result from a modification of the primary mica mineral in such a way that it behaves and is classed as a clay.[391] Most clays are crystalline, but some clays or some parts of clay minerals are amorphous.[392] The clays of a soil are a mixture of the various types of clay, but one type predominates.[393]

Typically there are four main groups of clay minerals: kaolinite, montmorillonite-smectite, illite, and chlorite.[394] Most clays are crystalline and most are made up of three or four planes of oxygen held together by planes of aluminium and silicon by way of ionic bonds that together form a single layer of clay. The spatial arrangement of the oxygen atoms determines clay's structure.[395] Half of the weight of clay is oxygen, but on a volume basis oxygen is ninety percent.[396] The layers of clay are sometimes held together through hydrogen bonds, sodium or potassium bridges and as a result will swell less in the presence of water.[397] Clays such as montmorillonite have layers that are loosely attached and will swell greatly when water intervenes between the layers.[398]

In a wider sense clays can be classified as:

1. Layer Crystalline alumino-silica clays: montmorillonite, illite, vermiculite, chlorite, kaolinite.
2. Crystalline Chain carbonate and sulfate minerals: calcite (CaCO3), dolomite (CaMg(CO3)2) and gypsum (CaSO4·2H2O).
3. Amorphous clays: young mixtures of silica (SiO2-OH) and alumina (Al(OH)3) which have not had time to form regular crystals.
4. Sesquioxide clays: old, highly leached clays which result in oxides of iron, aluminium and titanium.[399]

#### Alumino-silica clays[edit]

Alumino-silica clays or aluminosilicate clays are characterized by their regular crystalline or quasi-crystalline structure.[400] Oxygen in ionic bonds with silicon forms a tetrahedral coordination (silicon at the center) which in turn forms sheets of silica. Two sheets of silica are bonded together by a plane of aluminium which forms an octahedral coordination, called alumina, with the oxygens of the silica sheet above and that below it.[401] Hydroxyl ions (OH−) sometimes substitute for oxygen. During the clay formation process, Al3+ may substitute for Si4+ in the silica layer, and as much as one fourth of the aluminium Al3+ may be substituted by Zn2+, Mg2+ or Fe2+ in the alumina layer. The substitution of lower-valence cations for higher-valence cations (isomorphous substitution) gives clay a local negative charge on an oxygen atom[401] that attracts and holds water and positively charged soil cations, some of which are of value for plant growth.[402] Isomorphous substitution occurs during the clay's formation and does not change with time.[403][162]

- Montmorillonite clay is made of four planes of oxygen with two silicon and one central aluminium plane intervening. The alumino-silicate montmorillonite clay is thus said to have a 2:1 ratio of silicon to aluminium, in short it is called a 2:1 clay mineral.[404] The seven planes together form a single crystal of montmorillonite. The crystals are weakly held together and water may intervene, causing the clay to swell up to ten times its dry volume.[405] It occurs in soils which have had little leaching, hence it is found in arid regions, although it may also occur in humid climates, depending on its mineralogical origin.[406] As the crystals are not bonded face to face, the entire surface is exposed and available for surface reactions, hence it has a high cation exchange capacity (CEC).[407][408][409]
- Illite is a 2:1 clay similar in structure to montmorillonite but has potassium bridges between the faces of the clay crystals and the degree of swelling depends on the degree of weathering of potassium-feldspar.[410] The active surface area is reduced due to the potassium bonds. Illite originates from the modification of mica, a primary mineral. It is often found together with montmorillonite and its primary minerals. It has moderate CEC.[411][408][412][413][414]
- Vermiculite is a mica-based clay similar to illite, but the crystals of clay are held together more loosely by hydrated magnesium and it will swell, but not as much as does montmorillonite.[415] It has very high CEC.[416][417][413][414]
- Chlorite is similar to vermiculite, but the loose bonding by occasional hydrated magnesium, as in vermiculite, is replaced by a hydrated magnesium sheet, that firmly bonds the planes above and below it. It has two planes of silicon, one of aluminium and one of magnesium; hence it is a 2:2 clay.[418] Chlorite does not swell and it has low CEC.[416][419]
- Kaolinite is very common, highly weathered clay, and more common than montmorillonite in acid soils.[420] It has one silica and one alumina plane per crystal; hence it is a 1:1 type clay. One plane of silica of montmorillonite is dissolved and is replaced with hydroxyls, which produces strong hydrogen bonds to the oxygen in the next crystal of clay.[421] As a result, kaolinite does not swell in water and has a low specific surface area, and as almost no isomorphous substitution has occurred it has a low CEC.[422] Where rainfall is high, acid soils selectively leach more silica than alumina from the original clays, leaving kaolinite.[423] Even heavier weathering results in sesquioxide clays.[424][396][409][412][425][426]

#### Crystalline chain clays[edit]

The carbonate and sulfate clay minerals are much more soluble and hence are found primarily in desert soils where leaching is less active.[427]

#### Amorphous clays[edit]

Amorphous clays are young, and commonly found in recent volcanic ash deposits such as tephra.[428] They are mixtures of alumina and silica which have not formed the ordered crystal shape of alumino-silica clays which time would provide. The majority of their negative charges originates from hydroxyl ions, which can gain or lose a hydrogen ion (H+) in response to soil pH, in such way was as to buffer the soil pH. They may have either a negative charge provided by the attached hydroxyl ion (OH−), which can attract a cation, or lose the hydrogen of the hydroxyl to solution and display a positive charge which can attract anions. As a result, they may display either high CEC in an acid soil solution, or high anion exchange capacity in a basic soil solution.[424]

#### Sesquioxide clays[edit]

silica-sesquioxide

Sesquioxide clays are a product of heavy rainfall that has leached most of the silica from alumino-silica clay, leaving the less soluble oxides iron hematite (Fe2O3), iron hydroxide (Fe(OH)3), aluminium hydroxide gibbsite (Al(OH)3), hydrated manganese birnessite (MnO2), as can be observed in most lateritic weathering profiles of tropical soils.[429] It takes hundreds of thousands of years of leaching to create sesquioxide clays.[430] Sesqui is Latin for "one and one-half": there are three parts oxygen to two parts iron or aluminium; hence the ratio is one and one-half (not true for all). They are hydrated and act as either amorphous or crystalline. They are not sticky and do not swell, and soils high in them behave much like sand and can rapidly pass water. They are able to hold large quantities of phosphates, a sorptive process which can at least partly be inhibited in the presence of decomposed (humified) organic matter.[431] Sesquioxides have low CEC but these variable-charge minerals are able to hold anions as well as cations.[432] Such soils range from yellow to red in colour. Such clays tend to hold phosphorus so tightly that it is unavailable for absorption by plants.[433][434][435]

### Organic colloids[edit]

Humus is one of the two final stages of decomposition of organic matter. It remains in the soil as the organic component of the soil matrix while the other stage, carbon dioxide, is freely liberated in the atmosphere or reacts with calcium to form the soluble calcium bicarbonate. While humus may linger for a thousand years,[436] on the larger scale of the age of the mineral soil components, it is temporary, being finally released as CO2. It is composed of the very stable lignins (30%) and complex sugars (polyuronides, 30%), proteins (30%), waxes, and fats that are resistant to breakdown by microbes and can form complexes with metals, facilitating their downward migration (podzolization).[437] However, although originating for its main part from dead plant organs (wood, bark, foliage, roots), a large part of humus comes from organic compounds excreted by soil organisms (roots, microbes, animals) and from their decomposition upon death.[438] Its chemical assay is 60% carbon, 5% nitrogen, some oxygen and the remainder hydrogen, sulfur, and phosphorus. On a dry weight basis, the CEC of humus is many times greater than that of clay.[439][440][441]

Humus plays a major role in the regulation of atmospheric carbon, through carbon sequestration in the soil profile, more especially in deeper horizons with reduced biological activity.[442] Stocking and destocking of soil carbon are under strong climate influence.[443] They are normally balanced through an equilibrium between production and mineralization of organic matter, but the balance is in favour of destocking under present-day climate warming,[444] and more especially in permafrost.[445]

### Carbon and terra preta[edit]

In the extreme environment of high temperatures and the leaching caused by the heavy rain of tropical rain forests, the clay and organic colloids are largely destroyed. The heavy rains wash the alumino-silicate clays from the soil leaving only sesquioxide clays of low CEC. The high temperatures and humidity allow bacteria and fungi to virtually decay any organic matter on the rain-forest floor overnight and much of the nutrients are volatilized or leached from the soil and lost,[446] leaving only a thin root mat lying directly on the mineral soil.[447] However, carbon in the form of finely divided charcoal, also known as black carbon, is far more stable than soil colloids and is capable of performing many of the functions of the soil colloids of sub-tropical soils.[448] Soil containing substantial quantities of charcoal, of an anthropogenic origin, is called terra preta. In Amazonia it testifies for the agronomic knowledge of past Amerindian civilizations.[449] The pantropical peregrine earthworm Pontoscolex corethrurus has been suspected to contribute to the fine division of charcoal and its mixing to the mineral soil in the frame of present-day slash-and-burn or shifting cultivation still practiced by Amerindian tribes.[450] Research into terra preta is still young but is promising. Fallow periods "on the Amazonian Dark Earths can be as short as 6 months, whereas fallow periods on oxisols are usually 8 to 10 years long"[451] The incorporation of charcoal to agricultural soil for improving water and nutrient retention has been called biochar, being extended to other charred or carbon-rich by-products, and is now increasingly used in sustainable tropical agriculture.[452] Biochar also allows the irreversible sorption of pesticides and other pollutants, a mechanism by which their mobility, and thus their environmental risk, decreases.[453] It has also been argued as a mean of sequestering more carbon in the soil, thereby mitigating the so-called greenhouse effect.[454] However, the use of biochar is limited by the availability of wood or other products of pyrolysis and by risks caused by concomitent deforestation.[455]

## Chemistry[edit]

The chemistry of a soil determines its ability to supply available plant nutrients and affects its physical properties and the health of its living population. In addition, a soil's chemistry also determines its corrosivity, stability, and ability to absorb pollutants and to filter water. It is the surface chemistry of mineral and organic colloids that determines soil's chemical properties.[456] A colloid is a small, insoluble particle ranging in size from 1 nanometer to 1 micrometer, thus small enough to remain suspended by Brownian motion in a fluid medium without settling.[457] Most soils contain organic colloidal particles called humus as well as the inorganic colloidal particles of clays. The very high specific surface area of colloids and their net electrical charges give soil its ability to hold and release ions. Negatively charged sites on colloids attract and release cations in what is referred to as cation exchange. Cation-exchange capacity (CEC) is the amount of exchangeable cations per unit weight of dry soil and is expressed in terms of milliequivalents of positively charged ions per 100 grams of soil (or centimoles of positive charge per kilogram of soil; cmolc/kg). Similarly, positively charged sites on colloids can attract and release anions in the soil giving the soil anion exchange capacity (AEC).

### Cation and anion exchange[edit]

The cation exchange, that takes place between colloids and soil water, buffers (moderates) soil pH, alters soil structure, and purifies percolating water by adsorbing cations of all types, both useful and harmful.

The negative or positive charges on colloid particles make them able to hold cations or anions, respectively, to their surfaces. The charges result from four sources.[458]

1. Isomorphous substitution occurs in clay during its formation, when lower-valence cations substitute for higher-valence cations in the crystal structure.[203] Substitutions in the outermost layers are more effective than for the innermost layers, as the electric charge strength drops off as the square of the distance. The net result is oxygen atoms with net negative charge and the ability to attract cations.
2. Edge-of-clay oxygen atoms are not in balance ionically as the tetrahedral and octahedral structures are incomplete.[459]
3. Hydroxyls may substitute for oxygens of the silica layers, a process called hydroxylation. When the hydrogens of the clay hydroxyls are ionised into solution, they leave the oxygen with a negative charge (anionic clays).[460]
4. Hydrogens of humus hydroxyl groups may also be ionised into solution, leaving, similarly to clay, an oxygen with a negative charge.[461]

Cations held to the negatively charged colloids resist being washed downward by water and out of reach of plants' roots, thereby preserving the fertility of soils in areas of moderate rainfall and low temperatures.[462][463]

There is a hierarchy in the process of cation exchange on colloids, as they differ in the strength of adsorption by the colloid and hence their ability to replace one another (ion exchange). If present in equal amounts in the soil water solution:

Al3+ replaces H+ replaces Ca2+ replaces Mg2+ replaces K+ same as NH4+ replaces Na+[464]

If one cation is added in large amounts, it may replace the others by the sheer force of its numbers. This is called law of mass action. This is largely what occurs with the addition of cationic fertilisers (potash, lime).[465]

As the soil solution becomes more acidic (low pH, meaning an abundance of H+, the other cations more weakly bound to colloids are pushed into solution as hydrogen ions occupy exchange sites (protonation). A low pH may cause hydrogen of hydroxyl groups to be pulled into solution, leaving charged sites on the colloid available to be occupied by other cations. This ionisation of hydroxyl groups on the surface of soil colloids creates what is described as pH-dependent surface charges.[466] Unlike permanent charges developed by isomorphous substitution, pH-dependent charges are variable and increase with increasing pH.[43] Freed cations can be made available to plants but are also prone to be leached from the soil, possibly making the soil less fertile.[467] Plants are able to excrete H+ into the soil through the synthesis of organic acids and by that means, change the pH of the soil near the root and push cations off the colloids, thus making those available to the plant.[468]

#### Cation exchange capacity (CEC)[edit]

Cation exchange capacity should be thought of as the soil's ability to remove cations from the soil water solution and sequester those to be exchanged later as the plant roots release hydrogen ions to the solution. CEC is the amount of exchangeable hydrogen cation (H+) that will combine with 100 grams dry weight of soil and whose measure is one milliequivalents per 100 grams of soil (1 meq/100 g). Hydrogen ions have a single charge and one-thousandth of a gram of hydrogen ions per 100 grams dry soil gives a measure of one milliequivalent of hydrogen ion. Calcium, with an atomic weight 40 times that of hydrogen and with a valence of two, converts to (40/2) x 1 milliequivalent = 20 milliequivalents of hydrogen ion per 100 grams of dry soil or 20 meq/100 g.[469] The modern measure of CEC is expressed as centimoles of positive charge per kilogram (cmol/kg) of oven-dry soil.

Most of the soil's CEC occurs on clay and humus colloids, and the lack of those in hot, humid, wet climates, due to leaching and decomposition, respectively, explains the apparent sterility of tropical soils.[470] Live plant roots also have some CEC, linked to their specific surface area.[471]

Cation exchange capacity for soils; soil textures; soil colloids[472]
Soil | State | CEC meq/100 g
--- | --- | ---
Charlotte fine sand | Florida | 1.0
Ruston fine sandy loam | Texas | 1.9
Glouchester loam | New Jersey | 11.9
Grundy silt loam | Illinois | 26.3
Gleason clay loam | California | 31.6
Susquehanna clay loam | Alabama | 34.3
Davie mucky fine sand | Florida | 100.8
Sands | ------ | 1–5
Fine sandy loams | ------ | 5–10
Loams and silt loams | ----- | 5–15
Clay loams | ----- | 15–30
Clays | ----- | over 30
Sesquioxides | ----- | 0–3
Kaolinite | ----- | 3–15
Illite | ----- | 25–40
Montmorillonite | ----- | 60–100
Vermiculite (similar to illite) | ----- | 80–150
Humus | ----- | 100–300

#### Anion exchange capacity (AEC)[edit]

Anion exchange capacity should be thought of as the soil's ability to remove anions (e.g. nitrate, phosphate) from the soil water solution and sequester those for later exchange as the plant roots release carbonate anions to the soil water solution. Those colloids which have low CEC tend to have some AEC. Amorphous and sesquioxide clays have the highest AEC,[473] followed by the iron oxides. Levels of AEC are much lower than for CEC, because of the generally higher rate of positively (versus negatively) charged surfaces on soil colloids, to the exception of variable-charge soils.[474] Phosphates tend to be held at anion exchange sites.[475]

Iron and aluminum hydroxide clays are able to exchange their hydroxide anions (OH−) for other anions.[476] The order reflecting the strength of anion adhesion is as follows:

  H2PO4− replaces SO42− replaces NO3− replaces Cl−

The amount of exchangeable anions is of a magnitude of tenths to a few milliequivalents per 100 g dry soil.[472] As pH rises, there are relatively more hydroxyls, which will displace anions from the colloids and force them into solution and out of storage; hence AEC decreases with increasing pH (alkalinity).[477]

### Reactivity (pH)[edit]

Soil reactivity is expressed in terms of pH and is a measure of the acidity or alkalinity of the soil. More precisely, it is a measure of hydrogen ion concentration in an aqueous solution and ranges in values from 0 to 14 (acidic to basic) but practically speaking for soils, pH ranges from 3.5 to 9.5, as pH values beyond those extremes are toxic to life forms.[478]

At 25 °C an aqueous solution that has a pH of 3.5 has 10−3.5 moles H+ (hydrogen ions) per litre of solution (and also 10−10.5 mole/litre OH−). A pH of 7, defined as neutral, has 10−7 moles of hydrogen ions per litre of solution and also 10−7 moles of OH− per litre; since the two concentrations are equal, they are said to neutralise each other. A pH of 9.5 has 10−9.5 moles hydrogen ions per litre of solution (and also 10−2.5 mole per litre OH−). A pH of 3.5 has one million times more hydrogen ions per litre than a solution with pH of 9.5 (9.5–3.5 = 6 or 106) and is more acidic.[479]

The effect of pH on a soil is to remove from the soil or to make available certain ions. Soils with high acidity tend to have toxic amounts of aluminium and manganese.[480] As a result of a trade-off between toxicity and requirement most nutrients are better available to plants at moderate pH,[481] although most minerals are more soluble in acid soils. Soil organisms are hindered by high acidity, and most agricultural crops do best with mineral soils of pH 6.5 and organic soils of pH 5.5.[482] Given that at low pH toxic metals (e.g. cadmium, zinc, lead) are positively charged as cations and organic pollutants are in non-ionic form, thus both made more available to organisms,[483][484] it has been suggested that plants, animals and microbes commonly living in acid soils are pre-adapted to every kind of pollution, whether of natural or human origin.[485]

In high rainfall areas, soils tend to acidity as the basic cations are forced off the soil colloids by the mass action of hydrogen ions from the rain against those attached to the colloids. High rainfall rates can then wash the nutrients out, leaving the soil inhabited only by those organisms which are particularly efficient to uptake nutrients in very acid conditions, like in tropical rainforests.[486] Once the colloids are saturated with H+, the addition of any more hydrogen ions or aluminum hydroxyl cations drives the pH even lower (more acidic) as the soil has been left with no buffering capacity.[487] In areas of extreme rainfall and high temperatures, the clay and humus may be washed out, further reducing the buffering capacity of the soil.[488] In low rainfall areas, unleached calcium pushes pH to 8.5 and with the addition of exchangeable sodium, soils may reach pH 10.[489] Beyond a pH of 9, plant growth is reduced.[490] High pH results in low micro-nutrient mobility, but water-soluble chelates of those nutrients can correct the deficit.[491] Sodium can be reduced by the addition of gypsum (calcium sulphate) as calcium adheres to clay more tightly than does sodium causing sodium to be pushed into the soil water solution where it can be washed out by an abundance of water.[492][493]

#### Base saturation percentage[edit]

There are acid-forming cations (e.g. hydrogen, aluminium, iron) and there are base-forming cations (e.g. calcium, magnesium, sodium). The fraction of the negatively-charged soil colloid exchange sites (CEC) that are occupied by base-forming cations is called base saturation. If a soil has a CEC of 20 meq and 5 meq are aluminium and hydrogen cations (acid-forming), the remainder of positions on the colloids (20-5 = 15 meq) are assumed occupied by base-forming cations, so that the base saturation is 15/20 x 100% = 75% (the compliment 25% is assumed acid-forming cations or protons). Base saturation is almost in direct proportion to pH (it increases with increasing pH).[494] It is of use in calculating the amount of lime needed to neutralise an acid soil (lime requirement). The amount of lime needed to neutralize a soil must take account of the amount of acid forming ions on the colloids (exchangeable acidity), not just those in the soil water solution (free acidity).[495] The addition of enough lime to neutralize the soil water solution will be insufficient to change the pH, as the acid forming cations stored on the soil colloids will tend to restore the original pH condition as they are pushed off those colloids by the calcium of the added lime.[496]

### Buffering[edit]

The resistance of soil to change in pH, as a result of the addition of acid or basic material, is a measure of the buffering capacity of a soil and (for a particular soil type) increases as the CEC increases. Hence, pure sand has almost no buffering ability, while soils high in colloids (whether mineral or organic) have high buffering capacity.[497] Buffering occurs by cation exchange and neutralisation. However, colloids are not the only regulators of soil pH. The role of carbonates should be underlined, too.[498] More generally, according to pH levels, several buffer systems take precedence over each other, from calcium carbonate buffer range to iron buffer range.[499]

The addition of a small amount of highly basic aqueous ammonia to a soil will cause the ammonium to displace hydrogen ions from the colloids, and the end product is water and colloidally fixed ammonium, but little permanent change overall in soil pH.

The addition of a small amount of lime, Ca(OH)2, will displace hydrogen ions from the soil colloids, causing the fixation of calcium to colloids and the evolution of CO2 and water, with little permanent change in soil pH.

The above are examples of the buffering of soil pH. The general principal is that an increase in a particular cation in the soil water solution will cause that cation to be fixed to colloids (buffered) and a decrease in solution of that cation will cause it to be withdrawn from the colloid and moved into solution (buffered). The degree of buffering is often related to the CEC of the soil; the greater the CEC, the greater the buffering capacity of the soil.[500]

## Nutrients[edit]

Seventeen elements or nutrients are essential for plant growth and reproduction. They are carbon C, hydrogen H, oxygen O, nitrogen N, phosphorus P, potassium K, sulfur S, calcium Ca, magnesium Mg, iron Fe, boron B, manganese Mn, copper Cu, zinc Zn, molybdenum Mo, nickel Ni and chlorine Cl.[501][502][503] Nutrients required for plants to complete their life cycle are considered essential nutrients. Nutrients that enhance the growth of plants but are not necessary to complete the plant's life cycle are considered non-essential. With the exception of carbon, hydrogen and oxygen, which are supplied by carbon dioxide and water, and nitrogen, provided through nitrogen fixation,[503] the nutrients derive originally from the mineral component of the soil. The Law of the Minimum expresses that when the available form of a nutrient is not in enough proportion in the soil solution, then other nutrients cannot be taken up at an optimum rate by a plant.[504] A particular nutrient ratio of the soil solution is thus mandatory for optimizing plant growth, a value which might differ from nutrient ratios calculated from plant composition.[505]

Plant uptake of nutrients can only proceed when they are present in a plant-available form. In most situations, nutrients are absorbed in an ionic form from (or together with) soil water. Although minerals are the origin of most nutrients, and the bulk of most nutrient elements in the soil is held in crystalline form within primary and secondary minerals, they weather too slowly to support rapid plant growth. For example, the application of finely ground minerals, feldspar and apatite, to soil seldom provides the necessary amounts of potassium and phosphorus at a rate sufficient for good plant growth, as most of the nutrients remain bound in the crystals of those minerals.[506]

The nutrients adsorbed onto the surfaces of clay colloids and soil organic matter provide a more accessible reservoir of many plant nutrients (e.g. K, Ca, Mg, P, Zn). As plants absorb the nutrients from the soil water, the soluble pool is replenished from the surface-bound pool. The decomposition of soil organic matter by microorganisms is another mechanism whereby the soluble pool of nutrients is replenished – this is important for the supply of plant-available N, S, P, and B from soil.[507]

Gram for gram, the capacity of humus to hold nutrients and water is far greater than that of clay minerals, most of the soil cation exchange capacity arising from charged carboxylic groups on organic matter.[508] However, despite the great capacity of humus to retain water once water-soaked, its high hydrophobicity decreases its wettability.[509] All in all, small amounts of humus may remarkably increase the soil's capacity to promote plant growth.[510][507]

Plant nutrients, their chemical symbols, and the ionic forms common in soils and available for plant uptake[511]
Element | Symbol | Ion or molecule
--- | --- | ---
Carbon | C | CO2 (mostly through leaves)
Hydrogen | H | H+, HOH (water)
Oxygen | O | O2−, OH −, CO32−, SO42−, CO2
Phosphorus | P | H2PO4 −, HPO42− (phosphates)
Potassium | K | K+
Nitrogen | N | NH4+, NO3 − (ammonium, nitrate)
Sulfur | S | SO42−
Calcium | Ca | Ca2+
Iron | Fe | Fe2+, Fe3+ (ferrous, ferric)
Magnesium | Mg | Mg2+
Boron | B | H3BO3, H2BO3 −, B(OH)4 −
Manganese | Mn | Mn2+
Copper | Cu | Cu2+
Zinc | Zn | Zn2+
Molybdenum | Mo | MoO42− (molybdate)
Chlorine | Cl | Cl − (chloride)

### Uptake processes[edit]

Nutrients in the soil are taken up by the plant through its roots, and in particular its root hairs. To be taken up by a plant, a nutrient element must be located near the root surface; however, the supply of nutrients in contact with the root is rapidly depleted within a distance of ca. 2 mm.[512] There are three basic mechanisms whereby nutrient ions dissolved in the soil solution are brought into contact with plant roots:

1. Mass flow of water
2. Diffusion within water
3. Interception by root growth

All three mechanisms operate simultaneously, but one mechanism or another may be most important for a particular nutrient.[513] For example, in the case of calcium, which is generally plentiful in the soil solution, except when aluminium over competes calcium on cation exchange sites in very acid soils (pH less than 4),[514] mass flow alone can usually bring sufficient amounts to the root surface. However, in the case of phosphorus, diffusion is needed to supplement mass flow. For the most part, nutrient ions must travel some distance in the soil solution to reach the root surface. This movement can take place by mass flow, as when dissolved nutrients are carried along with the soil water flowing toward a root that is actively drawing water from the soil. In this type of movement, the nutrient ions are somewhat analogous to leaves floating down a stream. In addition, nutrient ions continually move by diffusion from areas of greater concentration toward the nutrient-depleted areas of lower concentration around the root surface. That process is due to random motion, also called Brownian motion, of molecules within a gradient of decreasing concentration.[515] By this means, plants can continue to take up nutrients even at night, when water is only slowly absorbed into the roots as transpiration has almost stopped following stomatal closure. Finally, root interception comes into play as roots continually grow into new, undepleted soil. By this way roots are also able to absorb nanomaterials such as nanoparticulate organic matter.[516]

Estimated relative importance of mass flow, diffusion and root interception as mechanisms in supplying plant nutrients to corn plant roots in soils[517]
Nutrient | Approximate percentage supplied by:
--- | ---
Mass flow | Root interception | Diffusion
Nitrogen | 98.8 | 1.2 | 0
Phosphorus | 6.3 | 2.8 | 90.9
Potassium | 20.0 | 2.3 | 77.7
Calcium | 71.4 | 28.6 | 0
Sulfur | 95.0 | 5.0 | 0
Molybdenum | 95.2 | 4.8 | 0

In the above table, phosphorus and potassium nutrients move more by diffusion than they do by mass flow in the soil water solution, as they are rapidly taken up by the roots creating a concentration of almost zero near the roots (the plants cannot transpire enough water to draw more of those nutrients near the roots). The very steep concentration gradient is of greater influence in the movement of those ions than is the movement of those by mass flow.[518] The movement by mass flow requires the transpiration of water from the plant causing water and solution ions to also move toward the roots.[519] Movement by root interception is slowest as the plants must extend their roots.[520]

Plants move ions out of their roots in an effort to move nutrients in from the soil, an exchange process which occurs in the root apoplast.[521] Hydrogen H+ is exchanged for other cations, and carbonate (HCO3−) and hydroxide (OH−) anions are exchanged for nutrient anions.[522] As plant roots remove nutrients from the soil water solution, they are replenished as other ions move off of clay and humus (by ion exchange or desorption), are added from the weathering of soil minerals, and are released by the decomposition of soil organic matter. However, the rate at which plant roots remove nutrients may not cope with the rate at which they are replenished in the soil solution, stemming in nutrient limitation to plant growth.[523] Plants derive a large proportion of their anion nutrients from decomposing organic matter, which typically holds about 95 percent of the soil nitrogen, 5 to 60 percent of the soil phosphorus and about 80 percent of the soil sulfur. Where crops are produced, the replenishment of nutrients in the soil must usually be augmented by the addition of fertilizer or organic matter.[517]

Because nutrient uptake is an active metabolic process, conditions that inhibit root metabolism may also inhibit nutrient uptake.[524] Examples of such conditions include waterlogging or soil compaction resulting in poor soil aeration, excessively high or low soil temperatures, and above-ground conditions that result in low translocation of sugars to plant roots.[525]

### Carbon[edit]

Measuring soil respiration in the field using an SRS2000 system.

Plants obtain their carbon from atmospheric carbon dioxide through photosynthetic carboxylation, to which must be added the uptake of dissolved carbon from the soil solution[526] and carbon transfer through mycorrhizal networks.[527] About 45% of a plant's dry mass is carbon; plant residues typically have a carbon to nitrogen ratio (C/N) of between 13:1 and 100:1. As the soil organic material is digested by micro-organisms and saprophagous soil fauna, the C/N decreases as the carbonaceous material is metabolized and carbon dioxide (CO2) is released as a byproduct which then finds its way out of the soil and into the atmosphere. Nitrogen turnover (mostly involved in protein turnover) is lesser than that of carbon (mostly involved in respiration) in the living, then dead matter of decomposers, which are always richer in nitrogen than plant litter, and so it builds up in the soil.[528] Normal CO2 concentration in the atmosphere is 0.03%, this can be the factor limiting plant growth. In a field of maize on a still day during high light conditions in the growing season, the CO2 concentration drops very low, but under such conditions the crop could use up to 20 times the normal concentration. The respiration of CO2 by soil micro-organisms decomposing soil organic matter and the CO2 respired by roots contribute an important amount of CO2 to the photosynthesising plants, to which must be added the CO2 respired by aboveground plant tissues.[529] Root-respired CO2 can be accumulated overnight within hollow stems of plants, to be further used for photosynthesis during the day.[530] Within the soil, CO2 concentration is 10 to 100 times that of atmospheric levels but may rise to toxic levels if the soil porosity is low or if diffusion is impeded by flooding.[531][501][532]

### Nitrogen[edit]

Generalization of percent soil nitrogen by soil order

Nitrogen is the most critical element obtained by plants from the soil, to the exception of moist tropical forests where phosphorus is the limiting soil nutrient,[533] and nitrogen deficiency often limits plant growth.[534] Plants can use the nitrogen as either the ammonium cation (NH4+) or the anion nitrate (NO3−). Plants are commonly classified as ammonium or nitrate plants according to their preferential nitrogen nutrition.[535] Usually, most of the nitrogen in soil is bound within organic compounds that make up the soil organic matter, and must be mineralized to the ammonium or nitrate form before it can be taken up by most plants. However, symbiosis with mycorrhizal fungi allow plants to get access to the organic nitrogen pool where and when mineral forms of nitrogen are poorly available.[536] The total nitrogen content depends largely on the soil organic matter content, which in turn depends on texture, climate, vegetation, topography, age and soil management.[537] Soil nitrogen typically decreases by 0.2 to 0.3% for every temperature increase by 10 °C. Usually, grassland soils contain more soil nitrogen than forest soils, because of a higher turnover rate of grassland organic matter.[538] Cultivation decreases soil nitrogen by exposing soil organic matter to decomposition by microorganisms,[539] most losses being caused by denitrification,[540] and soils under no-tillage maintain more soil nitrogen than tilled soils.[541]

Some micro-organisms are able to metabolise organic matter and release ammonium in a process called mineralisation. Others, called nitrifiers, take free ammonium or nitrite as an intermediary step in the process of nitrification, and oxidise it to nitrate. Nitrogen-fixing bacteria are capable of metabolising N2 into the form of ammonia or related nitrogenous compounds in a process called nitrogen fixation. Both ammonium and nitrate can be immobilized by their incorporation into microbial living cells, where it is temporarily sequestered in the form of amino acids and proteins. Nitrate may be lost from the soil to the atmosphere when bacteria metabolise it to the gases NH3, N2 and N2O, a process called denitrification. Nitrogen may also be leached from the vadose zone if in the form of nitrate, acting as a pollutant if it reaches the water table or flows over land, more especially in agricultural soils under high use of nutrient fertilizers.[542] Ammonium may also be sequestered in 2:1 clay minerals.[543] A small amount of nitrogen is added to soil by rainfall, to the exception of wide areas of North America and West Europe where the excess use of nitrogen fertilizers and manure has caused atmospheric pollution by ammonia emission, stemming in soil acidification and eutrophication of soils and aquatic ecosystems.[544][545][507][546][547][548]

#### Gains[edit]

In the process of mineralisation, microbes feed on organic matter, releasing ammonia (NH3), ammonium (NH4+), nitrate (NO3-) and other nutrients. As long as the carbon to nitrogen ratio (C/N) of fresh residues in the soil is above 30:1, nitrogen will be in short supply for the nitrogen-rich microbal biomass (nitrogen deficiency), and other bacteria will uptake ammonium and to a lesser extent nitrate and incorporate them into their cells in the immobilization process.[549] In that form the nitrogen is said to be immobilised. Later, when such bacteria die, they too are mineralised and some of the nitrogen is released as ammonium and nitrate. Predation of bacteria by soil fauna, in particular protozoa and nematodes, play a decisive role in the return of immobilized nitrogen to mineral forms.[550] If the C/N of fresh residues is less than 15, mineral nitrogen is freed to the soil and directly available to plants.[551] Bacteria may on average add 25 pounds (11 kg) nitrogen per acre, and in an unfertilised field, this is the most important source of usable nitrogen. In a soil with 5% organic matter perhaps 2 to 5% of that is released to the soil by such decomposition. It occurs fastest in warm, moist, well aerated soil.[552] The mineralisation of 3% of the organic material of a soil that is 4% organic matter overall, would release 120 pounds (54 kg) of nitrogen as ammonium per acre.[553]

Carbon/Nitrogen Ratio of Various Organic Materials[554]
Organic Material | C:N Ratio
--- | ---
Alfalfa | 13
Bacteria | 4
Clover, green sweet | 16
Clover, mature sweet | 23
Fungi | 9
Forest litter | 30
Humus in warm cultivated soils | 11
Legume-grass hay | 25
Legumes (alfalfa or clover), mature | 20
Manure, cow | 18
Manure, horse | 16–45
Manure, human | 10
Oat straw | 80
Straw, cornstalks | 90
Sawdust | 250

In nitrogen fixation, rhizobium bacteria convert N2 to ammonia (NH3), which is rapidly converted to amino acids, parts of which are used by the rhizobia for the synthesis of their own biomass proteins, while other parts are transported to the xylem of the host plant.[555] Rhizobia share a symbiotic relationship with host plants, since rhizobia supply the host with nitrogen and the host provides rhizobia with other nutrients and a safe environment. It is estimated that such symbiotic bacteria in the root nodules of legumes add 45 to 250 pounds of nitrogen per acre per year, which may be sufficient for the crop. Other, free-living nitrogen-fixing diazotroph bacteria and archaea live independently in the soil and release mineral forms of nitrogen when their dead bodies are converted by way of mineralization.[556]

Some amount of usable nitrogen is fixed by lightning as nitric oxide (NO) and nitrogen dioxide (NO2−).[557] Nitrogen dioxide is soluble in water to form nitric acid (HNO3) dissociating in H+ and NO3−. Ammonia, NH3, previously emitted from the soil, may fall with precipitation as nitric acid at a rate of about five pounds nitrogen per acre per year.[558]

#### Sequestration[edit]

When bacteria feed on soluble forms of nitrogen (ammonium and nitrate), they temporarily sequester that nitrogen in their bodies in a process called immobilization. At a later time when those bacteria die, their nitrogen may be released as ammonium by the process of mineralization, sped up by predatory fauna.[559]

Protein material is easily broken down, but the rate of its decomposition is slowed by its attachment to the crystalline structure of clay and when trapped between the clay layers[560] or attached to rough clay surfaces.[561] The layers are small enough that bacteria cannot enter.[562] Some organisms can exude extracellular enzymes that can act on the sequestered proteins. However, those enzymes too may be trapped on the clay crystals, resulting in a complex interaction between proteins, microbial enzymes and mineral surfaces.[563]

Ammonium fixation occurs mainly between the layers of 2:1 type clay minerals such as illite, vermiculite or montmorillonite, together with ions of similar ionic radius and low hydration energy such as potassium, but a small proportion of ammonium is also fixed in the silt fraction.[564] Only a small fraction of soil nitrogen is held this way.[413]

#### Losses[edit]

Usable nitrogen may be lost from soils when it is in the form of nitrate, as it is easily leached, contrary to ammonium which is easily fixed.[565] Further losses of nitrogen occur by denitrification, the process whereby soil bacteria convert nitrate (NO3−) to nitrogen gas, N2 or N2O. This occurs when poor soil aeration limits free oxygen, forcing bacteria to use the oxygen in nitrate for their respiratory process. Denitrification increases when oxidisable organic material is available, as in organic farming[565] and when soils are warm and slightly acidic, as currently happening in tropical areas.[566] Denitrification may vary throughout a soil as the aeration varies from place to place.[567] Denitrification may cause the loss of 10 to 20 percent of the available nitrates within a day and when conditions are favourable to that process, losses of up to 60 percent of nitrate applied as fertiliser may occur.[568]

Ammonia volatilisation occurs when ammonium reacts chemically with an alkaline soil, converting NH4+ to NH3.[569] The application of ammonium fertiliser to such a field can result in volatilisation losses of as much as 30 percent.[570]

All kinds of nitrogen losses, whether by leaching or volatilization, are responsible for a large part of aquifer pollution[571] and air pollution, with concomitant effects on soil acidification and eutrophication,[572] a novel combination of environmental threats (acidity and excess nitrogen) to which extant organisms are badly adapted, causing severe biodiversity losses in natural ecosystems.[573]

### Phosphorus[edit]

After nitrogen, phosphorus is probably the element most likely to be deficient in soils, although it often turns to be the most deficient in tropical soils where the mineral pool is depleted under intense leaching and mineral weathering while, contrary to nitrogen, phosphorus reserves cannot be replenished from other sources.[574] The soil mineral apatite is the most common mineral source of phosphorus, from which it can be extracted by microbial and root exudates,[575][576] with an important contribution of arbuscular mycorrhizal fungi.[577] The most common form of organic phosphate is phytate, the principal storage form of phosphorus in many plant tissues. While there is on average 1000 lb per acre (1120 kg per hectare) of phosphorus in the soil, it is generally in the form of orthophosphate with low solubility, except when linked to ammonium or calcium, hence the use of diammonium phosphate or monocalcium phosphate as fertilizers.[578] Total phosphorus is about 0.1 percent by weight of the soil, but only one percent of that is directly available to plants. Of the part available, more than half comes from the mineralisation of organic matter. Agricultural fields may need to be fertilised to make up for the phosphorus that has been removed in the crop.[425]

When phosphorus does form solubilised ions of H2PO4−, if not taken up by plant roots they rapidly form insoluble phosphates of calcium or hydrous oxides of iron and aluminum. Phosphorus is largely immobile in the soil and is not leached but actually builds up in the surface layer if not cropped. The application of soluble fertilisers to soils may result in zinc deficiencies as zinc phosphates form, but soil pH levels, partly depending on the form of phosphorus in the fertiliser, strongly interact with this effect, in some cases resulting in increased zinc availability.[579] Lack of phosphorus may interfere with the normal opening of the plant leaf stomata, decreased stomatal conductance resulting in decreased photosynthesis and respiration rates[580] while decreased transpiration increases plant temperature.[581] Phosphorus is most available when soil pH is 6.5 in mineral soils and 5.5 in organic soils.[570]

### Potassium[edit]

The amount of potassium in a soil may be as much as 80,000 lb per acre-foot, of which only 150 lb is available for plant growth. Common mineral sources of potassium are the mica biotite and potassium feldspar, KAlSi3O8. Rhizosphere bacteria, also called rhizobacteria, contribute through the production of organic acids to its solubilization.[582] When solubilised, half will be held as exchangeable cations on clay while the other half is in the soil water solution. Potassium fixation often occurs when soils dry and the potassium is bonded between layers of illite clay. Under certain conditions, dependent on the soil texture, intensity of drying, and initial amount of exchangeable potassium, the fixed percentage may be as much as 90 percent within ten minutes. Potassium may be leached from soils low in clay.[583][584]

### Calcium[edit]

Calcium is one percent by weight of soils and is generally available but may be low as it is soluble and can be leached. It is thus low in sandy and heavily leached soil or strongly acidic mineral soil. Calcium is supplied to the plant in the form of exchangeable ions and moderately soluble minerals. Calcium is more available on the soil colloids than is potassium because the common mineral calcite, CaCO3, is more soluble than potassium-bearing minerals.[585]

### Magnesium[edit]

Magnesium is one of the dominant exchangeable cations in most soils (as are calcium and potassium). Primary minerals that weather to release magnesium include hornblende, biotite and vermiculite. Soil magnesium concentrations are generally sufficient for optimal plant growth, but highly weathered and sandy soils may be magnesium deficient due to leaching by heavy precipitation.[507][586]

### Sulfur[edit]

Most sulfur is made available to plants, like phosphorus, by its release from decomposing organic matter.[586] Deficiencies may exist in some soils (especially sandy soils) and if cropped, sulfur needs to be added. The application of large quantities of nitrogen to fields that have marginal amounts of sulfur may cause sulfur deficiency in the rapidly growing plants by the plant's growth outpacing the supply of sulfur. A 15-ton crop of onions uses up to 19 lb of sulfur and 4 tons of alfalfa uses 15 lb per acre. Sulfur abundance varies with depth. In a sample of soils in Ohio, United States, the sulfur abundance varied with depths, 0–6 inches, 6–12 inches, 12–18 inches, 18–24 inches in the amounts: 1056, 830, 686, 528 lb per acre respectively.[587]

### Micronutrients[edit]

The micronutrients essential in plant life, in their order of importance, include iron,[588] manganese,[589] zinc,[590] copper,[591] boron,[592] chlorine[593] and molybdenum.[594] The term refers to plants' needs, not to their abundance in soil. They are required in very small amounts but are essential to plant health in that most are required parts of some enzyme system which speeds up plants' metabolisms. They are generally available in the mineral component of the soil, but the heavy application of phosphates can cause a deficiency in zinc and iron by the formation of insoluble zinc and iron phosphates. Iron deficiency may also result from excessive amounts of heavy metals or calcium minerals (lime) in the soil. Excess amounts of soluble boron, molybdenum and chloride are toxic.[595][596]

### Non-essential nutrients[edit]

Nutrients which enhance the health but whose deficiency does not stop the life cycle of plants include: cobalt, strontium, vanadium, silicon and nickel.[597] As their importance are evaluated they may be added to the list of essential plant nutrients.

## Soil organic matter[edit]

Soil organic matter is made up of organic compounds and includes plant, animal and microbial material, both living and dead. A typical soil has a biomass composition of 70% microorganisms, 22% macrofauna, and 8% roots. The living component of an acre of soil may include 900 lb of earthworms, 2400 lb of fungi, 1500 lb of bacteria, 133 lb of protozoa and 890 lb of arthropods and algae.[598]

A small part of the organic matter consists of the living cells such as bacteria, molds, and actinomycetes that work to break down the dead organic matter. Were it not for the action of these micro-organisms, the entire carbon dioxide part of the atmosphere would be sequestered as organic matter in the soil.

Chemically, organic matter is classed as follows:

1. Polysaccharides
   1. cellulose
   2. hemicellulose
   3. starch
   4. pectin
2. Lignins
3. Proteins

Most living things in soils, including plants, insects, bacteria, and fungi, are dependent on organic matter for nutrients and/or energy. Soils have organic compounds in varying degrees of decomposition which rate is dependent on the temperature, soil moisture, and aeration. Bacteria and fungi feed on the raw organic matter, which are fed upon by amoebas, which in turn are fed upon by nematodes and arthropods. Organic matter holds soils open, allowing the infiltration of air and water, and may hold as much as twice its weight in water. Many soils, including desert and rocky-gravel soils, have little or no organic matter. Soils that are all organic matter, such as peat (histosols), are infertile.[599] In its earliest stage of decomposition, the original organic material is often called raw organic matter. The final stage of decomposition is called humus.

In grassland, much of the organic matter added to the soil is from the deep, fibrous, grass root systems. By contrast, tree leaves falling on the forest floor are the principal source of soil organic matter in the forest. Another difference is the frequent occurrence in the grasslands of fires that destroy large amounts of aboveground material but stimulate even greater contributions from roots. Also, the much greater acidity under any forests inhibits the action of certain soil organisms that otherwise would mix much of the surface litter into the mineral soil. As a result, the soils under grasslands generally develop a thicker A horizon with a deeper distribution of organic matter than in comparable soils under forests, which characteristically store most of their organic matter in the forest floor (O horizon) and thin A horizon.

### Humus[edit]

Humus refers to organic matter that has been decomposed by soil flora and fauna to the point where it is resistant to further breakdown. Humus usually constitutes only five percent of the soil or less by volume, but it is an essential source of nutrients and adds important textural qualities crucial to soil health and plant growth. Humus also hold bits of undecomposed organic matter which feed arthropods and worms which further improve the soil. The end product, humus, is soluble in water and forms a weak acid that can attack silicate minerals.[600] Humus is a colloid with a high cation and anion exchange capacity that on a dry weight basis is many times greater than that of clay colloids. It also acts as a buffer, like clay, against changes in pH and soil moisture.

Humic acids and fulvic acids, which begin as raw organic matter, are important constituents of humus. After the death of plants and animals, microbes begin to feed on the residues, resulting finally in the formation of humus. With decomposition, there is a reduction of water-soluble constituents, cellulose and hemicellulose, and nutrients such as nitrogen, phosphorus, and sulfur. As the residues break down, only stable molecules made of aromatic carbon rings, oxygen and hydrogen remain in the form of humin, lignin and lignin complexes collectively called humus. While the structure of humus has few nutrients, it is able to attract and hold cation and anion nutrients by weak bonds that can be released into the soil solution in response to changes in soil pH.

Lignin is resistant to breakdown and accumulates within the soil. It also reacts with amino acids, which further increases its resistance to decomposition, including enzymatic decomposition by microbes. Fats and waxes from plant matter have some resistance to decomposition and persist in soils for a while. Clay soils often have higher organic contents that persist longer than soils without clay as the organic molecules adhere to and are stabilised by the clay. Proteins normally decompose readily, but when bound to clay particles, they become more resistant to decomposition. Clay particles also absorb the enzymes exuded by microbes which would normally break down proteins. The addition of organic matter to clay soils can render that organic matter and any added nutrients inaccessible to plants and microbes for many years. High soil tannin (polyphenol) content can cause nitrogen to be sequestered in proteins or cause nitrogen immobilisation.[601][602]

Humus formation is a process dependent on the amount of plant material added each year and the type of base soil. Both are affected by climate and the type of organisms present. Soils with humus can vary in nitrogen content but typically have 3 to 6 percent nitrogen. Raw organic matter, as a reserve of nitrogen and phosphorus, is a vital component affecting soil fertility.[599] Humus also absorbs water, and expands and shrinks between dry and wet states, increasing soil porosity. Humus is less stable than the soil's mineral constituents, as it is reduced by microbial decomposition, and over time its concentration diminshes without the addition of new organic matter. However, humus may persist over centuries if not millennia.

### Climatological influence[edit]

The production, accumulation and degradation of organic matter are greatly dependent on climate. Temperature, soil moisture and topography are the major factors affecting the accumulation of organic matter in soils. Organic matter tends to accumulate under wet or cold conditions where decomposer activity is impeded by low temperature[603] or excess moisture which results in anaerobic conditions.[604] Conversely, excessive rain and high temperatures of tropical climates enables rapid decomposition of organic matter and leaching of plant nutrients; forest ecosystems on these soils rely on efficient recycling of nutrients and plant matter to maintain their productivity.[605] Excessive slope may encourage the erosion of the top layer of soil which holds most of the raw organic material that would otherwise eventually become humus.

### Plant residue[edit]

Typical types and percentages of plant residue components

Cellulose (45%)
Lignin (20%)
Hemicellulose (18%)
Protein (8%)
Sugars and starches (5%)
Fats and waxes (2%)

Cellulose and hemicellulose undergo fast decomposition by fungi and bacteria, with a half-life of 12–18 days in a temperate climate.[606] Brown rot fungi can decompose the cellulose and hemicellulose, leaving the lignin and phenolic compounds behind. Starch, which is an energy storage system for plants, undergoes fast decomposition by bacteria and fungi. Lignin consists of polymers composed of 500 to 600 units with a highly branched, amorphous structure. Lignin undergoes very slow decomposition, mainly by white rot fungi and actinomycetes; its half-life under temperate conditions is about six months.[606]

## Horizons[edit]

A horizontal layer of the soil, whose physical features, composition and age are distinct from those above and beneath, is referred to as a soil horizon. The naming of a horizon is based on the type of material of which it is composed. Those materials reflect the duration of specific processes of soil formation. They are labelled using a shorthand notation of letters and numbers[607] which describe the horizon in terms of its colour, size, texture, structure, consistency, root quantity, pH, voids, boundary characteristics and presence of nodules or concretions.[608] No soil profile has all the major horizons. Some may have only one horizon.

The exposure of parent material to favourable conditions produces mineral soils that are marginally suitable for plant growth. That growth often results in the accumulation of organic residues. The accumulated organic layer called the O horizon produces a more active soil due to the effect of the organisms that live within it. Organisms colonise and break down organic materials, making available nutrients upon which other plants and animals can live. After sufficient time, humus moves downward and is deposited in a distinctive organic surface layer called the A horizon.

## Classification[edit]

Soil is classified into categories in order to understand relationships between different soils and to determine the suitability of a soil in a particular region. One of the first classification systems was developed by Russian scientist Dokuchaev around 1880. It was modified a number of times by American and European researchers, and developed into the system commonly used until the 1960s. It was based on the idea that soils have a particular morphology based on the materials and factors that form them. In the 1960s, a different classification system began to emerge which focused on soil morphology instead of parental materials and soil-forming factors. Since then it has undergone further modifications. The World Reference Base for Soil Resources (WRB)[609] aims to establish an international reference base for soil classification.

### Systems[edit]

#### Australia[edit]

There are fourteen soil orders at the top level of the Australian Soil Classification. They are: Anthroposols, Organosols, Podosols, Vertosols, Hydrosols, Kurosols, Sodosols, Chromosols, Calcarosols, Ferrosols, Dermosols, Kandosols, Rudosols and Tenosols.

#### European Union[edit]

The EU's soil taxonomy is based on a new standard soil classification in the World Reference Base for Soil Resources produced by the UN's Food and Agriculture Organization.[610]

#### United States[edit]

A taxonomy is an arrangement in a systematic manner; the USDA soil taxonomy has six levels of classification. They are, from most general to specific: order, suborder, great group, subgroup, family and series. Soil properties that can be measured quantitatively are used in this classification system – they include: depth, moisture, temperature, texture, structure, cation exchange capacity, base saturation, clay mineralogy, organic matter content and salt content. There are 12 soil orders (the top hierarchical level) in soil taxonomy.[611][612]

## Uses[edit]

Soil is used in agriculture, where it serves as the anchor and primary nutrient base for plants. The types of soil and available moisture determine the species of plants that can be cultivated. However, as demonstrated by aeroponics, soil material is not an absolute essential for agriculture.

Soil material is also a critical component in the mining, construction and landscape development industries.[613] Soil serves as a foundation for most construction projects. The movement of massive volumes of soil can be involved in surface mining, road building and dam construction. Earth sheltering is the architectural practice of using soil for external thermal mass against building walls. Many building materials are soil based.

Soil resources are critical to the environment, as well as to food and fibre production, producing 98.8% of food consumed by humans.[614] Soil provides minerals and water to plants. Soil absorbs rainwater and releases it later, thus preventing floods and drought. Soil cleans water as it percolates through it. Soil is the habitat for many organisms: the major part of known and unknown biodiversity is in the soil, in the form of invertebrates (earthworms, woodlice, millipedes, centipedes, snails, slugs, mites, springtails, enchytraeids, nematodes, protists), bacteria, archaea, fungi and algae; and most organisms living above ground have part of them (plants) or spend part of their life cycle (insects) below-ground. Above-ground and below-ground biodiversities are tightly interconnected,[615][616] making soil protection of paramount importance for any restoration or conservation plan.

The biological component of soil is an extremely important carbon sink since about 57% of the biotic content is carbon. Even on desert crusts, cyanobacteria, lichens and mosses capture and sequester a significant amount of carbon by photosynthesis. Poor farming and grazing methods have degraded soils and released much of this sequestered carbon to the atmosphere. Restoring the world's soils could offset the effect of increases in greenhouse gas emissions and slow global warming, while improving crop yields and reducing water needs.[617][618][619]

Waste management often has a soil component. Septic drain fields treat septic tank effluent using aerobic soil processes. Landfills use soil for daily cover. Land application of waste water relies on soil biology to aerobically treat BOD.

Organic soils, especially peat, serve as a significant fuel resource; but wide areas of peat production, such as sphagnum bogs, are now protected because of patrimonial interest.

Geophagy is the practice of eating soil-like substances. Both animals and human cultures occasionally consume soil for medicinal, recreational, or religious purposes. It has been shown that some monkeys consume soil, together with their preferred food (tree foliage and fruits), in order to alleviate tannin toxicity.[620]

Soils filter and purify water and affect its chemistry. Rain water and pooled water from ponds, lakes and rivers percolate through the soil horizons and the upper rock strata, thus becoming groundwater. Pests (viruses) and pollutants, such as persistent organic pollutants (chlorinated pesticides, polychlorinated biphenyls), oils (hydrocarbons), heavy metals (lead, zinc, cadmium), and excess nutrients (nitrates, sulfates, phosphates) are filtered out by the soil.[621] Soil organisms metabolise them or immobilise them in their biomass and necromass,[622] thereby incorporating them into stable humus.[623] The physical integrity of soil is also a prerequisite for avoiding landslides in rugged landscapes.[624]

## Degradation[edit]

Land degradation[625] refers to a human-induced or natural process which impairs the capacity of land to function. Soils degradation involves the acidification, contamination, desertification, erosion or salination.

Soil acidification is beneficial in the case of alkaline soils, but it degrades land when it lowers crop productivity and increases soil vulnerability to contamination and erosion. Soils are often initially acid because their parent materials were acid and initially low in the basic cations (calcium, magnesium, potassium and sodium). Acidification occurs when these elements are leached from the soil profile by rainfall or by the harvesting of forest or agricultural crops. Soil acidification is accelerated by the use of acid-forming nitrogenous fertilizers and by the effects of acid precipitation.

Soil contamination at low levels is often within a soil's capacity to treat and assimilate waste material. Soil biota can treat waste by transforming it; soil colloids can adsorb the waste material. Many waste treatment processes rely on this treatment capacity. Exceeding treatment capacity can damage soil biota and limit soil function. Derelict soils occur where industrial contamination or other development activity damages the soil to such a degree that the land cannot be used safely or productively. Remediation of derelict soil uses principles of geology, physics, chemistry and biology to degrade, attenuate, isolate or remove soil contaminants to restore soil functions and values. Techniques include leaching, air sparging, chemical amendments, phytoremediation, bioremediation and natural degradation. An example of diffuse pollution with contaminants is the copper distribution in agricultural soils mainly due to fungicide applications in vineyards and other permanent crops.[626]

Desertification

Desertification is an environmental process of ecosystem degradation in arid and semi-arid regions, often caused by human activity. It is a common misconception that droughts cause desertification. Droughts are common in arid and semiarid lands. Well-managed lands can recover from drought when the rains return. Soil management tools include maintaining soil nutrient and organic matter levels, reduced tillage and increased cover. These practices help to control erosion and maintain productivity during periods when moisture is available. Continued land abuse during droughts, however, increases land degradation. Increased population and livestock pressure on marginal lands accelerates desertification.

Erosion control

Erosion of soil is caused by water, wind, ice, and movement in response to gravity. More than one kind of erosion can occur simultaneously. Erosion is distinguished from weathering, since erosion also transports eroded soil away from its place of origin (soil in transit may be described as sediment). Erosion is an intrinsic natural process, but in many places it is greatly increased by human activity, especially poor land use practices. These include agricultural activities which leave the soil bare during times of heavy rain or strong winds, overgrazing, deforestation, and improper construction activity. Improved management can limit erosion. Soil conservation techniques which are employed include changes of land use (such as replacing erosion-prone crops with grass or other soil-binding plants), changes to the timing or type of agricultural operations, terrace building, use of erosion-suppressing cover materials (including cover crops and other plants), limiting disturbance during construction, and avoiding construction during erosion-prone periods.

A serious and long-running water erosion problem occurs in China, on the middle reaches of the Yellow River and the upper reaches of the Yangtze River. From the Yellow River, over 1.6 billion tons of sediment flow each year into the ocean. The sediment originates primarily from water erosion (gully erosion) in the Loess Plateau region of northwest China.

Soil piping is a particular form of soil erosion that occurs below the soil surface. It causes levee and dam failure, as well as sink hole formation. Turbulent flow removes soil starting at the mouth of the seep flow and the subsoil erosion advances up-gradient.[627] The term sand boil is used to describe the appearance of the discharging end of an active soil pipe.[628]

Soil salination is the accumulation of free salts to such an extent that it leads to degradation of the agricultural value of soils and vegetation. Consequences include corrosion damage, reduced plant growth, erosion due to loss of plant cover and soil structure, and water quality problems due to sedimentation. Salination occurs due to a combination of natural and human-caused processes. Arid conditions favour salt accumulation. This is especially apparent when soil parent material is saline. Irrigation of arid lands is especially problematic.[629] All irrigation water has some level of salinity. Irrigation, especially when it involves leakage from canals and overirrigation in the field, often raises the underlying water table. Rapid salination occurs when the land surface is within the capillary fringe of saline groundwater. Soil salinity control involves watertable control and flushing with higher levels of applied water in combination with tile drainage or another form of subsurface drainage.[630][631]

## Reclamation[edit]

Soils which contain high levels of particular clays, such as smectites, are often very fertile. For example, the smectite-rich clays of Thailand's Central Plains are among the most productive in the world.

Many farmers in tropical areas, however, struggle to retain organic matter in the soils they work. In recent years, for example, productivity has declined in the low-clay soils of northern Thailand. Farmers initially responded by adding organic matter from termite mounds, but this was unsustainable in the long-term. Scientists experimented with adding bentonite, one of the smectite family of clays, to the soil. In field trials, conducted by scientists from the International Water Management Institute in cooperation with Khon Kaen University and local farmers, this had the effect of helping retain water and nutrients. Supplementing the farmer's usual practice with a single application of 200 kg bentonite per rai (6.26 rai = 1 hectare) resulted in an average yield increase of 73%. More work showed that applying bentonite to degraded sandy soils reduced the risk of crop failure during drought years.

In 2008, three years after the initial trials, IWMI scientists conducted a survey among 250 farmers in northeast Thailand, half of whom had applied bentonite to their fields. The average improvement for those using the clay addition was 18% higher than for non-clay users. Using the clay had enabled some farmers to switch to growing vegetables, which need more fertile soil. This helped to increase their income. The researchers estimated that 200 farmers in northeast Thailand and 400 in Cambodia had adopted the use of clays, and that a further 20,000 farmers were introduced to the new technique.[632]

If the soil is too high in clay, adding gypsum, washed river sand and organic matter will balance the composition. Adding organic matter (like ramial chipped wood for instance) to soil which is depleted in nutrients and too high in sand will boost its quality.[633]

## See also[edit]

- Acid sulfate soil
- Agrophysics
- Alkaline soil
- Biochar
- Crust
- Geoponic
- Factors affecting permeability of soils
- Index of soil-related articles
- Mineral matter in plants
- Mycorrhizal fungi and soil carbon storage
- Nitrogen cycle
- Red Mediterranean soil
- Saline soil
- Shrink-swell capacity
- Soil management
- Soil zoology
- World Soil Museum

| Wikiquote has quotations related to: Soil

| Wikimedia Commons has media related to Soils.

## References[edit]

Citations

1. ^ Chesworth, Ward, ed. (2008). Encyclopedia of soil science (PDF). Dordrecht, The Netherlands: Springer. ISBN 978-1-4020-3994-2. Archived (PDF) from the original on 5 September 2018. Retrieved 14 January 2019.
2. ^ "pedo-". Oxford English Dictionary (3rd ed.). Oxford University Press. September 2005. (Subscription or UK public library membership required.), from the ancient Greek πέδον "ground", "earth".
3. ^ Voroney, R. Paul & Heck, Richard J. (2007). "The soil habitat" (PDF). In Paul, Eldor A. (ed.). Soil microbiology, ecology and biochemistry (3rd ed.). Amsterdam: Elsevier. pp. 25–49. doi:10.1016/B978-0-08-047514-1.50006-8. ISBN 978-0-12-546807-7. Archived (PDF) from the original on 10 July 2018. Retrieved 15 January 2019.
4. ^ Danoff-Burg, James A. "The terrestrial influence: geology and soils". Earth Institute Center for Environmental Sustainability. New York: Columbia University Press. Retrieved 17 December 2017.
5. ^ Taylor, Sterling A. & Ashcroft, Gaylen L. (1972). Physical edaphology: the physics of irrigated and nonirrigated soils. San Francisco: W.H. Freeman. ISBN 978-0-7167-0818-6.
6. ^ McCarthy, David F. (2006). Essentials of soil mechanics and foundations: basic geotechnics (7th ed.). Upper Saddle River, New Jersey: Prentice Hall. ISBN 978-0-13-114560-3.
7. ^ a b Gilluly, James; Waters, Aaron Clement & Woodford, Alfred Oswald (1975). Principles of geology (4th ed.). San Francisco: W.H. Freeman. ISBN 978-0-7167-0269-6.
8. ^ Ponge, Jean-François (2015). "The soil as an ecosystem" (PDF). Biology and Fertility of Soils. 51 (6): 645–48. doi:10.1007/s00374-015-1016-1. Retrieved 17 December 2017.
9. ^ a b Yu, Charley; Kamboj, Sunita; Wang, Cheng & Cheng, Jing-Jy (2015). "Data collection handbook to support modeling impacts of radioactive material in soil and building structures" (PDF). Argonne National Laboratory. pp. 13–21. Archived (PDF) from the original on 4 August 2018. Retrieved 17 December 2017.
10. ^ a b Buol, Stanley W.; Southard, Randal J.; Graham, Robert C. & McDaniel, Paul A. (2011). Soil genesis and classification (7th ed.). Ames, Iowa: Wiley-Blackwell. ISBN 978-0-470-96060-8.
11. ^ Retallack, Gregory J.; Krinsley, David H; Fischer, Robert; Razink, Joshua J. & Langworthy, Kurt A. (2016). "Archean coastal-plain paleosols and life on land" (PDF). Gondwana Research. 40: 1–20. Bibcode:2016GondR..40....1R. doi:10.1016/j.gr.2016.08.003. Archived (PDF) from the original on 13 November 2018. Retrieved 15 January 2019.
12. ^ "Glossary of Terms in Soil Science". Agriculture and Agri-Food Canada. Archived from the original on 27 October 2018. Retrieved 15 January 2019.
13. ^ Amundson, Ronald. "Soil preservation and the future of pedology" (PDF). Faculty of Natural Resources. Songkhla, Thailand: Prince of Songkla University. Archived (PDF) from the original on 12 June 2018. Retrieved 15 January 2019.
14. ^ Küppers, Michael; Vincent, Jean-Baptiste. "Impacts and formation of regolith". Max Planck Institute for Solar System Research. Archived from the original on 4 August 2018. Retrieved 15 January 2019.
15. ^ "Soils overview provided by The Soil Science Society of America" (PDF). Retrieved 24 February 2019.
16. ^ Pouyat, Richard; Groffman, Peter; Yesilonis, Ian & Hernandez, Luis (2002). "Soil carbon pools and fluxes in urban ecosystems" (PDF). Environmental Pollution. 116 (Supplement 1): S107–S118. doi:10.1016/S0269-7491(01)00263-9. PMID 11833898. Retrieved 17 December 2017.
17. ^ a b Davidson, Eric A. & Janssens, Ivan A. (2006). "Temperature sensitivity of soil carbon decomposition and feedbacks to climate change" (PDF). Nature. 440 (9 March 2006): 165‒73. Bibcode:2006Natur.440..165D. doi:10.1038/nature04514. PMID 16525463. Retrieved 17 December 2017.
18. ^ Powlson, David (2005). "Climatology: will soil amplify climate change?". Nature. 433 (20 January 2005): 204‒05. Bibcode:2005Natur.433..204P. doi:10.1038/433204a. PMID 15662396.
19. ^ Bradford, Mark A.; Wieder, William R.; Bonan, Gordon B.; Fierer, Noah; Raymond, Peter A. & Crowther, Thomas W. (2016). "Managing uncertainty in soil carbon feedbacks to climate change" (PDF). Nature Climate Change. 6 (27 July 2016): 751–58. Bibcode:2016NatCC...6..751B. doi:10.1038/nclimate3071. Retrieved 17 December 2017.
20. ^ Dominati, Estelle; Patterson, Murray & Mackay, Alec (2010). "A framework for classifying and quantifying the natural capital and ecosystem services of soils" (PDF). Ecological Economics. 69 (9): 1858‒68. doi:10.1016/j.ecolecon.2010.05.002. Retrieved 17 December 2017.
21. ^ Dykhuizen, Daniel E. (1998). "Santa Rosalia revisited: why are there so many species of bacteria?" (PDF). Antonie van Leeuwenhoek. 73 (1): 25‒33. doi:10.1023/A:1000665216662. PMID 9602276. Retrieved 17 December 2017.
22. ^ Torsvik, Vigdis & Øvreås, Lise (2002). "Microbial diversity and function in soil: from genes to ecosystems". Current Opinion in Microbiology. 5 (3): 240‒45. doi:10.1016/S1369-5274(02)00324-7. PMID 12057676.
23. ^ Raynaud, Xavier & Nunan, Naoise (2014). "Spatial ecology of bacteria at the microscale in soil". PLOS ONE. 9 (1): e87217. Bibcode:2014PLoSO...987217R. doi:10.1371/journal.pone.0087217. PMC 3905020. PMID 24489873.
24. ^ Whitman, William B.; Coleman, David C. & Wiebe, William J. (1998). "Prokaryotes: the unseen majority". Proceedings of the National Academy of Sciences of the USA. 95 (12): 6578‒83. Bibcode:1998PNAS...95.6578W. doi:10.1073/pnas.95.12.6578. PMC 33863. PMID 9618454.
25. ^ Schlesinger, William H. & Andrews, Jeffrey A. (2000). "Soil respiration and the global carbon cycle" (PDF). Biogeochemistry. 48 (1): 7‒20. doi:10.1023/A:1006247623877. Retrieved 17 December 2017.
26. ^ Denmead, Owen Thomas & Shaw, Robert Harold (1962). "Availability of soil water to plants as affected by soil moisture content and meteorological conditions" (PDF). Agronomy Journal. 54 (5): 385‒90. doi:10.2134/agronj1962.00021962005400050005x. Retrieved 17 December 2017.
27. ^ House, Christopher H.; Bergmann, Ben A.; Stomp, Anne-Marie & Frederick, Douglas J. (1999). "Combining constructed wetlands and aquatic and soil filters for reclamation and reuse of water" (PDF). Ecological Engineering. 12 (1–2): 27–38. doi:10.1016/S0925-8574(98)00052-4. Retrieved 17 December 2017.
28. ^ Van Bruggen, Ariena H.C. & Semenov, Alexander M. (2000). "In search of biological indicators for soil health and disease suppression" (PDF). Applied Soil Ecology. 15 (1): 13–24. doi:10.1016/S0929-1393(00)00068-8. Retrieved 17 December 2017.
29. ^ "A citizen's guide to monitored natural attenuation" (PDF). Retrieved 17 December 2017.
30. ^ Linn, Daniel Myron; Doran, John W. (1984). "Effect of water-filled pore space on carbon dioxide and nitrous oxide production in tilled and nontilled soils" (PDF). Soil Science Society of America Journal. 48 (6): 1267–72. Bibcode:1984SSASJ..48.1267L. doi:10.2136/sssaj1984.03615995004800060013x. Retrieved 17 December 2017.
31. ^ Miller, Raymond W.; Donahue, Roy Luther (1990). Soils: an introduction to soils and plant growth. Upper Saddle River, New Jersey: Prentice Hall. ISBN 978-0-13-820226-2.
32. ^ Bot, Alexandra; Benites, José (2005). The importance of soil organic matter: key to drought-resistant soil and sustained food and production (PDF). Rome: Food and Agriculture Organization of the United Nations. ISBN 978-92-5-105366-9. Retrieved 17 December 2017.
33. ^ a b McClellan, Tai. "Soil composition". University of Hawai‘i – College of Tropical Agriculture and Human Resources. Retrieved 29 April 2018.
34. ^ "Arizona Master Gardener Manual". Cooperative Extension, College of Agriculture, University of Arizona. 9 November 2017. Archived from the original on 29 May 2016. Retrieved 17 December 2017.
35. ^ a b Vannier, Guy (1987). "The porosphere as an ecological medium emphasized in Professor Ghilarov's work on soil animal adaptations" (PDF). Biology and Fertility of Soils. 3 (1): 39–44. doi:10.1007/BF00260577. Retrieved 29 July 2018.
36. ^ Torbert, H. Allen & Wood, Wes (1992). "Effect of soil compaction and water-filled pore space on soil microbial activity and N losses" (PDF). Communications in Soil Science and Plant Analysis. 23 (11): 1321‒31. doi:10.1080/00103629209368668. Retrieved 17 December 2017.
37. ^ Simonson 1957, p. 17.
38. ^ a b c Bronick, Carol J. & Lal, Ratan (January 2005). "Soil structure and management: a review" (PDF). Geoderma. 124 (1/2): 3–22. Bibcode:2005Geode.124....3B. doi:10.1016/j.geoderma.2004.03.005. Retrieved 17 December 2017.
39. ^ "Soil and water". Food and Agriculture Organization of the United Nations. Retrieved 17 December 2017.
40. ^ Valentin, Christian; d'Herbès, Jean-Marc & Poesen, Jean (1999). "Soil and water components of banded vegetation patterns" (PDF). Catena. 37 (1): 1‒24. doi:10.1016/S0341-8162(99)00053-3. Retrieved 17 December 2017.
41. ^ Barber, Stanley A. (1995). "Chemistry of soil-nutrient associations". In Barber, Stanley A. (ed.). Soil nutrient bioavailability: a mechanistic approach (2nd ed.). New York: John Wiley & Sons. pp. 9–48. ISBN 978-0-471-58747-7.
42. ^ "Soil colloids: properties, nature, types and significance" (PDF). Tamil Nadu Agricultural University. Retrieved 17 December 2017.
43. ^ a b "Cation exchange capacity in soils, simplified". Retrieved 17 December 2017.
44. ^ Miller, Jarrod O. "Soil pH affects nutrient availability" (PDF). University of Maryland. Retrieved 17 December 2017.
45. ^ Goulding, Keith W.T.; Bailey, Neal J.; Bradbury, Nicola J.; Hargreaves, Patrick; Howe, MT; Murphy, Daniel V.; Poulton, Paul R. & Willison, Toby W. (1998). "Nitrogen deposition and its contribution to nitrogen cycling and associated soil processes". New Phytologist. 139 (1): 49‒58. doi:10.1046/j.1469-8137.1998.00182.x.
46. ^ Kononova, M.M. (2013). Soil organic matter: its nature, its role in soil formation and in soil fertility (2nd ed.). Amsterdam: Elsevier. ISBN 978-1-4831-8568-2.
47. ^ Hillel, Daniel (1993). Out of the Earth: civilization and the life of the soil. Berkeley: University of California Press. ISBN 978-0-520-08080-5.
48. ^ a b Donahue, Miller & Shickluna 1977, p. 4.
49. ^ Kellogg 1957, p. 1.
50. ^ Ibn al-'Awwam (1864). Le livre de l'agriculture, traduit de l'arabe par Jean Jacques Clément-Mullet (PDF). Filāḥah.French (in French). Paris: Librairie A. Franck. Retrieved 17 December 2017.
51. ^ Jelinek, Lawrence J. (1982). Harvest empire: a history of California agriculture. San Francisco: Boyd and Fraser. ISBN 978-0-87835-131-2.
52. ^ de Serres, Olivier (1600). Le Théâtre d'Agriculture et mesnage des champs (in French). Paris: Jamet Métayer. Retrieved 17 December 2017.
53. ^ Virto, Iñigo; Imaz, María José; Fernández-Ugalde, Oihane; Gartzia-Bengoetxea, Nahia; Enrique, Alberto & Bescansa, Paloma (2015). "Soil degradation and soil quality in western Europe: current situation and future perspectives". Sustainability. 7 (1): 313–65. doi:10.3390/su7010313.
54. ^ Van der Ploeg, Rienk R.; Schweigert, Peter & Bachmann, Joerg (2001). "Use and misuse of nitrogen in agriculture: the German story". Scientific World Journal. 1 (S2): 737–44. doi:10.1100/tsw.2001.263. PMC 6084271. PMID 12805882.
55. ^ a b c d e Brady, Nyle C. (1984). The nature and properties of soils (9th ed.). New York: Collier Macmillan. ISBN 978-0-02-313340-4.
56. ^ Kellogg 1957, p. 3.
57. ^ Kellogg 1957, p. 2.
58. ^ de Lavoisier, Antoine-Laurent (1777). "Mémoire sur la combustion en général" (PDF). Mémoires de l'Académie Royale des Sciences (in French). Retrieved 17 December 2017.
59. ^ Boussingault, Jean-Baptiste (1860–1874). Agronomie, chimie agricole et physiologie, volumes 1–5 (PDF) (in French). Paris: Mallet-Bachelier. Retrieved 17 December 2017.
60. ^ von Liebig, Justus (1840). Organic chemistry in its applications to agriculture and physiology (PDF). London: Taylor and Walton. Retrieved 17 December 2017.
61. ^ Way, J. Thomas (1849). "On the composition and money value of the different varieties of guano". Journal of the Royal Agricultural Society of England. 10: 196–230. Retrieved 17 December 2017.
62. ^ a b Kellogg 1957, p. 4.
63. ^ Tandon, Hari L.S. "A short history of fertilisers". Fertiliser Development and Consultation Organisation. Retrieved 17 December 2017.
64. ^ Way, J. Thomas (1852). "On the power of soils to absorb manure". Journal of the Royal Agricultural Society of England. 13: 123–43. Retrieved 17 December 2017.
65. ^ Warington, Robert (1878). Note on the appearance of nitrous acid during the evaporation of water: a report of experiments made in the Rothamsted laboratory. London: Harrison and Sons.
66. ^ Winogradsky, Sergei (1890). "Sur les organismes de la nitrification" (PDF). Comptes Rendus Hebdomadaires des Séances de l'Académie des Sciences (in French). 110 (1): 1013–16. Retrieved 17 December 2017.
67. ^ Kellogg 1957, pp. 1–4.
68. ^ Hilgard, Eugene W. (1921). Soils: their formation, properties, composition, and relations to climate and plant growth in the humid and arid regions. London: The Macmillan Company. Retrieved 17 December 2017.
69. ^ Fallou, Friedrich Albert (1857). Anfangsgründe der Bodenkunde (PDF) (in German). Dresden: G. Schönfeld´s Buchhandlung. Archived from the original (PDF) on 15 December 2018. Retrieved 15 December 2018.
70. ^ Glinka, Konstantin Dmitrievich (1914). Die Typen der Bodenbildung: ihre Klassifikation und geographische Verbreitung (in German). Berlin: Borntraeger.
71. ^ Glinka, Konstantin Dmitrievich (1927). The great soil groups of the world and their development. Ann Arbor, Michigan: Edwards Brothers.
72. ^ Bishop, Janice L.; Murchie, Scott L.; Pieters, Carlé L. & Zent, Aaron P. (2002). "A model for formation of dust, soil, and rock coatings on Mars: physical and chemical processes on the Martian surface". Journal of Geophysical Research. 107 (E11): 7-1–7-17. Bibcode:2002JGRE..107.5097B. doi:10.1029/2001JE001581.
73. ^ Navarro-González, Rafael; Rainey, Fred A.; Molina, Paola; Bagaley, Danielle R.; Hollen, Becky J.; de la Rosa, José; Small, Alanna M.; Quinn, Richard C.; Grunthaner, Frank J.; Cáceres, Luis; Gomez-Silva, Benito & McKay, Christopher P. (2003). "Mars-like soils in the Atacama desert, Chile, and the dry limit of microbial life" (PDF). Science. 302 (5647): 1018–21. Bibcode:2003Sci...302.1018N. doi:10.1126/science.1089143. PMID 14605363. Retrieved 17 December 2017.
74. ^ Van Schöll, Laura; Smits, Mark M. & Hoffland, Ellis (2006). "Ectomycorrhizal weathering of the soil minerals muscovite and hornblende". New Phytologist. 171 (4): 805–14. doi:10.1111/j.1469-8137.2006.01790.x. PMID 16918551.
75. ^ Jackson, Togwell A. & Keller, Walter David (1970). "A comparative study of the role of lichens and "inorganic" processes in the chemical weathering of recent Hawaiian lava flows". American Journal of Science. 269 (5): 446–66. Bibcode:1970AmJS..269..446J. doi:10.2475/ajs.269.5.446.
76. ^ Dojani, Stephanie; Lakatos, Michael; Rascher, Uwe; Waneck, Wolfgang; Luettge, Ulrich & Büdel, Burkhard (2007). "Nitrogen input by cyanobacterial biofilms of an inselberg into a tropical rainforest in French Guiana". Flora. 202 (7): 521–29. doi:10.1016/j.flora.2006.12.001.
77. ^ Kabala, Cesary & Kubicz, Justyna (2012). "Initial soil development and carbon accumulation on moraines of the rapidly retreating Werenskiold Glacier, SW Spitsbergen, Svalbard archipelago" (PDF). Geoderma. 175/176: 9–20. Bibcode:2012Geode.175....9K. doi:10.1016/j.geoderma.2012.01.025. Retrieved 26 May 2019.
78. ^ a b c d Jenny, Hans (1941). Factors of soil formation: a system of qunatitative pedology (PDF). New York: McGraw-Hill. Archived from the original (PDF) on 8 August 2017. Retrieved 17 December 2017.
79. ^ Ritter, Michael E. "The physical environment: an introduction to physical geography". Retrieved 17 December 2017.
80. ^ Donahue, Miller & Shickluna 1977, pp. 20–21.
81. ^ Donahue, Miller & Shickluna 1977, p. 21.
82. ^ Donahue, Miller & Shickluna 1977, p. 24.
83. ^ "Weathering". University of Regina. Retrieved 17 December 2017.
84. ^ Uroz, Stéphane; Calvaruso, Christophe; Turpault, Marie-Pierre & Frey-Klett, Pascale (2009). "Mineral weathering by bacteria: ecology, actors and mechanisms". Trends in Microbiology. 17 (8): 378–87. doi:10.1016/j.tim.2009.05.004. PMID 19660952.
85. ^ a b Landeweert, Renske; Hoffland, Ellis; Finlay, Roger D.; Kuyper, Thom W. & Van Breemen, Nico (2001). "Linking plants to rocks: ectomycorrhizal fungi mobilize nutrients from minerals". Trends in Ecology and Evolution. 16 (5): 248–54. doi:10.1016/S0169-5347(01)02122-X. PMID 11301154.
86. ^ Andrews, Jeffrey A. & Schlesinger, William H. (2001). "Soil CO2 dynamics, acidification, and chemical weathering in a temperate forest with experimental CO2 enrichment". Global Biogeochemical Cycles. 15 (1): 149–62. Bibcode:2001GBioC..15..149A. doi:10.1029/2000GB001278.
87. ^ Donahue, Miller & Shickluna 1977, pp. 28–31.
88. ^ Jones, Clive G. & Shachak, Moshe (1990). "Fertilization of the desert soil by rock-eating snails" (PDF). Nature. 346 (6287): 839–41. Bibcode:1990Natur.346..839J. doi:10.1038/346839a0. Retrieved 17 December 2017.
89. ^ Donahue, Miller & Shickluna 1977, pp. 31–33.
90. ^ Li, Li; Steefel, Carl I. & Yang, Li (2008). "Scale dependence of mineral dissolution rates within single pores and fractures" (PDF). Geochimica et Cosmochimica Acta. 72 (2): 360–77. Bibcode:2008GeCoA..72..360L. doi:10.1016/j.gca.2007.10.027. Retrieved 17 December 2017.
91. ^ La Iglesia, Ángel; Martin-Vivaldi Jr, Juan Luis & López Aguayo, Francisco (1976). "Kaolinite crystallization at room temperature by homogeneous precipitation. III. Hydrolysis of feldspars" (PDF). Clays and Clay Minerals. 24 (6287): 36–42. Bibcode:1990Natur.346..839J. doi:10.1038/346839a0. Archived from the original (PDF) on 9 August 2017. Retrieved 17 December 2017.
92. ^ Al-Hosney, Hashim & Grassian, Vicki H. (2004). "Carbonic acid: an important intermediate in the surface chemistry of calcium carbonate". Journal of the American Chemical Society. 126 (26): 8068–69. doi:10.1021/ja0490774. PMID 15225019.
93. ^ Jiménez-González, Inmaculada; Rodríguez‐Navarro, Carlos & Scherer, George W. (2008). "Role of clay minerals in the physicomechanical deterioration of sandstone". Journal of Geophysical Research. 113 (F02021): 1–17. Bibcode:2008JGRF..113.2021J. doi:10.1029/2007JF000845.
94. ^ Mylvaganam, Kausala & Zhang, Liangchi (2002). "Effect of oxygen penetration in silicon due to nano-indentation" (PDF). Nanotechnology. 13 (5): 623–26. Bibcode:2002Nanot..13..623M. doi:10.1088/0957-4484/13/5/316. Retrieved 17 December 2017.
95. ^ Favre, Fabienne; Tessier, Daniel; Abdelmoula, Mustapha; Génin, Jean-Marie; Gates, Will P. & Boivin, Pascal (2002). "Iron reduction and changes in cation exchange capacity in intermittently waterlogged soil". European Journal of Soil Science. 53 (2): 175–83. doi:10.1046/j.1365-2389.2002.00423.x.
96. ^ Riebe, Clifford S.; Kirchner, James W. & Finkel, Robert C. (2004). "Erosional and climatic effects on long-term chemical weathering rates in granitic landscapes spanning diverse climate regimes" (PDF). Earth and Planetary Science Letters. 224 (3/4): 547–62. Bibcode:2004E&PSL.224..547R. doi:10.1016/j.epsl.2004.05.019. Retrieved 17 December 2017.
97. ^ "Rates of weathering" (PDF). Retrieved 17 December 2017.
98. ^ Dere, Ashlee L.; White, Timothy S.; April, Richard H.; Reynolds, Bryan; Miller, Thomas E.; Knapp, Elizabeth P.; McKay, Larry D. & Brantley, Susan L. (2013). "Climate dependence of feldspar weathering in shale soils along a latitudinal gradient". Geochimica et Cosmochimica Acta. 122: 101–26. Bibcode:2013GeCoA.122..101D. doi:10.1016/j.gca.2013.08.001.
99. ^ Kitayama, Kanehiro; Majalap-Lee, Noreen & Aiba, Shin-ichiro (2000). "Soil phosphorus fractionation and phosphorus-use efficiencies of tropical rainforests along altitudinal gradients of Mount Kinabalu, Borneo". Oecologia. 123 (3): 342–49. Bibcode:2000Oecol.123..342K. doi:10.1007/s004420051020. PMID 28308588.
100. ^ Sequeira Braga, Maria Amália; Paquet, Hélène & Begonha, Arlindo (2002). "Weathering of granites in a temperate climate (NW Portugal): granitic saprolites and arenization" (PDF). Catena. 49 (1/2): 41–56. doi:10.1016/S0341-8162(02)00017-6. Retrieved 17 December 2017.
101. ^ Epstein, Howard E.; Burke, Ingrid C. & Lauenroth, William K. (2002). "Regional patterns of decomposition and primary production rates in the U.S. Great Plains" (PDF). Ecology. 83 (2): 320–27. doi:10.1890/0012-9658(2002)083[0320:RPODAP]2.0.CO;2. Retrieved 17 December 2017.
102. ^ Woodward, F. Ian; Lomas, Mark R. & Kelly, Colleen K. (2004). "Global climate and the distribution of plant biomes" (PDF). Philosophical Transactions of the Royal Society of London. Series B, Biological Sciences. 359 (1450): 1465–76. doi:10.1098/rstb.2004.1525. PMC 1693431. PMID 15519965. Retrieved 17 December 2017.
103. ^ Fedoroff, Nicolas (1997). "Clay illuviation in Red Mediterranean soils". Catena. 28 (3/4): 171–89. doi:10.1016/S0341-8162(96)00036-7.
104. ^ Michalzik, Beate; Kalbitz, Karsten; Park, Ji-Hyung; Solinger, Stephan & Matzner, Egbert (2001). "Fluxes and concentrations of dissolved organic carbon and nitrogen: a synthesis for temperate forests" (PDF). Biogeochemistry. 52 (2): 173–205. doi:10.1023/A:1006441620810. Retrieved 17 December 2017.
105. ^ Bernstein, Leon (1975). "Effects of salinity and sodicity on plant growth". Annual Review of Phytopathology. 13: 295–312. doi:10.1146/annurev.py.13.090175.001455.
106. ^ Yuan, Bing-Cheng; Li, Zi-Zhen; Liu, Hua; Gao, Meng & Zhang, Yan-Yu (2007). "Microbial biomass and activity in salt affected soils under arid conditions" (PDF). Applied Soil Ecology. 35 (2): 319–28. doi:10.1016/j.apsoil.2006.07.004. Retrieved 17 December 2017.
107. ^ Schlesinger, William H. (1982). "Carbon storage in the caliche of arid soils: a case study from Arizona" (PDF). Soil Science. 133 (4): 247–55. doi:10.1146/annurev.py.13.090175.001455. Archived from the original (PDF) on 4 March 2018. Retrieved 17 December 2017.
108. ^ Nalbantoglu, Zalihe & Gucbilmez, Emin (2001). "Improvement of calcareous expansive soils in semi-arid environments". Journal of Arid Environments. 47 (4): 453–63. Bibcode:2001JArEn..47..453N. doi:10.1006/jare.2000.0726.
109. ^ Retallack, Gregory J. (2010). "Lateritization and bauxitization events" (PDF). Economic Geology. 105 (3): 655–67. doi:10.2113/gsecongeo.105.3.655. Retrieved 17 December 2017.
110. ^ Donahue, Miller & Shickluna 1977, p. 35.
111. ^ Pye, Kenneth & Tsoar, Haim (1987). "The mechanics and geological implications of dust transport and deposition in deserts with particular reference to loess formation and dune sand diagenesis in the northern Negev, Israel" (PDF). In Frostick, Lynne & Reid, Ian (eds.). Desert sediments: ancient and modern. Geological Society of London, Special Publications. 35. pp. 139–56. Bibcode:1987GSLSP..35..139P. doi:10.1144/GSL.SP.1987.035.01.10. ISBN 978-0-632-01905-2. Retrieved 17 December 2017.
112. ^ Prospero, Joseph M. (1999). "Long-range transport of mineral dust in the global atmosphere: impact of African dust on the environment of the southeastern United States". Proceedings of the National Academy of Sciences of the United States of America. 96 (7): 3396–403. Bibcode:1999PNAS...96.3396P. doi:10.1073/pnas.96.7.3396. PMC 34280. PMID 10097049.
113. ^ Post, Wilfred M.; Emanuel, William R.; Zinke, Paul J. & Stangerberger, Alan G. (1999). "Soil carbon pools and world life zones". Nature. 298 (5870): 156–59. Bibcode:1982Natur.298..156P. doi:10.1038/298156a0.
114. ^ Gómez-Heras, Miguel; Smith, Bernard J. & Fort, Rafael (2006). "Surface temperature differences between minerals in crystalline rocks: implications for granular disaggregation of granites through thermal fatigue". Geomorphology. 78 (3/4): 236–49. Bibcode:2006Geomo..78..236G. doi:10.1016/j.geomorph.2005.12.013.
115. ^ Nicholson, Dawn T. & Nicholson, Frank H. (2000). "Physical deterioration of sedimentary rocks subjected to experimental freeze–thaw weathering" (PDF). Earth Surface Processes and Landforms. 25 (12): 1295–307. Bibcode:2000ESPL...25.1295N. doi:10.1002/1096-9837(200011)25:12<1295::AID-ESP138>3.0.CO;2-E.
116. ^ Lucas, Yves (2001). "The role of plants in controlling rates and products of weathering: importance of biological pumping" (PDF). Annual Review of Earth and Planetary Sciences. 29: 135–63. Bibcode:2001AREPS..29..135L. doi:10.1146/annurev.earth.29.1.135. Retrieved 17 December 2017.
117. ^ Liu, Baoyuan; Nearing, Mark A. & Risse, L. Mark (1994). "Slope gradient effects on soil loss for steep slopes" (PDF). Transactions of the American Society of Agricultural and Biological Engineers. 37 (6): 1835–40. doi:10.13031/2013.28273. Retrieved 17 December 2017.
118. ^ a b Gans, Jason; Wolinsky, Murray & Dunbar, John (2005). "Computational improvements reveal great bacterial diversity and high metal toxicity in soil" (PDF). Science. 309 (5739): 1387–90. Bibcode:2005Sci...309.1387G. doi:10.1126/science.1112665. PMID 16123304. Retrieved 17 December 2017.
119. ^ a b Dance, Amber (2008). "What lies beneath" (PDF). Nature. 455 (7214): 724–25. doi:10.1038/455724a. PMID 18843336. Retrieved 17 December 2017.
120. ^ a b Roesch, Luiz F.W.; Fulthorpe, Roberta R.; Riva, Alberto; Casella, George; Hadwin, Alison K.M.; Kent, Angela D.; Daroub, Samira H.; Camargo, Flavio A.O.; Farmerie, William G. & Triplett, Eric W. (2007). "Pyrosequencing enumerates and contrasts soil microbial diversity" (PDF). The ISME Journal. 1 (4): 283–90. doi:10.1038/ismej.2007.53. PMC 2970868. PMID 18043639. Retrieved 17 December 2017.
121. ^ Meysman, Filip J.R.; Middelburg, Jack J. & Heip, Carlo H.R. (2006). "Bioturbation: a fresh look at Darwin's last idea" (PDF). Trends in Ecology and Evolution. 21 (12): 688–95. doi:10.1016/j.tree.2006.08.002. PMID 16901581. Retrieved 17 December 2017.
122. ^ Williams, Stacey M. & Weil, Ray R. (2004). "Crop cover root channels may alleviate soil compaction effects on soybean crop" (PDF). Soil Science Society of America Journal. 68 (4): 1403–09. Bibcode:2004SSASJ..68.1403W. doi:10.2136/sssaj2004.1403. Retrieved 17 December 2017.
123. ^ Lynch, Jonathan (1995). "Root architecture and plant productivity" (PDF). Plant Physiology. 109 (1): 7–13. doi:10.1104/pp.109.1.7. PMC 157559. PMID 12228579. Retrieved 17 December 2017.
124. ^ Nguyen, Christophe (2003). "Rhizodeposition of organic C by plants: mechanisms and controls" (PDF). Agronomie. 23 (5/6): 375–96. doi:10.1051/agro:2003011. Retrieved 17 December 2017.
125. ^ Widmer, Franco; Pesaro, Manuel; Zeyer, Josef & Blaser, Peter (2000). "Preferential flow paths: biological 'hot spots' in soils" (PDF). In Bundt, Maya (ed.). Highways through the soil: properties of preferential flow paths and transport of reactive compounds (Thesis). Zurich: ETH Library. pp. 53–75. doi:10.3929/ethz-a-004036424. hdl:20.500.11850/144808. Retrieved 17 December 2017.
126. ^ Bonkowski, Michael (2004). "Protozoa and plant growth: the microbial loop in soil revisited". New Phytologist. 162 (3): 617–31. doi:10.1111/j.1469-8137.2004.01066.x.
127. ^ Six, Johan; Bossuyt, Heleen; De Gryze, Steven & Denef, Karolien (2004). "A history of research on the link between (micro)aggregates, soil biota, and soil organic matter dynamics". Soil and Tillage Research. 79 (1): 7–31. doi:10.1016/j.still.2004.03.008.
128. ^ Saur, Étienne & Ponge, Jean-François (1988). "Alimentary studies on the collembolan Paratullbergia callipygos using transmission electron microscopy" (PDF). Pedobiologia. 31 (5/6): 355–79. Retrieved 17 December 2017.
129. ^ Oldeman, L. Roel (1992). "Global extent of soil degradation" (PDF). ISRIC Bi-Annual Report 1991/1992. Wagenngen, The Netherlands: ISRIC. pp. 19–36. Retrieved 17 December 2017.
130. ^ Karathanasis, Anastasios D. & Wells, Kenneth L. (2004). "A comparison of mineral weathering trends between two management systems on a catena of loess-derived soils". Soil Science Society of America Journal. 53 (2): 582–88. Bibcode:1989SSASJ..53..582K. doi:10.2136/sssaj1989.03615995005300020047x.
131. ^ a b Lee, Kenneth Ernest & Foster, Ralph C. (2003). "Soil fauna and soil structure". Australian Journal of Soil Research. 29 (6): 745–75. doi:10.1071/SR9910745.
132. ^ Scheu, Stefan (2003). "Effects of earthworms on plant growth: patterns and perspectives". Pedobiologia. 47 (5/6): 846–56. doi:10.1078/0031-4056-00270.
133. ^ Zhang, Haiquan & Schrader, Stefan (1993). "Earthworm effects on selected physical and chemical properties of soil aggregates". Biology and Fertility of Soils. 15 (3): 229–34. doi:10.1007/BF00361617.
134. ^ Bouché, Marcel B. & Al-Addan, Fathel (1997). "Earthworms, water infiltration and soil stability: some new assessments". Soil Biology and Biochemistry. 29 (3/4): 441–52. doi:10.1016/S0038-0717(96)00272-6.
135. ^ Bernier, Nicolas (1998). "Earthworm feeding activity and development of the humus profile". Biology and Fertility of Soils. 26 (3): 215–23. doi:10.1007/s003740050370.
136. ^ Scheu, Stefan (1991). "Mucus excretion and carbon turnover of endogeic earthworms" (PDF). Biology and Fertility of Soils. 12 (3): 217–20. doi:10.1007/BF00337206. Retrieved 17 December 2017.
137. ^ Brown, George G. (1995). "How do earthworms affect microfloral and faunal community diversity?". Plant and Soil. 170 (1): 209–31. doi:10.1007/BF02183068.
138. ^ Jouquet, Pascal; Dauber, Jens; Lagerlöf, Jan; Lavelle, Patrick & Lepage, Michel (2006). "Soil invertebrates as ecosystem engineers: intended and accidental effects on soil and feedback loops" (PDF). Applied Soil Ecology. 32 (2): 153–64. doi:10.1016/j.apsoil.2005.07.004. Retrieved 17 December 2017.
139. ^ Bohlen, Patrick J.; Scheu, Stefan; Hale, Cindy M.; McLean, Mary Ann; Migge, Sonja; Groffman, Peter M. & Parkinson, Dennis (2004). "Non-native invasive earthworms as agents of change in northern temperate forests" (PDF). Frontiers in Ecology and the Environment. 2 (8): 427–35. doi:10.2307/3868431. JSTOR 3868431. Retrieved 13 August 2017.
140. ^ De Bruyn, Lisa Lobry & Conacher, Arthur J. (1990). "The role of termites and ants in soil modification: a review" (PDF). Australian Journal of Soil Research. 28 (1): 55–93. doi:10.1071/SR9900055. Retrieved 17 December 2017.
141. ^ Kinlaw, Alton Emory (2006). "Burrows of semi-fossorial vertebrates in upland communities of Central Florida: their architecture, dispersion and ecological consequences" (PDF). pp. 19–45. Retrieved 17 December 2017.
142. ^ Borst, George (1968). "The occurrence of crotovinas in some southern California soils" (PDF). Transactions of the 9th International Congress of Soil Science, Adelaide, Australia, August 5–15, 1968. 2. Sidney: Angus & Robertson. pp. 19–27. Retrieved 17 December 2017.
143. ^ Gyssels, Gwendolyn; Poesen, Jean; Bochet, Esther & Li, Yong (2005). "Impact of plant roots on the resistance of soils to erosion by water: a review" (PDF). Progress in Physical Geography. 29 (2): 189–217. doi:10.1191/0309133305pp443ra. Retrieved 17 December 2017.
144. ^ Balisky, Allen C. & Burton, Philip J. (1993). "Distinction of soil thermal regimes under various experimental vegetation covers". Canadian Journal of Soil Science. 73 (4): 411–20. doi:10.4141/cjss93-043.
145. ^ Marrou, Hélène; Dufour, Lydie & Wery, Jacques (2013). "How does a shelter of solar panels influence water flows in a soil-crop system?". European Journal of Agronomy. 50: 38–51. doi:10.1016/j.eja.2013.05.004.
146. ^ Heck, Pamela; Lüthi, Daniel & Schär, Christoph (1999). "The influence of vegetation on the summertime evolution of European soil moisture". Physics and Chemistry of the Earth, Part B, Hydrology, Oceans and Atmosphere. 24 (6): 609–14. Bibcode:1999PCEB...24..609H. doi:10.1016/S1464-1909(99)00052-0.
147. ^ Jones, David L. (1998). "Organic acids in the rhizospere: a critical review" (PDF). Plant and Soil. 205 (1): 25–44. doi:10.1023/A:1004356007312. Retrieved 17 December 2017.
148. ^ Calvaruso, Christophe; Turpault, Marie-Pierre & Frey-Klett, Pascal (2006). "Root-associated bacteria contribute to mineral weathering and to mineral nutrition in trees: a budgeting analysis" (PDF). Applied and Environmental Microbiology. 72 (2): 1258–66. doi:10.1128/AEM.72.2.1258-1266.2006. PMC 1392890. PMID 16461674. Retrieved 17 December 2017.
149. ^ Angers, Denis A.; Caron, Jean (1998). "Plant-induced changes in soil structure: processes and feedbacks" (PDF). Biogeochemistry. 42 (1): 55–72. doi:10.1023/A:1005944025343. Retrieved 17 December 2017.
150. ^ Dai, Shengpei; Zhang, Bo; Wang, Haijun; Wang, Yamin; Guo, Lingxia; Wang, Xingmei & Li, Dan (2011). "Vegetation cover change and the driving factors over northwest China" (PDF). Journal of Arid Land. 3 (1): 25–33. doi:10.3724/SP.J.1227.2011.00025. Retrieved 17 December 2017.
151. ^ Vogiatzakis, Ioannis; Griffiths, Geoffrey H. & Mannion, Antoinette M. (2003). "Environmental factors and vegetation composition, Lefka Ori Massif, Crete, S. Aegean". Global Ecology and Biogeography. 12 (2): 131–46. doi:10.1046/j.1466-822X.2003.00021.x.
152. ^ Brêthes, Alain; Brun, Jean-Jacques; Jabiol, Bernard; Ponge, Jean-François & Toutain, François (1995). "Classification of forest humus forms: a French proposal" (PDF). Annales des Sciences Forestières. 52 (6): 535–46. doi:10.1051/forest:19950602. Retrieved 17 December 2017.
153. ^ Dudal, Rudi (2005). "The sixth factor of soil formation" (PDF). Eurasian Soil Science. 38 (Supplement 1): S60–S65. Retrieved 17 December 2017.
154. ^ Anderson, Roger C. (2006). "Evolution and origin of the Central Grassland of North America: climate, fire, and mammalian grazers". Journal of the Torrey Botanical Society. 133 (4): 626–47. doi:10.3159/1095-5674(2006)133[626:EAOOTC]2.0.CO;2.
155. ^ Burke, Ingrid C.; Yonker, Caroline M.; Parton, William J.; Cole, C. Vernon; Flach, Klaus & Schimel, David S. (1989). "Texture, climate, and cultivation effects on soil organic matter content in U.S. grassland soils" (PDF). Soil Science Society of America Journal. 53 (3): 800–05. Bibcode:1989SSASJ..53..800B. doi:10.2136/sssaj1989.03615995005300030029x. Retrieved 17 December 2017.
156. ^ Lisetskii, Fedor N. & Pichura, Vitalii I. (2016). "Assessment and forecast of soil formation under irrigation in the steppe zone of Ukraine" (PDF). Russian Agricultural Sciences. 42 (2): 155–59. doi:10.3103/S1068367416020075. Retrieved 17 December 2017.
157. ^ Schön, Martina (2011). "Impact of N fertilization on subsoil properties: soil organic matter and aggregate stability" (PDF). Retrieved 17 December 2017.
158. ^ Bormann, Bernard T.; Spaltenstein, Henri; McClellan, Michael H.; Ugolini, Fiorenzo C.; Cromack, Kermit Jr & Nay, Stephan M. (1995). "Rapid soil development after windthrow disturbance in pristine forests" (PDF). Journal of Ecology. 83 (5): 747–57. doi:10.2307/2261411. JSTOR 2261411. Retrieved 17 December 2017.
159. ^ Crocker, Robert L. & Major, Jack (1955). "Soil development in relation to vegetation and surface age at Glacier Bay, Alaska" (PDF). Journal of Ecology. 43 (2): 427–48. doi:10.2307/2257005. JSTOR 2257005. Archived from the original (PDF) on 25 September 2017. Retrieved 17 December 2017.
160. ^ a b c d Crews, Timothy E.; Kitayama, Kanehiro; Fownes, James H.; Riley, Ralph H.; Herbert, Darrell A.; Mueller-Dombois, Dieter & Vitousek, Peter M. (1995). "Changes in soil phosphorus and ecosystem dynamics along a long term chronosequence in Hawaii" (PDF). Ecology. 76 (5): 1407–24. doi:10.2307/1938144. JSTOR 1938144. Retrieved 17 December 2017.
161. ^ Huggett, Richard J. (1998). "Soil chronosequences, soil development, and soil evolution: a critical review". Catena. 32 (3/4): 155–72. doi:10.1016/S0341-8162(98)00053-8.
162. ^ a b Simonson 1957, pp. 20–21.
163. ^ Donahue, Miller & Shickluna 1977, p. 26.
164. ^ Craft, Christopher; Broome, Stephen & Campbell, Carlton (2002). "Fifteen years of vegetation and soil development after brackish‐water marsh creation" (PDF). Restoration Ecology. 10 (2): 248–58. doi:10.1046/j.1526-100X.2002.01020.x. Archived from the original (PDF) on 10 August 2017. Retrieved 17 December 2017.
165. ^ Shipitalo, Martin J. & Le Bayon, Renée-Claire (2004). "Quantifying the effects of earthworms on soil aggregation and porosity" (PDF). In Edwards, Clive A. (ed.). Earthworm ecology (PDF) (2nd ed.). Boca Raton, Florida: CRC Press. pp. 183–200. doi:10.1201/9781420039719.pt5. ISBN 978-1-4200-3971-9. Retrieved 17 December 2017.
166. ^ He, Changling; Breuning-Madsen, Henrik & Awadzi, Theodore W. (2007). "Mineralogy of dust deposited during the Harmattan season in Ghana". Geografisk Tidsskrift. 107 (1): 9–15. CiteSeerX 10.1.1.469.8326. doi:10.1080/00167223.2007.10801371.
167. ^ Pimentel, David; Harvey, C.; Resosudarmo, Pradnja; Sinclair, K.; Kurz, D.; McNair, M.; Crist, S.; Shpritz, Lisa; Fitton, L.; Saffouri, R. & Blair, R. (1995). "Environmental and economic cost of soil erosion and conservation benefits" (PDF). Science. 267 (5201): 1117–23. Bibcode:1995Sci...267.1117P. doi:10.1126/science.267.5201.1117. PMID 17789193. Retrieved 17 December 2017.
168. ^ Wakatsuki, Toshiyuki & Rasyidin, Azwar (1992). "Rates of weathering and soil formation" (PDF). Geoderma. 52 (3/4): 251–63. Bibcode:1992Geode..52..251W. doi:10.1016/0016-7061(92)90040-E. Retrieved 17 December 2017.
169. ^ Huggett, R.J (1998). "Soil chronosequences, soil development, and soil evolution: a critical review". Catena. 32 (3–4): 155–172. doi:10.1016/S0341-8162(98)00053-8.
170. ^ Gardner, Catriona M.K.; Laryea, Kofi Buna & Unger, Paul W. (1999). Soil physical constraints to plant growth and crop production (PDF) (1st ed.). Rome: Food and Agriculture Organization of the United Nations. Retrieved 24 December 2017.
171. ^ Six, Johan; Paustian, Keith; Elliott, Edward T. & Combrink, Clay (2000). "Soil structure and organic matter. I. Distribution of aggregate-size classes and aggregate-associated carbon" (PDF). Soil Science Society of America Journal. 64 (2): 681–89. Bibcode:2000SSASJ..64..681S. doi:10.2136/sssaj2000.642681x. Retrieved 24 December 2017.
172. ^ Håkansson, Inge & Lipiec, Jerzy (2000). "A review of the usefulness of relative bulk density values in studies of soil structure and compaction" (PDF). Soil and Tillage Research. 53 (2): 71–85. doi:10.1016/S0167-1987(99)00095-1. Retrieved 24 December 2017.
173. ^ Schwerdtfeger, W.J. (1965). "Soil resistivity as related to underground corrosion and cathodic protection". Journal of Research of the National Bureau of Standards. 69C (1): 71–77. doi:10.6028/jres.069c.012.
174. ^ Tamboli, Prabhakar Mahadeo (1961). The influence of bulk density and aggregate size on soil moisture retention (PDF). Ames, Iowa: Iowa State University. Retrieved 24 December 2017.
175. ^ Haynes, Richard J. & Naidu, Ravi (1998). "Influence of lime, fertilizer and manure applications on soil organic matter content and soil physical conditions: a review" (PDF). Nutrient Cycling in Agroecosystems. 51 (2): 123–37. doi:10.1023/A:1009738307837. Retrieved 24 December 2017.
176. ^ Silver, Whendee L.; Neff, Jason; McGroddy, Megan; Veldkamp, Ed; Keller, Michael & Cosme, Raimundo (2000). "Effects of soil texture on belowground carbon and nutrient storage in a lowland Amazonian forest ecosystem" (PDF). Ecosystems. 3 (2): 193–209. doi:10.1007/s100210000019. Retrieved 24 December 2017.
177. ^ Jackson, Marion L. (1957). "Frequency distribution of clay minerals in major great soil groups as related to the factors of soil formation". Clays and Clay Minerals. 6 (1): 133–43. Bibcode:1957CCM.....6..133J. doi:10.1346/CCMN.1957.0060111.
178. ^ a b Petersen, Lis Wollesen; Moldrup, Per; Jacobsen, Ole Hørbye & Rolston, Dennis E. (1996). "Relations between specific surface area and soil physical and chemical properties" (PDF). Soil Science. 161 (1): 9–21. Bibcode:1996SoilS.161....9P. doi:10.1097/00010694-199601000-00003. Retrieved 24 December 2017.
179. ^ Lewis, D.R. (1955). "Ion exchange reactions of clays" (PDF). In Pask, Joseph A.; Turner, Mort D. (eds.). Clays and clay technology. San Francisco: State of California, Department of Natural Resources, Division of Mines. pp. 54–69. Retrieved 24 December 2017.
180. ^ Dexter, Anthony R. (2004). "Soil physical quality. I. Theory, effects of soil texture, density, and organic matter, and effects on root growth". Geoderma. 120 (3/4): 201–14. doi:10.1016/j.geoderma.2003.09.004.
181. ^ Bouyoucos, George J. (1935). "The clay ratio as a criterion of susceptibility of soils to erosion". Journal of the American Society of Agronomy. 27 (9): 738–41. doi:10.2134/agronj1935.00021962002700090007x.
182. ^ Borrelli, Pasquale; Ballabio, Cristiano; Panagos, Panos; Montanarella, Luca (2014). "Wind erosion susceptibility of European soils" (PDF). Geoderma. 232/234: 471–78. Bibcode:2014Geode.232..471B. doi:10.1016/j.geoderma.2014.06.008. Retrieved 24 December 2017.
183. ^ Russell 1957, pp. 32–33.
184. ^ Flemming 1957, p. 331.
185. ^ "Calcareous Sand". U.S. Geological Survey. Retrieved 24 December 2017.
186. ^ Grim, Ralph E. (1953). Clay mineralogy (PDF). New York: McGraw-Hill. Archived from the original (PDF) on 24 December 2017. Retrieved 24 December 2017.
187. ^ Donahue, Miller & Shickluna 1977, p. 53.
188. ^ Sillanpää, Mikko & Webber, L.R. (1961). "The effect of freezing-thawing and wetting-drying cycles on soil aggregation". Canadian Journal of Soil Science. 41 (2): 182–87. doi:10.4141/cjss61-024.
189. ^ a b Oades, J. Malcolm (1993). "The role of biology in the formation, stabilization and degradation of soil structure" (PDF). Geoderma. 56 (1–4): 377–400. Bibcode:1993Geode..56..377O. doi:10.1016/0016-7061(93)90123-3. Retrieved 25 December 2017.
190. ^ Soil Science Division Staff (2017). "Soil structure". Soil Survey Manual (issued March 2017), USDA Handbook No. 18. Washington, DC: United States Department of Agriculture, Natural Researches Conservation Service, Soils. Retrieved 25 December 2017.
191. ^ Horn, Rainer; Taubner, Heidi; Wuttke, M. & Baumgartl, Thomas (1994). "Soil physical properties related to soil structure". Soil and Tillage Research. 30 (2–4): 187–216. doi:10.1016/0167-1987(94)90005-1.
192. ^ Murray, Robert S. & Grant, Cameron D. (2007). "The impact of irrigation on soil structure". The National Program for Sustainable Irrigation. CiteSeerX 10.1.1.460.5683.
193. ^ Donahue, Miller & Shickluna 1977, pp. 55–56.
194. ^ Dinka, Takele M.; Morgan, Cristine L.S.; McInnes, Kevin J.; Kishné, Andrea Sz. & Harmel, R. Daren (2013). "Shrink–swell behavior of soil across a Vertisol catena" (PDF). Journal of Hydrology. 476: 352–59. Bibcode:2013JHyd..476..352D. doi:10.1016/j.jhydrol.2012.11.002. Retrieved 25 December 2017.
195. ^ Morris, Peter H.; Graham, James & Williams, David J. (1992). "Cracking in drying soils" (PDF). Canadian Geotechnical Journal. 29 (2): 263–77. doi:10.1139/t92-030. Retrieved 25 December 2017.
196. ^ Robinson, Nicole; Harper, R.J. & Smettem, Keith Richard J. (2006). "Soil water depletion by Eucalyptus spp. integrated into dryland agricultural systems" (PDF). Plant and Soil. 286 (1/2): 141–51. doi:10.1007/s11104-006-9032-4. Retrieved 25 December 2017.
197. ^ Scholl, Peter; Leitner, Daniel; Kammerer, Gerhard; Loiskandl, Willibald; Kaul, Hans-Peter & Bodner, Gernot (2014). "Root induced changes of effective 1D hydraulic properties in a soil column" (PDF). Plant and Soil. 381 (1/2): 193–213. doi:10.1007/s11104-014-2121-x. PMC 4372835. PMID 25834290. Retrieved 25 December 2017.
198. ^ Angers, Denis A. & Caron, Jean (1998). "Plant-induced changes in soil structure: processes and feedbacks" (PDF). Biogeochemistry. 42 (1): 55–72. doi:10.1023/A:1005944025343. Retrieved 25 December 2017.
199. ^ White, Rosemary G. & Kirkegaard, John A. (2010). "The distribution and abundance of wheat roots in a dense, structured subsoil: implications for water uptake" (PDF). Plant, Cell and Environment. 33 (2): 133–48. doi:10.1111/j.1365-3040.2009.02059.x. PMID 19895403. Retrieved 25 December 2017.
200. ^ Skinner, Malcolm F. & Bowen, Glynn D. (1974). "The penetration of soil by mycelial strands of ectomycorrhizal fungi". Soil Biology and Biochemistry. 6 (1): 57–8. doi:10.1016/0038-0717(74)90012-1.
201. ^ Chenu, Claire (1993). "Clay- or sand-polysaccharide associations as models for the interface between micro-organisms and soil: water related properties and microstructure" (PDF). Geoderma. 56 (1–4): 143–56. Bibcode:1993Geode..56..143C. doi:10.1016/0016-7061(93)90106-U. Retrieved 25 December 2017.
202. ^ Franzluebbers, Alan J. (2002). "Water infiltration and soil structure related to organic matter and its stratification with depth" (PDF). Soil and Tillage Research. 66 (2): 197–205. doi:10.1016/S0167-1987(02)00027-2. Retrieved 25 December 2017.
203. ^ a b Sposito, Garrison; Skipper, Neal T.; Sutton, Rebecca; Park, Sung-Ho; Soper, Alan K. & Greathouse, Jeffery A. (1999). "Surface geochemistry of the clay minerals". Proceedings of the National Academy of Sciences of the United States of America. 96 (7): 3358–64. Bibcode:1999PNAS...96.3358S. doi:10.1073/pnas.96.7.3358. PMC 34275. PMID 10097044.
204. ^ Tombácz, Etelka & Szekeres, Márta (2006). "Surface charge heterogeneity of kaolinite in aqueous suspension in comparison with montmorillonite" (PDF). Applied Clay Science. 34 (1–4): 105–24. doi:10.1016/j.clay.2006.05.009. Retrieved 25 December 2017.
205. ^ Schofield, R. Kenworthy & Samson, H.R. (1953). "The deflocculation of kaolinite suspensions and the accompanying change-over from positive to negative chloride adsorption". Clay Minerals Bulletin. 2 (9): 45–51. Bibcode:1953ClMin...2...45S. doi:10.1180/claymin.1953.002.9.08.
206. ^ Shainberg, Isaac & Letey, John (1984). "Response of soils to sodic and saline conditions". Hilgardia. 52 (2): 1–57. doi:10.3733/hilg.v52n02p057. Archived from the original (PDF) on 11 December 2017. Retrieved 25 December 2017.
207. ^ Young, Michael H.; McDonald, Eric V.; Caldwell, Todd G.; Benner, Shawn G. & Meadows, Darren G. (2004). "Hydraulic properties of a desert soil chronosequence in the Mojave Desert, USA" (PDF). Vadose Zone Journal. 3 (3): 956–63. doi:10.2113/3.3.956. Retrieved 16 June 2018.
208. ^ Donahue, Miller & Shickluna 1977, p. 60.
209. ^ Blanco-Canqui, Humberto; Lal, Rattan; Post, Wilfred M.; Izaurralde, Roberto Cesar & Shipitalo, Martin J. (2006). "Organic carbon influences on soil particle density and rheological properties" (PDF). Soil Science Society of America Journal. 70 (4): 1407–14. Bibcode:2006SSASJ..70.1407B. doi:10.2136/sssaj2005.0355. Retrieved 25 December 2017.
210. ^ Cornell, Rochelle M. & Schwertmann, Udo (2003). The iron oxides: structure, properties, reactions, occurrences and uses (PDF) (2nd ed.). Weinheim, Germany: Wiley-VCH. Archived from the original (PDF) on 26 December 2017. Retrieved 25 December 2017.
211. ^ Håkansson, Inge & Lipiec, Jerzy (2000). "A review of the usefulness of relative bulk density values in studies of soil structure and compaction" (PDF). Soil and Tillage Research. 53 (2): 71–85. doi:10.1016/S0167-1987(99)00095-1. Retrieved 31 December 2017.
212. ^ Donahue, Miller & Shickluna 1977, pp. 59–61.
213. ^ Mäder, Paul; Fließbach, Andreas; Dubois, David; Gunst, Lucie; Fried, Padruot & Liggli, Urs (2002). "Soil fertility and biodiversity in organic farming" (PDF). Science. 296 (1694): 1694–97. Bibcode:2002Sci...296.1694M. doi:10.1126/science.1071148. PMID 12040197. Retrieved 30 December 2017.
214. ^ Blanchart, Éric; Albrecht, Alain; Alegre, Julio; Duboisset, Arnaud; Gilot, Cécile; Pashanasi, Beto; Lavelle, Patrick & Brussaard, Lijbert (1999). "Effects of earthworms on soil structure and physical properties" (PDF). In Lavelle, Patrick; Brussaard, Lijbert & Hendrix, Paul F. (eds.). Earthworm management in tropical agroecosystems (1st ed.). Wallingford, UK: CAB International. pp. 149–72. ISBN 978-0-85199-270-9. Retrieved 31 December 2017.
215. ^ Rampazzo, Nicola; Blum, Winfried E.H. & Wimmer, Bernhard (1998). "Assessment of soil structure parameters and functions in agricultural soils" (PDF). Die Bodenkultur. 49 (2): 69–84. Retrieved 30 December 2017.
216. ^ Bodman, Geoffrey Baldwin & Constantin, Winfried G.K. (1965). "Influence of particle size distribution in soil compaction" (PDF). Hilgardia. 36 (15): 567–91. doi:10.3733/hilg.v36n15p567. Retrieved 30 December 2017.
217. ^ Zeng, Y.; Gantzer, Clark; Payton, R.L. & Anderson, Stephen H. (1996). "Fractal dimension and lacunarity of bulk density determined with X-ray computed tomography" (PDF). Soil Science Society of America Journal. 60 (6): 1718–24. Bibcode:1996SSASJ..60.1718Z. doi:10.2136/sssaj1996.03615995006000060016x. Retrieved 30 December 2017.
218. ^ Rawls, Walter J.; Brakensiek, Donald L. & Saxton, Keith E. (1982). "Estimation of soil water properties" (PDF). Transactions of the American Society of Agricultural Engineers. 25 (5): 1316–20. doi:10.13031/2013.33720. Archived from the original (PDF) on 17 May 2017. Retrieved 30 December 2017.
219. ^ "Physical aspects of crop productivity". www.fao.org. Rome: Food and Agriculture Organization of the United Nations. Retrieved 1 January 2018.
220. ^ Rutherford, P. Michael & Juma, Noorallah G. (1992). "Influence of texture on habitable pore space and bacterial-protozoan populations in soil". Biology and Fertility of Soils. 12 (4): 221–27. doi:10.1007/BF00336036.
221. ^ Diamond, Sidney (1970). "Pore size distributions in clays" (PDF). Clays and Clay Minerals. 18 (1): 7–23. Bibcode:1970CCM....18....7D. doi:10.1346/CCMN.1970.0180103. Retrieved 1 January 2018.
222. ^ "Permeability of different soils". nptel.ac.in. Chennai, India: NPTEL, Government of India. Archived from the original on 2 January 2018. Retrieved 1 January 2018.
223. ^ Donahue, Miller & Shickluna 1977, pp. 62–63.
224. ^ "Physical properties of soil and soil water". passel.unl.edu. Lincoln, Nebraska: Plant and Soil Sciences eLibrary. Retrieved 1 January 2018.
225. ^ Nimmo, John R. (2004). "Porosity and pore size distribution" (PDF). In Hillel, Daniel; Rosenzweig, Cynthia; Powlson, David; Scow, Kate; Singer, Michail; Sparks, Donald (eds.). Encyclopedia of soils in the environment, volume 3 (1st ed.). London: Academic Press. pp. 295–303. ISBN 978-0-12-348530-4. Retrieved 7 January 2018.
226. ^ Giller, Paul S. (1996). "The diversity of soil communities, the 'poor man's tropical rainforest'" (PDF). Biodiversity and Conservation. 5 (2): 135–68. doi:10.1007/BF00055827. Retrieved 1 January 2018.
227. ^ Boekel, P. & Peerlkamp, Petrus K. (1956). "Soil consistency as a factor determining the soil structure of clay soils" (PDF). Netherlands Journal of Agricultural Science. 4 (1): 122–25. Retrieved 7 January 2018.
228. ^ Day, Robert W. (2000). "Soil mechanics and foundations" (PDF). In Merritt, Frederick S.; Rickett, Jonathan T. (eds.). Building design and construction handbook (6th ed.). New York: McGraw-Hill Professional. ISBN 978-0-07-041999-5. Retrieved 7 January 2018.
229. ^ "Soil consistency". Rome: Food and Agriculture Organization of the United Nations. Retrieved 7 January 2018.
230. ^ Donahue, Miller & Shickluna 1977, pp. 62–63, 565–67.
231. ^ Deardorff, James W. (1978). "Efficient prediction of ground surface temperature and moisture, with inclusion of a layer of vegetation" (PDF). Journal of Geophysical Research. 83 (C4): 1889–903. Bibcode:1978JGR....83.1889D. CiteSeerX 10.1.1.466.5266. doi:10.1029/JC083iC04p01889. Retrieved 28 January 2018.
232. ^ Hursh, Andrew; Ballantyne, Ashley; Cooper, Leila; Maneta, Marco; Kimball, John & Watts, Jennifer (2017). "The sensitivity of soil respiration to soil temperature, moisture, and carbon supply at the global scale" (PDF). Global Change Biology. 23 (5): 2090–103. Bibcode:2017GCBio..23.2090H. doi:10.1111/gcb.13489. PMID 27594213. Retrieved 28 January 2018.
233. ^ Forcella, Frank; Benech Arnold, Roberto L.; Sanchez, Rudolfo & Ghersa, Claudio M. (2000). "Modeling seedling emergence" (PDF). Field Crops Research. 67 (2): 123–39. doi:10.1016/S0378-4290(00)00088-5. Retrieved 28 January 2018.
234. ^ Benech-Arnold, Roberto L.; Sánchez, Rodolfo A.; Forcella, Frank; Kruk, Betina C. & Ghersa, Claudio M. (2000). "Environmental control of dormancy in weed seed banks in soil" (PDF). Field Crops Research. 67 (2): 105–22. doi:10.1016/S0378-4290(00)00087-3. Retrieved 28 January 2018.
235. ^ Herranz, José M.; Ferrandis, Pablo & Martínez-Sánchez, Juan J. (1998). "Influence of heat on seed germination of seven Mediterranean Leguminosae species" (PDF). Plant Ecology. 136 (1): 95–103. doi:10.1023/A:1009702318641. Retrieved 28 January 2018.
236. ^ McMichael, Bobbie L. & Burke, John J. (1998). "Soil temperature and root growth" (PDF). HortScience. 33 (6): 947–51. doi:10.21273/HORTSCI.33.6.947. Archived from the original (PDF) on 12 July 2018. Retrieved 28 January 2018.
237. ^ Tindall, James A.; Mills, Harry A. & Radcliffe, David E. (1990). "The effect of root zone temperature on nutrient uptake of tomato" (PDF). Journal of Plant Nutrition. 13 (8): 939–56. doi:10.1080/01904169009364127. Retrieved 28 January 2018.
238. ^ "Soil temperatures". Exeter, UK: Met Office. Retrieved 3 February 2018.
239. ^ a b Lal, Ratan (1974). "Soil temperature, soil moisture and maize yield from mulched and unmulched tropical soils" (PDF). Plant and Soil. 40 (1): 129–43. doi:10.1007/BF00011415. Retrieved 3 February 2018.
240. ^ Ritchie, Joe T. & NeSmith, D. Scott (1991). "Temperature and crop development" (PDF). In Hanks, John & Ritchie, Joe T. (eds.). Modeling plant and soil systems (1st ed.). Madison, Wisconsin: American Society of Agronomy. pp. 5–29. ISBN 978-0-89118-106-4. Retrieved 4 February 2018.
241. ^ Vetsch, Jeffrey A. & Randall, Gyles W. (2004). "Corn production as affected by nitrogen application timing and tillage" (PDF). Agronomy Journal. 96 (2): 502–09. doi:10.2134/agronj2004.5020. Retrieved 4 February 2018.
242. ^ Holmes, R.M. & Robertson, G.W. (1960). "Soil heaving in alfalfa plots in relation to soil and air temperature". Canadian Journal of Soil Science. 40 (2): 212–18. doi:10.4141/cjss60-027.
243. ^ Dagesse, Daryl F. (2013). "Freezing cycle effects on water stability of soil aggregates". Canadian Journal of Soil Science. 93 (4): 473–83. doi:10.4141/cjss2012-046.
244. ^ Dormaar, Johan F. & Ketcheson, John W. (1960). "The effect of nitrogen form and soil temperature on the growth and phosphorus uptake of corn plants grown in the greenhouse". Canadian Journal of Soil Science. 40 (2): 177–84. doi:10.4141/cjss60-023.
245. ^ Fuchs, Marcel & Tanner, Champ B. (1967). "Evaporation from a drying soil". Journal of Applied Meteorology. 6 (5): 852–57. Bibcode:1967JApMe...6..852F. doi:10.1175/1520-0450(1967)006<0852:EFADS>2.0.CO;2.
246. ^ Waggoner, Paul E.; Miller, Patrick M. & De Roo, Henry C. (1960). "Plastic mulching: principles and benefits" (PDF). Bulletin of the Connecticut Agricultural Experiment Station. 634: 1–44. Retrieved 10 February 2018.
247. ^ Beadle, Noel C.W. (1940). "Soil temperatures during forest fires and their effect on the survival of vegetation" (PDF). Journal of Ecology. 28 (1): 180–92. doi:10.2307/2256168. JSTOR 2256168. Retrieved 18 February 2018.
248. ^ a b Post, Donald F.; Fimbres, Adan; Matthias, Allan D.; Sano, Edson E.; Accioly, Luciano; Batchily, A. Karim & Ferreira, Laerte G. (2000). "Predicting soil albedo from soil color and spectral reflectance data" (PDF). Soil Science Society of America Journal. 64 (3): 1027–34. Bibcode:2000SSASJ..64.1027P. doi:10.2136/sssaj2000.6431027x. Retrieved 25 February 2018.
249. ^ Macyk, T.M.; Pawluk, S. & Lindsay, J.D. (1978). "Relief and microclimate as related to soil properties". Canadian Journal of Soil Science. 58 (3): 421–38. doi:10.4141/cjss78-049.
250. ^ Zheng, Daolan; Hunt Jr, E. Raymond & Running, Steven W. (1993). "A daily soil temperature model based on air temperature and precipitation for continental applications". Climate Research. 2 (3): 183–91. Bibcode:1993ClRes...2..183Z. doi:10.3354/cr002183.
251. ^ Kang, Sinkyu; Kim, S.; Oh, S. & Lee, Dowon (2000). "Predicting spatial and temporal patterns of soil temperature based on topography, surface cover and air temperature" (PDF). Forest Ecology and Management. 136 (1–3): 173–84. doi:10.1016/S0378-1127(99)00290-X. Retrieved 4 March 2018.
252. ^ Bristow, Keith L. (1998). "Measurement of thermal properties and water content of unsaturated sandy soil using dual-probe heat-pulse probes" (PDF). Agricultural and Forest Meteorology. 89 (2): 75–84. Bibcode:1998AgFM...89...75B. doi:10.1016/S0168-1923(97)00065-8. Retrieved 4 March 2018.
253. ^ Abu-Hamdeh, Nidal H. (2003). "Thermal properties of soils as affected by density and water content" (PDF). Biosystems Engineering. 86 (1): 97–102. doi:10.1016/S1537-5110(03)00112-0. Retrieved 4 March 2018.
254. ^ Beadle, N.C.W. (1940). "Soil temperatures during forest fires and their effect on the survival of vegetation" (PDF). Journal of Ecology. 28 (1): 180–92. doi:10.2307/2256168. JSTOR 2256168. Retrieved 11 March 2018.
255. ^ Barney, Charles W. (1951). "Effects of soil temperature and light intensity on root growth of loblolly pine seedlings". Plant Physiology. 26 (1): 146–63. doi:10.1104/pp.26.1.146. PMC 437627. PMID 16654344.
256. ^ Equiza, Maria A.; Miravé, Juan P. & Tognetti, Jorge A. (2001). "Morphological, anatomical and physiological responses related to differential shoot vs. root growth inhibition at low temperature in spring and winter wheat" (PDF). Annals of Botany. 87 (1): 67–76. doi:10.1006/anbo.2000.1301. Retrieved 17 March 2018.
257. ^ Babalola, Olubukola; Boersma, Larry & Youngberg, Chester T. (1968). "Photosynthesis and transpiration of Monterey pine seedlings as a function of soil water suction and soil temperature" (PDF). Plant Physiology. 43 (4): 515–21. doi:10.1104/pp.43.4.515. PMC 1086880. PMID 16656800. Retrieved 17 March 2018.
258. ^ Gill, Don (1975). "Influence of white spruce trees on permafrost-table microtopography, Mackenzie River Delta" (PDF). Canadian Journal of Earth Sciences. 12 (2): 263–72. Bibcode:1975CaJES..12..263G. doi:10.1139/e75-023. Retrieved 18 March 2018.
259. ^ Coleman, Mark D.; Hinckley, Thomas M.; McNaughton, Geoffrey & Smit, Barbara A. (1992). "Root cold hardiness and native distribution of subalpine conifers" (PDF). Canadian Journal of Forest Research. 22 (7): 932–38. doi:10.1139/x92-124. Retrieved 25 March 2018.
260. ^ Binder, Wolfgang D. & Fielder, Peter (1995). "Heat damage in boxed white spruce (Picea glauca [Moench.] Voss) seedlings: its pre-planting detection and effect on field performance" (PDF). New Forests. 9 (3): 237–59. doi:10.1007/BF00035490. Retrieved 25 March 2018.
261. ^ McMichael, Bobby L. & Burke, John J. (1998). "Soil temperature and root growth" (PDF). HortScience. 33 (6): 947–51. doi:10.21273/HORTSCI.33.6.947. Archived from the original (PDF) on 12 July 2018. Retrieved 1 April 2018.
262. ^ a b Landhäusser, Simon M.; DesRochers, Annie & Lieffers, Victor J. (2001). "A comparison of growth and physiology in Picea glauca and Populus tremuloides at different soil temperatures" (PDF). Canadian Journal of Forest Research. 31 (11): 1922–29. doi:10.1139/x01-129. Retrieved 1 April 2018.
263. ^ Heninger, Ronald L. & White, D.P. (1974). "Tree seedling growth at different soil temperatures" (PDF). Forest Science. 20 (4): 363–67. doi:10.1093/forestscience/20.4.363 (inactive 3 December 2019). Retrieved 1 April 2018.
264. ^ Tryon, Peter R. & Chapin, F. Stuart III (1983). "Temperature control over root growth and root biomass in taiga forest trees". Canadian Journal of Forest Research. 13 (5): 827–33. doi:10.1139/x83-112.
265. ^ Landhäusser, Simon M.; Silins, Uldis; Lieffers, Victor J. & Liu, Wei (2003). "Response of Populus tremuloides, Populus balsamifera, Betula papyrifera and Picea glauca seedlings to low soil temperature and water-logged soil conditions" (PDF). Scandinavian Journal of Forest Research. 18 (5): 391–400. doi:10.1080/02827580310015044. Retrieved 1 April 2018.
266. ^ Turner, N.C. & Jarvis, Paul G. (1975). "Photosynthesis in Sitka spruce (Picea sitchensis (Bong.) Carr. IV. Response to soil temperature". Journal of Applied Ecology. 12 (2): 561–76. doi:10.2307/2402174. JSTOR 2402174.
267. ^ Day, Tolly A.; DeLucia, Evan H. & Smith, William K. (1990). "Effect of soil temperature on stem flow, shoot gas exchange and water potential of Picea engelmannii (Parry) during snowmelt". Oecologia. 84 (4): 474–81. Bibcode:1990Oecol..84..474D. doi:10.1007/bf00328163. JSTOR 4219453. PMID 28312963.
268. ^ Green, D. Scott (2004). "Describing condition-specific determinants of competition in boreal and sub-boreal mixedwood stands". Forestry Chronicle. 80 (6): 736–42. doi:10.5558/tfc80736-6.
269. ^ Davidson, Eric A. & Janssens, Ivan A. (2006). "Temperature sensitivity of soil carbon decomposition and feedbacks to climate change" (PDF). Nature. 440 (7081): 165–73. Bibcode:2006Natur.440..165D. doi:10.1038/nature04514. PMID 16525463. Retrieved 8 April 2018.
270. ^ Schaefer, Kevin; Zhang, Tingjun; Bruhwiler, Lori & Barrett, Andrew P. (2011). "Amount and timing of permafrost carbon release in response to climate warming" (PDF). Tellus B. 63 (2): 165–80. Bibcode:2011TellB..63..165S. doi:10.1111/j.1600-0889.2011.00527.x. Retrieved 8 April 2018.
271. ^ Jorgenson, M. Torre; Racine, Charles H.; Walters, James C. & Osterkamp, Thomas E. (2001). "Permafrost degradation and ecological changes associated with a warming climate in Central Alaska". Climatic Change. 48 (4): 551–79. CiteSeerX 10.1.1.420.5083. doi:10.1023/A:1005667424292.
272. ^ Donahue, Miller & Shickluna 1977, p. 71.
273. ^ "Soil color never lies". European Geosciences Union. Retrieved 25 February 2018.
274. ^ Viscarra Rossel, Raphael A.; Cattle, Stephen R.; Ortega, A. & Fouad, Youssef (2009). "In situ measurements of soil colour, mineral composition and clay content by vis–NIR spectroscopy". Geoderma. 150 (3–4): 253–66. Bibcode:2009Geode.150..253V. CiteSeerX 10.1.1.462.5659. doi:10.1016/j.geoderma.2009.01.025.
275. ^ a b Blavet, Didier; Mathe, E. & Leprun, Jean-Claude (2000). "Relations between soil colour and waterlogging duration in a representative hillside of the West African granito-gneissic bedrock" (PDF). Catena. 39 (3): 187–210. doi:10.1016/S0341-8162(99)00087-9. Retrieved 13 January 2018.
276. ^ Shields, J.A.; Paul, Eldor A.; St. Arnaud, Roland J. & Head, W.K. (1968). "Spectrophotometric measurement of soil color and its relationship to moisture and organic matter". Canadian Journal of Soil Science. 48 (3): 271–80. doi:10.4141/cjss68-037. hdl:10217/81101.
277. ^ a b Barrón, Vidal & Torrent, José (1986). "Use of the Kubelka-Munk theory to study the influence of iron oxides on soil colour" (PDF). Journal of Soil Science. 37 (4): 499–510. doi:10.1111/j.1365-2389.1986.tb00382.x. Retrieved 5 January 2018.
278. ^ Viscarra Rossel, Raphael A.; Cattle, Stephen R.; Ortega, Andres & Fouad, Youssef (2009). "In situ measurements of soil colour, mineral composition and clay content by vis–NIR spectroscopy". Geoderma. 150 (3/4): 253–66. Bibcode:2009Geode.150..253V. CiteSeerX 10.1.1.462.5659. doi:10.1016/j.geoderma.2009.01.025.
279. ^ Ponge, Jean-François; Chevalier, Richard & Loussot, Philippe (2002). "Humus Index: an integrated tool for the assessment of forest floor and topsoil properties" (PDF). Soil Science Society of America Journal. 66 (6): 1996–2001. Bibcode:2002SSASJ..66.1996P. doi:10.2136/sssaj2002.1996. Retrieved 14 January 2018.
280. ^ Maurel, Noelie; Salmon, Sandrine; Ponge, Jean-François; Machon, Nathalie; Moret, Jacques & Muratet, Audrey (2010). "Does the invasive species Reynoutria japonica have an impact on soil and flora in urban wastelands?" (PDF). Biological Invasions. 12 (6): 1709–19. doi:10.1007/s10530-009-9583-4. Retrieved 14 January 2018.
281. ^ Davey, B.G.; Russell, J.D. & Wilson, M. Jeff (1975). "Iron oxide and clay minerals and their relation to colours of red and yellow podzolic soils near Sydney, Australia" (PDF). Geoderma. 14 (2): 125–38. Bibcode:1975Geode..14..125D. doi:10.1016/0016-7061(75)90071-3. Retrieved 21 January 2018.
282. ^ Anderson, Darwin W. (1979). "Processes of humus formation and transformation in soils of the Canadian Great Plains". European Journal of Soil Science. 30 (1): 77–84. doi:10.1111/j.1365-2389.1979.tb00966.x.
283. ^ Vodyanitskii, Yu. N.; Vasil'ev, A.A.; Lessovaia, Sofia N.; Sataev, E.F. & Sivtsov, A.V. (2004). "Formation of manganese oxides in soils" (PDF). Eurasian Soil Science. 37 (6): 572–84. Retrieved 21 January 2018.
284. ^ Fanning, D.S.; Rabenhorst, M.C. & Bigham, J.M. (1993). "Colors of acid sulfate soils". In Bigham, J.M. & Ciolkosz, E.J. (eds.). Soil color (1st ed.). Fitchburg, Wisconsin: Soil Science Society of America. pp. 91–108. ISBN 978-0-89118-926-8.
285. ^ "The color of soil". U.S. Department of Agriculture – Natural Resources Conservation Service. Retrieved 7 January 2018.
286. ^ Noor, Ehteram A. & Al-Moubaraki, Aisha (2014). "Influence of soil moisture content on the corrosion behavior of X60 steel in different soils" (PDF). Arabian Journal for Science and Engineering. 39 (7): 5421–35. doi:10.1007/s13369-014-1135-2. Retrieved 22 April 2018.
287. ^ Amrheln, Christopher; Strong, James E. & Mosher, Paul A. (1992). "Effect of deicing salts on metal and organic matter mobility in roadside soils" (PDF). Environmental Science and Technology. 26 (4): 703–09. Bibcode:1992EnST...26..703A. doi:10.1021/es00028a006. Retrieved 22 April 2018.
288. ^ Samouëlian, Anatja; Cousin, Isabelle; Tabbagh, Alain; Bruand, Ary & Richard, Guy (2005). "Electrical resistivity survey in soil science: a review" (PDF). Soil and Tillage Research. 83 (2): 173–93. CiteSeerX 10.1.1.530.686. doi:10.1016/j.still.2004.10.004. Retrieved 29 April 2018.
289. ^ Wallace, James S. & Batchelor, Charles H. (1997). "Managing water resources for crop production". Philosophical Transactions of the Royal Society B: Biological Sciences. 352 (1356): 937–47. doi:10.1098/rstb.1997.0073. PMC 1691982.
290. ^ Veihmeyer, Frank J. & Hendrickson, Arthur H. (1927). "Soil-moisture conditions in relation to plant growth". Plant Physiology. 2 (1): 71–82. doi:10.1104/pp.2.1.71. PMC 439946. PMID 16652508.
291. ^ Donahue, Miller & Shickluna 1977, p. 72.
292. ^ Van Breemen, Nico & Buurman, Peter (2003). Soil formation (PDF) (2nd ed.). Dordrecht, The Netherlands: Kluwer Academic Publishers. ISBN 978-0-306-48163-5. Retrieved 29 April 2018.
293. ^ Ratliff, Larry F.; Ritchie, Jerry T. & Cassel, D. Keith (1983). "Field-measured limits of soil water availability as related to laboratory-measured properties" (PDF). Soil Science Society of America Journal. 47 (4): 770–75. Bibcode:1983SSASJ..47..770R. doi:10.2136/sssaj1983.03615995004700040032x. Retrieved 29 April 2018.
294. ^ a b c d Wadleigh 1957, p. 48.
295. ^ Richards & Richards 1957, p. 50.
296. ^ Richards & Richards 1957, p. 56.
297. ^ Wadleigh 1957, p. 39.
298. ^ Richards & Richards 1957, p. 52.
299. ^ "Water movement in soils". Oklahoma State University. Retrieved 1 May 2018.
300. ^ Le Bissonnais, Yves (2016). "Aggregate stability and assessment of soil crustability and erodibility. I. Theory and methodology" (PDF). European Journal of Soil Science. 67 (1): 11–21. doi:10.1111/ejss.4_12311. Retrieved 5 May 2018.
301. ^ a b Easton, Zachary M. & Bock, Emily. "Soil and soil water relationships" (PDF). Virginia Tech. Retrieved 5 May 2018.
302. ^ Sims, J. Thomas; Simard, Régis R. & Joern, Brad Christopher (1998). "Phosphorus loss in agricultural drainage: historical perspective and current research" (PDF). Journal of Environmental Quality. 27 (2): 277–93. doi:10.2134/jeq1998.00472425002700020006x. Retrieved 6 May 2018.
303. ^ Brooks, Royal H. & Corey, Arthur T. (1966). "Properties of porous media affecting fluid flow" (PDF). Journal of the Irrigation and Drainage Division. 92 (2): 61–90. Retrieved 6 May 2018.
304. ^ McElrone, Andrew J.; Choat, Brendan; Gambetta, Greg A. & Brodersen, Craig R. "Water uptake and transport in vascular plants". The Nature Education Knowledge Project. Retrieved 6 May 2018.
305. ^ Steudle, Ernst (2000). "Water uptake by plant roots: an integration of views" (PDF). Plant and Soil. 226 (1): 45–56. doi:10.1023/A:1026439226716. Retrieved 6 May 2018.
306. ^ Wilcox, Carolyn S.; Ferguson, Joseph W.; Fernandez, George C.J. & Nowak, Robert S. (2004). "Fine root growth dynamics of four Mojave Desert shrubs as related to soil moisture and microsite" (PDF). Journal of Arid Environments. 56 (1): 129–48. Bibcode:2004JArEn..56..129W. doi:10.1016/S0140-1963(02)00324-5. Retrieved 6 May 2018.
307. ^ Hunter, Albert S. & Kelley, Omer J. (1946). "The extension of plant roots into dry soil". Plant Physiology. 21 (4): 445–51. doi:10.1104/pp.21.4.445. PMC 437296. PMID 16654059.
308. ^ Zhang, Yongqiang; Kendy, Eloise; Qiang, Yu; Liu, Changming; Shen, Yanjun & Sun, Hongyong (2004). "Effect of soil water deficit on evapotranspiration, crop yield, and water use efficiency in the North China Plain" (PDF). Agricultural Water Management. 64 (2): 107–22. doi:10.1016/S0378-3774(03)00201-4. Retrieved 6 May 2018.
309. ^ Oyewole, Olusegun Ayodeji; Inselsbacher, Erich & Näsholm, Torgny (2014). "Direct estimation of mass flow and diffusion of nitrogen compounds in solution and soil" (PDF). New Phytologist. 201 (3): 1056–64. doi:10.1111/nph.12553. PMID 24134319. Retrieved 10 May 2018.
310. ^ "the GCOS Essential Climate Variables". GCOS. 2013. Retrieved 5 November 2013.
311. ^ Brocca, L.; Hasenauer, S.; Lacava, T.; oramarco, T.; Wagner, W.; Dorigo, W.; Matgen, P.; Martínez-Fernández, J.; Llorens, P.; Latron, C.; Martin, C.; Bittelli, M. (2011). "Soil moisture estimation through ASCAT and AMSR-E sensors: An intercomparison and validation study across Europe". Remote Sensing of Environment. 115 (12): 3390–3408. Bibcode:2011RSEnv.115.3390B. doi:10.1016/j.rse.2011.08.003.
312. ^ Donahue, Miller & Shickluna 1977, pp. 72–74.
313. ^ "Soil and water". Food and Agriculture Organization of the United Nations. Retrieved 10 May 2018.
314. ^ Petersen, Lis Wollesen; Møldrup, Per; Jacobsen, Ole H. & Rolston, Dennis E. (1996). "Relations between specific surface area and soil physical and chemical properties" (PDF). Soil Science. 161 (1): 9–21. Bibcode:1996SoilS.161....9P. doi:10.1097/00010694-199601000-00003. Retrieved 10 May 2018.
315. ^ a b Gupta, Satish C. & Larson, William E. (1979). "Estimating soil water retention characteristics from particle size distribution, organic matter percent, and bulk density". Water Resources Research. 15 (6): 1633–35. Bibcode:1979WRR....15.1633G. CiteSeerX 10.1.1.475.497. doi:10.1029/WR015i006p01633.
316. ^ "Soil Water Potential". AgriInfo.in. Archived from the original on 17 August 2017. Retrieved 15 March 2019.
317. ^ Savage, Michael J.; Ritchie, Joe T.; Bland, William L. & Dugas, William A. (1996). "Lower limit of soil water availability" (PDF). Agronomy Journal. 88 (4): 644–51. doi:10.2134/agronj1996.00021962008800040024x. Retrieved 12 May 2018.
318. ^ Al-Ani, Tariq & Bierhuizen, Johan Frederik (1971). "Stomatal resistance, transpiration, and relative water content as influenced by soil moisture stress" (PDF). Acta Botanica Neerlandica. 20 (3): 318–26. doi:10.1111/j.1438-8677.1971.tb00715.x. Retrieved 12 May 2018.
319. ^ Donahue, Miller & Shickluna 1977, pp. 75–76.
320. ^ Rawls, W. J.; Brakensiek, D. L.; Saxtonn, K. E. (1982). "Estimation of Soil Water Properties" (PDF). Transactions of the ASAE. 25 (5): 1316–1320. doi:10.13031/2013.33720. Retrieved 17 March 2019.
321. ^ Donahue, Miller & Shickluna 1977, p. 85.
322. ^ "Soil water movement: saturated and unsaturated flow and vapour movement, soil moisture constants and their importance in irrigation" (PDF). Tamil Nadu Agricultural University. Retrieved 19 May 2018.
323. ^ Donahue, Miller & Shickluna 1977, p. 86.
324. ^ Donahue, Miller & Shickluna 1977, p. 88.
325. ^ Cueto-Felgueroso, Luis & Juanes, Ruben (2008). "Nonlocal interface dynamics and pattern formation in gravity-driven unsaturated flow through porous media" (PDF). Physical Review Letters. 101 (24): 244504. Bibcode:2008PhRvL.101x4504C. doi:10.1103/PhysRevLett.101.244504. PMID 19113626. Retrieved 21 May 2018.
326. ^ "Finger flow in coarse soils". Cornell University. Retrieved 21 May 2018.
327. ^ Ghestem, Murielle; Sidle, Roy C. & Stokes, Alexia (2011). "The influence of plant root systems on subsurface flow: implications for slope stability". BioScience. 61 (11): 869–79. doi:10.1525/bio.2011.61.11.6.
328. ^ Bartens, Julia; Day, Susan D.; Harris, J. Roger; Dove, Joseph E. & Wynn, Theresa M. (2008). "Can urban tree roots improve infiltration through compacted subsoils for stormwater management?" (PDF). Journal of Environmental Quality. 37 (6): 2048–57. doi:10.2134/jeq2008.0117. PMID 18948457. Retrieved 21 May 2018.
329. ^ Zhang, Guohua; Feng, Gary; Li, Xinhu; Xie, Congbao & P, Xiaoyu (2017). "Flood effect on groundwater recharge on a typical silt loam soil". Water. 9 (7): 523. doi:10.3390/w9070523.
330. ^ Nielsen, Donald R.; Biggar, James W. & Erh, Koon T. (1973). "Spatial variability of field-measured soil-water properties". Hilgardia. 42 (7): 215–59. doi:10.3733/hilg.v42n07p215. Archived from the original (PDF) on 12 June 2018. Retrieved 9 June 2018.
331. ^ Rimon, Yaara; Dahan, Ofer; Nativ, Ronit & Geyer, Stefan (2007). "Water percolation through the deep vadose zone and groundwater recharge: preliminary results based on a new vadose zone monitoring system". Water Resources Research. 43 (5): W05402. Bibcode:2007WRR....43.5402R. doi:10.1029/2006WR004855.
332. ^ Weiss, Peter T.; LeFevre, Greg & Gulliver, John S. "Contamination of soil and groundwater due to stormwater infiltration practices: a literature review". CiteSeerX 10.1.1.410.5113. Cite journal requires `|journal=` (help)
333. ^ Hagedorn, Charles; Hansen, Debra T. & Simonson, Gerald H. (1978). "Survival and movement of fecal indicator bacteria in soil under conditions of saturated flow" (PDF). Journal of Environmental Quality. 7 (1): 55–59. doi:10.2134/jeq1978.00472425000700010011x. Retrieved 24 June 2018.
334. ^ Donahue, Miller & Shickluna 1977, p. 90.
335. ^ Donahue, Miller & Shickluna 1977, p. 80.
336. ^ Ng, Charles W.W. & Pang, Wenyan (2000). "Influence of stress state on soil-water characteristics and slope stability" (PDF). Journal of Geotechnical and Geoenvironmental Engineering. 126 (2): 157–66. doi:10.1061/(ASCE)1090-0241(2000)126:2(157). Retrieved 1 July 2018.
337. ^ Richards, L.A. (1931). "Capillary conduction of liquids through porous mediums". Physics. 1 (5): 318–333. Bibcode:1931Physi...1..318R. doi:10.1063/1.1745010.
338. ^ Šimůnek, J.; Saito, H.; Sakai, M.; van Genuchten, M. Th. (2013). "The HYDRUS-1D Software Package for Simulating the One-Dimensional Movement of Water, Heat, and Multiple Solutes in Variably-Saturated Media". Retrieved 15 March 2019.
339. ^ Bouma, Johan (1981). "Soil morphology and preferential flow along macropores" (PDF). Geoderma. 3 (4): 235–50. doi:10.1016/0378-3774(81)90009-3. Retrieved 1 July 2018.
340. ^ Luo, Lifang; Lin, Henry & Halleck, Phil (2008). "Quantifying soil structure and preferential flow in intact soil Using X-ray computed tomography". Soil Science Society of America Journal. 72 (4): 1058–69. Bibcode:2008SSASJ..72.1058L. CiteSeerX 10.1.1.455.2567. doi:10.2136/sssaj2007.0179.
341. ^ Beven, Keith & Germann, Peter (2013). "Macropores and water flow in soils revisited" (PDF). Water Resources Research. 49 (6): 3071–92. Bibcode:2013WRR....49.3071B. doi:10.1002/wrcr.20156.
342. ^ Aston, M.J. & Lawlor, David W. (1979). "The relationship between transpiration, root water uptake, and leaf water potential" (PDF). Journal of Experimental Botany. 30 (1): 169–81. doi:10.1093/jxb/30.1.169. Retrieved 8 July 2018.
343. ^ Powell, D.B.B. (1978). "Regulation of plant water potential by membranes of the endodermis in young roots" (PDF). Plant, Cell and Environment. 1 (1): 69–76. doi:10.1111/j.1365-3040.1978.tb00749.x. Retrieved 7 July 2018.
344. ^ Irvine, James; Perks, Michael P.; Magnani, Federico & Grace, John (1998). "The response of Pinus sylvestris to drought: stomatal control of transpiration and hydraulic conductance". Tree Physiology. 18 (6): 393–402. doi:10.1093/treephys/18.6.393. PMID 12651364.
345. ^ Jackson, Robert B.; Sperry, John S. & Dawson, Todd E. (2000). "Root water uptake and transport: using physiological processes in global predictions" (PDF). Trends in Plant Science. 5 (11): 482–88. doi:10.1016/S1360-1385(00)01766-0. PMID 11077257. Retrieved 8 July 2018.
346. ^ Steudle, Ernst (2000). "Water uptake by plant roots: an integration of views" (PDF). Plant and Soil. 226 (1): 45–56. doi:10.1023/A:1026439226716. Retrieved 8 July 2018.
347. ^ Donahue, Miller & Shickluna 1977, p. 92.
348. ^ Kaufmann, Merrill R. & Eckard, Alan N. (1971). "Evaluation of water stress control with polyethylene glycols by analysis of guttation". Plant Physiology. 47 (4): 453–6. doi:10.1104/pp.47.4.453. PMC 396708. PMID 16657642.
349. ^ Wadleigh 1957, p. 46.
350. ^ Kramer, Paul J. & Coile, Theodore S. (1940). "An estimation of the volume of water made available by root extension". Plant Physiology. 15 (4): 743–47. doi:10.1104/pp.15.4.743. PMC 437871. PMID 16653671.
351. ^ Lynch, Jonathan (1995). "Root architecture and plant productivity". Plant Physiology. 109 (1): 7–13. doi:10.1104/pp.109.1.7. PMC 157559. PMID 12228579.
352. ^ Comas, Louise H.; Eissenstat, David M. & Lakso, Alan N. (2000). "Assessing root death and root system dynamics in a study of grape canopy pruning". New Phytologist. 147 (1): 171–78. doi:10.1046/j.1469-8137.2000.00679.x.
353. ^ a b Donahue, Miller & Shickluna 1977, p. 94.
354. ^ Schlesinger, William H. & Jasechko, Scott (2014). "Transpiration in the global water cycle" (PDF). Agricultural and Forest Meteorology. 189/190: 115–17. Bibcode:2014AgFM..189..115S. doi:10.1016/j.agrformet.2014.01.011. Retrieved 22 July 2018.
355. ^ Erie, Leonard J.; French, Orrin F. & Harris, Karl (1968). Consumptive use of water by crops in Arizona (PDF). Tucson, Arizona: The University of Arizona. Retrieved 15 July 2018.
356. ^ Tolk, Judy A.; Howell, Terry A. & Evett, Steve R. (1999). "Effect of mulch, irrigation, and soil type on water use and yield of maize" (PDF). Soil and Tillage Research. 50 (2): 137–47. doi:10.1016/S0167-1987(99)00011-2. Retrieved 15 July 2018.
357. ^ Donahue, Miller & Shickluna 1977, pp. 97–99.
358. ^ Qi, Jingen; Marshall, John D. & Mattson, Kim G. (1994). "High soil carbon dioxide concentrations inhibit root respiration of Douglas fir". New Phytologist. 128 (3): 435–42. doi:10.1111/j.1469-8137.1994.tb02989.x.
359. ^ Karberg, Noah J.; Pregitzer, Kurt S.; King, John S.; Friend, Aaron L. & Wood, James R. (2005). "Soil carbon dioxide partial pressure and dissolved inorganic carbonate chemistry under elevated carbon dioxide and ozone" (PDF). Oecologia. 142 (2): 296–306. Bibcode:2005Oecol.142..296K. doi:10.1007/s00442-004-1665-5. PMID 15378342. Retrieved 26 August 2018.
360. ^ Chang, H.T. & Loomis, W.E. (1945). "Effect of carbon dioxide on absorption of water and nutrients by roots". Plant Physiology. 20 (2): 221–32. doi:10.1104/pp.20.2.221. PMC 437214. PMID 16653979.
361. ^ McDowell, Nate J.; Marshall, John D.; Qi, Jingen & Mattson, Kim (1999). "Direct inhibition of maintenance respiration in western hemlock roots exposed to ambient soil carbon dioxide concentrations" (PDF). Tree Physiology. 19 (9): 599–605. doi:10.1093/treephys/19.9.599. PMID 12651534. Retrieved 22 July 2018.
362. ^ Xu, Xia; Nieber, John L. & Gupta, Satish C. (1992). "Compaction effect on the gas diffusion coefficient in soils" (PDF). Soil Science Society of America Journal. 56 (6): 1743–50. Bibcode:1992SSASJ..56.1743X. doi:10.2136/sssaj1992.03615995005600060014x. Retrieved 29 July 2018.
363. ^ a b Smith, Keith A.; Ball, Tom; Conen, Franz; Dobbie, Karen E.; Massheder, Jonathan & Rey, Ana (2003). "Exchange of greenhouse gases between soil and atmosphere: interactions of soil physical factors and biological processes" (PDF). European Journal of Soil Science. 54 (4): 779–91. doi:10.1046/j.1351-0754.2003.0567.x. Retrieved 5 August 2018.
364. ^ Russell 1957, pp. 35–36.
365. ^ Ruser, Reiner; Flessa, Heiner; Russow, Rolf; Schmidt, G.; Buegger, Franz & Munch, J.C. (2006). "Emission of N2O, N2 and CO2 from soil fertilized with nitrate: effect of compaction, soil moisture and rewetting" (PDF). Soil Biology and Biochemistry. 38 (2): 263–74. Bibcode:1992SSASJ..56.1743X. doi:10.1016/j.soilbio.2005.05.005. Retrieved 5 August 2018.
366. ^ Hartmann, Adrian A.; Buchmann, Nina & Niklaus, Pascal A. (2011). "A study of soil methane sink regulation in two grasslands exposed to drought and N fertilization" (PDF). Plant and Soil. 342 (1/2): 265–75. doi:10.1007/s11104-010-0690-x. Retrieved 12 August 2018.
367. ^ Moore, Tim R. & Dalva, Moshe (1993). "The influence of temperature and water table position on carbon dioxide and methane emissions from laboratory columns of peatland soils" (PDF). Journal of Soil Science. 44 (4): 651–64. doi:10.1111/j.1365-2389.1993.tb02330.x. Retrieved 12 August 2018.
368. ^ Hiltpold, Ivan; Toepfer, Stefan; Kuhlmann, Ulrich & Turlings, Ted C.J. (2010). "How maize root volatiles affect the efficacy of entomopathogenic nematodes in controlling the western corn rootworm?" (PDF). Chemoecology. 20 (2): 155–62. doi:10.1007/s00049-009-0034-6. Retrieved 12 August 2018.
369. ^ Ryu, Choong-Min; Farag, Mohamed A.; Hu, Chia-Hui; Reddy, Munagala S.; Wei, Han-Xun; Paré, Paul W. & Kloepper, Joseph W. (2003). "Bacterial volatiles promote growth in Arabidopsis" (PDF). Proceedings of the National Academy of Sciences of the United States of America. 100 (8): 4927–32. Bibcode:2003PNAS..100.4927R. doi:10.1073/pnas.0730845100. PMC 153657. PMID 12684534. Retrieved 12 August 2018.
370. ^ Hung, Richard; Lee, Samantha & Bennett, Joan W. (2015). "Fungal volatile organic compounds and their role in ecosystems" (PDF). Applied Microbiology and Biotechnology. 99 (8): 3395–405. doi:10.1007/s00253-015-6494-4. PMID 25773975. Retrieved 12 August 2018.
371. ^ Purrington, Foster Forbes; Kendall, Paricia A.; Bater, John E. & Stinner, Benjamin R. (1991). "Alarm pheromone in a gregarious poduromorph collembolan (Collembola: Hypogastruridae)" (PDF). Great Lakes Entomologist. 24 (2): 75–78. Retrieved 12 August 2018.
372. ^ Badri, Dayakar V.; Weir, Tiffany L.; Van der Lelie, Daniel & Vivanco, Jorge M. (2009). "Rhizosphere chemical dialogues: plant–microbe interactions". Current Opinion in Biotechnology. 20 (6): 642–50. doi:10.1016/j.copbio.2009.09.014. PMID 19875278.
373. ^ Salmon, Sandrine & Ponge, Jean-François (2001). "Earthworm excreta attract soil springtails: laboratory experiments on Heteromurus nitidus (Collembola: Entomobryidae)" (PDF). Soil Biology and Biochemistry. 33 (14): 1959–69. doi:10.1016/S0038-0717(01)00129-8. Retrieved 19 August 2018.
374. ^ Lambers, Hans; Mougel, Christophe; Jaillard, Benoît & Hinsinger, Philipe (2009). "Plant-microbe-soil interactions in the rhizosphere: an evolutionary perspective" (PDF). Plant and Soil. 321 (1/2): 83–115. doi:10.1007/s11104-009-0042-x. Retrieved 19 August 2018.
375. ^ Peñuelas, Josep; Asensio, Dolores; Tholl, Dorothea; Wenke, Katrin; Rosenkranz, Maaria; Piechulla, Birgit & Schnitzler, Jörg-Petter (2014). "Biogenic volatile emissions from the soil". Plant, Cell and Environment. 37 (8): 1866–91. doi:10.1111/pce.12340. PMID 24689847.
376. ^ Buzuleciu, Samuel A.; Crane, Derek P. & Parker, Scott L. (2016). "Scent of disinterred soil as an olfactory cue used by raccoons to locate nests of diamond-backed terrapins (Malaclemys terrapin)" (PDF). Herpetological Conservation and Biology. 11 (3): 539–51. Retrieved 19 August 2018.
377. ^ Saxton, Keith E. & Rawls, Walter J. (2006). "Soil water characteristic estimates by texture and organic matter for hydrologic solutions" (PDF). Soil Science Society of America Journal. 70 (5): 1569–78. Bibcode:2006SSASJ..70.1569S. CiteSeerX 10.1.1.452.9733. doi:10.2136/sssaj2005.0117. Retrieved 2 September 2018.
378. ^ College of Tropical Agriculture and Human Resources. "Soil Mineralogy". cms.ctahr.hawaii.edu/. University of Hawai‘i at Mānoa. Retrieved 2 September 2018.
379. ^ a b Russell, E. Walter (1973). Soil conditions and plant growth (10th ed.). London: Longman. pp. 67–70. ISBN 978-0-582-44048-7.
380. ^ Mercader, Julio; Bennett, Tim; Esselmont, Chris; Simpson, Steven & Walde, Dale (2011). "Soil phytoliths from miombo woodlands in Mozambique" (PDF). Quaternary Research. 75 (1): 138–50. Bibcode:2011QuRes..75..138M. doi:10.1016/j.yqres.2010.09.008. Retrieved 9 September 2018.
381. ^ Sleep, Norman H. & Hessler, Angela M. (2006). "Weathering of quartz as an Archean climatic indicator" (PDF). Earth and Planetary Science Letters. 241 (3–4): 594–602. Bibcode:2006E&PSL.241..594S. doi:10.1016/j.epsl.2005.11.020. Retrieved 9 September 2018.
382. ^ Banfield, Jillian F.; Barker, William W.; Welch, Susan A. & Taunton, Anne (1999). "Biological impact on mineral dissolution: application of the lichen model to understanding mineral weathering in the rhizosphere" (PDF). Proceedings of the National Academy of Sciences of the United States of America. 96 (7): 3404–11. Bibcode:1999PNAS...96.3404B. doi:10.1073/pnas.96.7.3404. PMC 34281. PMID 10097050. Retrieved 9 September 2018.
383. ^ Santamarina, J. Carlos; Klein, Katherine A.; Wang, Yu-Hsing & Prencke, E. (2002). "Specific surface: determination and relevance" (PDF). Canadian Geotechnical Journal. 39 (1): 233–41. doi:10.1139/t01-077. Retrieved 30 September 2018.
384. ^ Tombácz, Etelka & Szekeres, Márta (2006). "Surface charge heterogeneity of kaolinite in aqueous suspension in comparison with montmorillonite" (PDF). Applied Clay Science. 34 (1–4): 105–24. doi:10.1016/j.clay.2006.05.009. Retrieved 30 September 2018.
385. ^ Brown, George (1984). "Crystal structures of clay minerals and related phyllosilicates" (PDF). Philosophical Transactions of the Royal Society of London. Series B, Biological Sciences. 311 (1517): 221–40. Bibcode:1984RSPTA.311..221B. doi:10.1098/rsta.1984.0025. Retrieved 30 September 2018.
386. ^ Hillier, Stephen (1978). "Clay mineralogy" (PDF). In Middleton, Gerard V.; Church, Michael J.; Coniglio, Mario; Hardie, Lawrence A.; Longstaffe, Frederick J. (eds.). Encyclopedia of sediments and Sedimentary rocks. Encyclopedia of Earth Science. Dordrecht, The Netherlands: Springer Science+Business Media B.V. pp. 139–42. doi:10.1007/3-540-31079-7_47. ISBN 978-0-87933-152-8. Retrieved 30 September 2018.
387. ^ Donahue, Miller & Shickluna 1977, pp. 101–02.
388. ^ Bergaya, Faïza; Beneke, Klaus; Lagaly, Gerhard. "History and perspectives of clay science" (PDF). University of Kiel. Retrieved 20 October 2018.
389. ^ Wilson, M. Jeff (1999). "The origin and formation of clay minerals in soils: past, present and future perspectives" (PDF). Clay Minerals. 34 (1): 7–25. Bibcode:1999ClMin..34....7W. doi:10.1180/000985599545957. Archived from the original (PDF) on 29 March 2018. Retrieved 20 October 2018.
390. ^ Simonson 1957, p. 19.
391. ^ Churchman, G. Jock (1980). "Clay minerals formed from micas and chlorites in some New Zealand soils" (PDF). Clay Minerals. 15 (1): 59–76. Bibcode:1980ClMin..15...59C. doi:10.1180/claymin.1980.015.1.05. Retrieved 20 October 2018.
392. ^ Wada, Koji; Greenland, Dennis J. (1970). "Selective dissolution and differential infrared spectroscopy for characterization of 'amorphous' constituents in soil clays". Clay Minerals. 8 (3): 241–54. Bibcode:1970ClMin...8..241W. CiteSeerX 10.1.1.624.1439. doi:10.1180/claymin.1970.008.3.02.
393. ^ Donahue, Miller & Shickluna 1977, p. 102.
394. ^ "The clay mineral group" (PDF). Amethyst Galleries, Inc. Retrieved 28 October 2018.
395. ^ Schulze, Darrell G. (2005). "Clay minerals" (PDF). In Hillel, Daniel (ed.). Encyclopedia of soils in the environment. Amsterdam: Academic Press. pp. 246–54. doi:10.1016/b0-12-348530-4/00189-2. ISBN 9780123485304. Retrieved 28 October 2018.
396. ^ a b Russell 1957, p. 33.
397. ^ Tambach, Tim J.; Bolhuis, Peter G.; Hensen, Emiel J.M.; Smit, Berend (2006). "Hysteresis in clay swelling induced by hydrogen bonding: accurate prediction of swelling states" (PDF). Langmuir. 22 (3): 1223–34. doi:10.1021/la051367q. PMID 16430287. Retrieved 3 November 2018.
398. ^ Donahue, Miller & Shickluna 1977, pp. 102–07.
399. ^ Donahue, Miller & Shickluna 1977, pp. 101–07.
400. ^ Aylmore, L.A. Graham & Quirk, James P. (1971). "Domains and quasicrystalline regions in clay systems" (PDF). Soil Science Society of America Journal. 35 (4): 652–54. Bibcode:1971SSASJ..35..652Q. doi:10.2136/sssaj1971.03615995003500040046x. Retrieved 18 November 2018.
401. ^ a b Barton, Christopher D.; Karathanasis, Anastasios D. (2002). "Clay minerals" (PDF). In Lal, Rattan (ed.). Encyclopedia of Soil Science. New York: Marcel Dekker. pp. 187–92. Retrieved 3 November 2018.
402. ^ Schoonheydt, Robert A.; Johnston, Cliff T. (2011). "The surface properties of clay minerals" (PDF). In Brigatti, Maria Franca; Mottana, Annibale (eds.). Layered mineral structures and their application in advanced technologies. Twickenham, UK: Mineralogical Society of Great Britain & Ireland. pp. 337–73. Retrieved 2 December 2018.
403. ^ Donahue, Miller & Shickluna 1977, p. 107.
404. ^ Lagaly, Gerhard (1979). "The "layer charge" of regular interstratified 2:1 clay minerals". Clays and Clay Minerals. 27 (1): 1–10. Bibcode:1979CCM....27....1L. doi:10.1346/CCMN.1979.0270101.
405. ^ Eirish, M. V.; Tret'yakova, L. I. (1970). "The role of sorptive layers in the formation and change of the crystal structure of montmorillonite" (PDF). Clay Minerals. 8 (3): 255–66. Bibcode:1970ClMin...8..255E. doi:10.1180/claymin.1970.008.3.03. Archived from the original (PDF) on 19 July 2018. Retrieved 2 December 2018.
406. ^ Tardy, Yves; Bocquier, Gérard; Paquet, Hélène; Millot, Georges (1973). "Formation of clay from granite and its distribution in relation to climate and topography" (PDF). Geoderma. 10 (4): 271–84. Bibcode:1973Geode..10..271T. doi:10.1016/0016-7061(73)90002-5. Retrieved 15 December 2018.
407. ^ Donahue, Miller & Shickluna 1977, p. 108.
408. ^ a b Russell 1957, pp. 33–34.
409. ^ a b Coleman & Mehlich 1957, p. 74.
410. ^ Meunier, Alain; Velde, Bruce (2004). "The geology of illite" (PDF). Illite: origins, evolution and metamorphism. Berlin: Springer. pp. 63–143. Retrieved 15 December 2018.
411. ^ Donahue, Miller & Shickluna 1977, pp. 108–10.
412. ^ a b Dean 1957, p. 82.
413. ^ a b c Allison 1957, p. 90.
414. ^ a b Reitemeier 1957, p. 103.
415. ^ Norrish, Keith; Rausell-Colom, José Antonio (1961). "Low-angle X-ray diffraction studies of the swelling of montmorillonite and vermiculite". Clays and Clay Minerals. 10 (1): 123–49. Bibcode:1961CCM....10..123N. doi:10.1346/CCMN.1961.0100112.
416. ^ a b Donahue, Miller & Shickluna 1977, p. 110.
417. ^ Coleman & Mehlich 1957, p. 73.
418. ^ Moore, Duane M.; Reynolds, Robert C. Jr (1997). X-ray diffraction and the identification and analysis of clay minerals (PDF). Oxford: Oxford University Press. Retrieved 16 December 2018.
419. ^ Holmes & Brown 1957, p. 112.
420. ^ Karathanasis, Anastasios D.; Hajek, Benjamin F. (1983). "Transformation of smectite to kaolinite in naturally acid soil systems: structural and thermodynamic considerations". Soil Science Society of America Journal. 47 (1): 158–63. Bibcode:1983SSASJ..47..158K. doi:10.2136/sssaj1983.03615995004700010031x.
421. ^ Tombácz, Etelka; Szekeres, Márta (2006). "Surface charge heterogeneity of kaolinite in aqueous suspension in comparison with montmorillonite" (PDF). Applied Clay Science. 34 (1–4): 105–24. doi:10.1016/j.clay.2006.05.009. Retrieved 16 February 2019.
422. ^ Coles, Cynthia A.; Yong, Raymond N. (2002). "Aspects of kaolinite characterization and retention of Pb and Cd" (PDF). Applied Clay Science. 22 (1–2): 39–45. CiteSeerX 10.1.1.576.3783. doi:10.1016/S0169-1317(02)00110-2. Retrieved 24 February 2019.
423. ^ Fisher, G. Burch; Ryan, Peter C. (2006). "The smectite-to-disordered kaolinite transition in a tropical soil chronosequence, Pacific coast, Costa Rica" (PDF). Clays and Clay Minerals. 54 (5): 571–86. Bibcode:2006CCM....54..571F. doi:10.1346/CCMN.2006.0540504. Retrieved 24 February 2019.
424. ^ a b Donahue, Miller & Shickluna 1977, p. 111.
425. ^ a b Olsen & Fried 1957, p. 96.
426. ^ Reitemeier 1957, p. 101.
427. ^ Hamdi-Aïssa, Belhadj; Vallès, Vincent; Aventurier, Alain; Ribolzi, Olivier (2004). "Soils and brine geochemistry and mineralogy of hyperarid Desert Playa, Ouargla Basin, Algerian Sahara" (PDF). Arid Land Research and Management. 18 (2): 103–26. doi:10.1080/1532480490279656. Retrieved 24 February 2019.
428. ^ Shoji, Sadao; Saigusa, Masahiko (1977). "Amorphous clay materials of Towada Ando soils". Soil Science and Plant Nutrition. 23 (4): 437–55. doi:10.1080/00380768.1977.10433063.
429. ^ Tardy, Yves; Nahon, Daniel (1985). "Geochemistry of laterites, stability of Al-goethite, Al-hematite, and Fe3+-kaolinite in bauxites and ferricretes: an approach to the mechanism of concretion formation" (PDF). American Journal of Science. 285 (10): 865–903. doi:10.2475/ajs.285.10.865. Retrieved 10 March 2019.
430. ^ Nieuwenhuyse, André; Verburg, Paul S.J.; Jongmans, Antoine G. (2000). "Mineralogy of a soil chronosequence on andesitic lava in humid tropical Costa Rica" (PDF). Geoderma. 98 (1–2): 61–82. Bibcode:2000Geode..98...61N. doi:10.1016/S0016-7061(00)00052-5. Retrieved 10 March 2019.
431. ^ Hunt, James F.; Ohno, Tsutomu; He, Zhongqi; Honeycutt, C. Wayne; Dail, D. Bryan (2007). "Inhibition of phosphorus sorption to goethite, gibbsite, and kaolin by fresh and decomposed organic matter" (PDF). Biology and Fertility of Soils. 44 (2): 277–88. doi:10.1007/s00374-007-0202-1. Retrieved 10 March 2019.
432. ^ Shamshuddin, Jusop; Anda, Markus (2008). "Charge properties of soils in Malaysia dominated by kaolinite, gibbsite, goethite and hematite" (PDF). Bulletin of the Geological Society of Malaysia. 54: 27–31. doi:10.7186/bgsm54200805. Retrieved 10 March 2019.
433. ^ Donahue, Miller & Shickluna 1977, pp. 103–12.
434. ^ Simonson 1957, pp. 18, 21–24, 29.
435. ^ Russell 1957, pp. 32, 35.
436. ^ Paul, Eldor A.; Campbell, Colin A.; Rennie, David A. & McCallum, Kenneth J. (1964). "Investigations of the dynamics of soil humus utilizing carbon dating techniques" (PDF). Transactions of the 8th International Congress of Soil Science, Bucharest, Romania, 1964. Bucharest, Romania: Publishing House of the Academy of the Socialist Republic of Romania. pp. 201–08. Retrieved 16 March 2019.
437. ^ Bin, Gao; Cao, Xinde; Dong, Yan; Luo, Yongming & Ma, Lena Q. (2011). "Colloid deposition and release in soils and their association with heavy metals" (PDF). Critical Reviews in Environmental Science and Technology. 41 (4): 336–72. doi:10.1080/10643380902871464. Retrieved 24 March 2019.
438. ^ Six, Johan; Frey, Serita D.; Thiet, Rachel K. & Batten, Katherine M. (2006). "Bacterial and fungal contributions to carbon sequestration in agroecosystems" (PDF). Soil Science Society of America Journal. 70 (2): 555–69. Bibcode:2006SSASJ..70..555S. CiteSeerX 10.1.1.461.9539. doi:10.2136/sssaj2004.0347. Retrieved 16 March 2019.
439. ^ Donahue, Miller & Shickluna 1977, p. 112.
440. ^ Russell 1957, p. 35.
441. ^ Allaway 1957, p. 69.
442. ^ Thornton, Peter E.; Doney, Scott C.; Lindsay, Konkel; Moore, J. Keith; Mahowald, Natalie; Randerson, James T.; Fung, Inez; Lamarque, Jean-François; Feddema, Johannes J. & Lee, Y. Hanna (2009). "Carbon-nitrogen interactions regulate climate-carbon cycle feedbacks: results from an atmosphere-ocean general circulation model". Biogeosciences. 6 (10): 2099–120. doi:10.5194/bg-6-2099-2009.
443. ^ Morgan, Jack A.; Follett, Ronald F.; Allen Jr, Leon Hartwell; Del Grosso, Stephen; Derner, Justin D.; Dijkstra, Feike; Franzluebbers, Alan; Fry, Robert; Paustian, Keith & Schoeneberger, Michele M. (2010). "Carbon sequestration in agricultural lands of the United States" (PDF). Journal of Soil and Water Conservation. 65 (1): 6A–13A. doi:10.2489/jswc.65.1.6A. Retrieved 24 March 2019.
444. ^ Parton, Willam J.; Scurlock, Jonathan M. O.; Ojima, Dennis S.; Schimel, David; Hall, David O. & The SCOPEGRAM Group (1995). "Impact of climate change on grassland production and soil carbon worldwide" (PDF). Global Change Biology. 1 (1): 13–22. Bibcode:1995GCBio...1...13P. doi:10.1111/j.1365-2486.1995.tb00002.x. Retrieved 24 March 2019.
445. ^ Schuur, Edward A. G.; Vogel, Jason G.; Crummer, Kathryn G.; Lee, Hanna; Sickman, James O. & Osterkamp, T. E. (2009). "The effect of permafrost thaw on old carbon release and net carbon exchange from tundra" (PDF). Nature. 459 (7246): 556–59. Bibcode:2009Natur.459..556S. doi:10.1038/nature08031. PMID 19478781. Retrieved 24 March 2019.
446. ^ Wieder, William R.; Cleveland, Cory C. & Townsend, Alan R. (2009). "Controls over leaf litter decomposition in wet tropical forests" (PDF). Ecology. 90 (12): 3333–41. doi:10.1890/08-2294.1. PMID 20120803. Retrieved 31 March 2019.
447. ^ Stark, Nellie M. & Lordan, Carl F. (1978). "Nutrient retention by the root mat of an Amazonian rain forest" (PDF). Ecology. 59 (3): 434–37. doi:10.2307/1936571. JSTOR 1936571. Retrieved 31 March 2019.
448. ^ Liang, Biqing; Lehmann, Johannes; Solomon, Dawit; Kinyangi, James; Grossman, Julie; O'Neill, Brendan; Skjemstad, Jan O.; Thies, Janice; Luizaõ, Flávio J.; Petersen, Julie & Neves, Eduardo G. (2006). "Black carbon increases cation exchange capacity in soils" (PDF). Soil Science Society of America Journal. 70 (5): 1719–30. Bibcode:2006SSASJ..70.1719L. doi:10.2136/sssaj2005.0383. Retrieved 30 March 2019.
449. ^ Neves, Eduardo G.; Petersen, James B.; Bartone, Robert N.; da Silva, Carlos Augusto (2003). "Historical and socio-cultural origins of Amazonian Dark Earth" (PDF). In Lehmann, Johannes; Kern, Dirse C.; Glaser, Bruno; Woods, William I. (eds.). Amazonian Dark Earths: origin, properties, management. Berlin, Germany: Springer Science & Business Media. pp. 29–50. Retrieved 7 April 2019.
450. ^ Ponge, Jean-François; Topoliantz, Stéphanie; Ballof, Sylvain; Rossi, Jean-Pierre; Lavelle, Patrick; Betsch, Jean-Marie & Gaucher, Philippe (2006). "Ingestion of charcoal by the Amazonian earthworm Pontoscolex corethrurus: a potential for tropical soil fertility" (PDF). Soil Biology and Biochemistry. 38 (7): 2008–09. doi:10.1016/j.soilbio.2005.12.024. Retrieved 7 April 2019.
451. ^ Lehmann, Johannes. "Terra Preta de Indio". University of Cornell, Department of Crop and Soil Sciences. Archived from the original on 24 April 2013. Retrieved 7 April 2019.
452. ^ Lehmann, Johannes; Rondon, Marco (2006). "Bio-char soil management on highly weathered soils in the humid tropics" (PDF). In Uphoff, Norman; Ball, Andrew S.; Fernandes, Erick; Herren, Hans; Husson, Olivier; Laing, Mark; Palm, Cheryl; Pretty, Jules; Sánchez, Pedro; Sanginga, Nteranya; Thies, Janice (eds.). Biological approaches to sustainable soil systems. Boca Raton, Florid: CRC Press. pp. 517–30. Retrieved 14 April 2019.
453. ^ Yu, Xiangyang; Pan, Ligang; Ying, Guangguo & Kookana, Rai S. (2010). "Enhanced and irreversible sorption of pesticide pyrimethanil by soil amended with biochars" (PDF). Journal of Environmental Sciences. 22 (4): 615–20. doi:10.1016/S1001-0742(09)60153-4. PMID 20617740. Retrieved 14 April 2019.
454. ^ Whitman, Thea & Lehmann, Johannes (2009). "Biochar: one way forward for soil carbon in offset mechanisms in Africa?" (PDF). Environmental Science and Policy. 12 (7): 1024–27. doi:10.1016/j.envsci.2009.07.013. Retrieved 14 April 2019.
455. ^ Mwampamba, Tuyeni Heita (2007). "Has the woodfuel crisis returned? Urban charcoal consumption in Tanzania and its implications to present and future forest availability" (PDF). Energy Policy. 35 (8): 4221–34. doi:10.1016/j.enpol.2007.02.010. Retrieved 14 April 2019.
456. ^ Sposito, Garrison (1984). The surface chemistry of soils (PDF). New York, New York: Oxford University Press. Retrieved 21 April 2019.
457. ^ Wynot, Christopher. "Theory of diffusion in colloidal suspensions" (PDF). Retrieved 21 April 2019.
458. ^ Donahue, Miller & Shickluna 1977, p. 103–06.
459. ^ Bickmore, Barry R.; Rosso, Kevin M.; Nagy, Kathryn L.; Cygan, Randall T. & Tadanier, Christopher J. (2003). "Ab initio determination of edge surface structures for dioctahedral 2:1 phyllosilicates: implications for acid-base reactivity" (PDF). Clays and Clay Minerals. 51 (4): 359–71. Bibcode:2003CCM....51..359B. doi:10.1346/CCMN.2003.0510401. Retrieved 21 April 2019.
460. ^ Rajamathi, Michael; Thomas, Grace S. & Kamath, P. Vishnu (2001). "The many ways of making anionic clays" (PDF). Journal of Chemical Sciences. 113 (5–6): 671–80. doi:10.1007/BF02708799. Retrieved 27 April 2019.
461. ^ Moayedi, Hossein & Kazemian, Sina (2012). "Zeta potentials of suspended humus in multivalent cationic saline solution and its effect on electro-osomosis behavior" (PDF). Journal of Dispersion Science and Technology. 34 (2): 283–94. doi:10.1080/01932691.2011.646601. Retrieved 27 April 2019.
462. ^ Pettit, Robert E. "Organic matter, humus, humate, humic acid, fulvic acid and humin: their importance in soil fertility and plant health" (PDF). Retrieved 27 April 2019.
463. ^ Diamond, Sidney & Kinter, Earl B. (1965). "Mechanisms of soil-lime stabilization: an interpretative review" (PDF). Highway Research Record. 92: 83–102. Retrieved 27 April 2019.
464. ^ Woodruff, Clarence M. (1955). "The energies of replacement of calcium by potassium in soils" (PDF). Soil Science Society of America Journal. 19 (2): 167–71. Bibcode:1955SSASJ..19..167W. doi:10.2136/sssaj1955.03615995001900020014x. Retrieved 28 April 2019.
465. ^ Fronæus, Sture (1953). "On the application of the mass action law to cation exchange equilibria" (PDF). Acta Chemica Scandinavica. 7: 469–80. doi:10.3891/acta.chem.scand.07-0469. Retrieved 4 May 2019.
466. ^ Bolland, Mike D. A.; Posner, Alan M.; Quirk, James P. (1980). "pH-independent and pH-dependent surface charges on kaolinite". Clays and Clay Minerals. 28 (6): 412–18. Bibcode:1980CCM....28..412B. doi:10.1346/CCMN.1980.0280602.
467. ^ Silber, Avner; Levkovitch, Irit; Graber, Ellen R. (2010). "pH-dependent mineral release and surface properties of cornstraw biochar: agronomic implications" (PDF). Environmental Science and Technology. 44 (24): 9318–23. Bibcode:2010EnST...44.9318S. doi:10.1021/es101283d. PMID 21090742. Retrieved 4 May 2019.
468. ^ Dakora, Felix D.; Phillips, Donald D. (2002). "Root exudates as mediators of mineral acquisition in low-nutrient environments" (PDF). Plant and Soil. 245: 35–47. doi:10.1023/A:1020809400075. Retrieved 25 July 2019.
469. ^ Donahue, Miller & Shickluna 1977, p. 114.
470. ^ Singh, Jamuna Sharan; Raghubanshi, Akhilesh Singh; Singh, Raj S. & Srivastava, S. C. (1989). "Microbial biomass acts as a source of plant nutrient in dry tropical forest and savanna" (PDF). Nature. 338 (6215): 499–500. Bibcode:1989Natur.338..499S. doi:10.1038/338499a0. Retrieved 12 May 2019.
471. ^ Szatanik-Kloc, Alicja; Szerement, Justyna & Józefaciuk, Grzegorz (2017). "The role of cell walls and pectins in cation exchange and surface area of plant roots" (PDF). Journal of Plant Physiology. 215: 85–90. doi:10.1016/j.jplph.2017.05.017. PMID 28600926. Retrieved 25 July 2019.
472. ^ a b Donahue, Miller & Shickluna 1977, pp. 115–16.
473. ^ Gu, Baohua; Schulz, Robert K. "Anion retention in soil: possible application to reduce migration of buried technetium and iodine, a review" (PDF). Retrieved 19 May 2019.
474. ^ Sollins, Phillip; Robertson, G. Philip & Uehara, Goro (1988). "Nutrient mobility in variable- and permanent-charge soils" (PDF). Biogeochemistry. 6 (3): 181–99. doi:10.1007/BF02182995. Retrieved 19 May 2019.
475. ^ Sanders, W. M. H. (1964). "Extraction of soil phosphate by anion-exchange membrane". New Zealand Journal of Agricultural Research. 7 (3): 427–31. doi:10.1080/00288233.1964.10416423.
476. ^ Hinsinger, Philippe (2001). "Bioavailability of soil inorganic P in the rhizosphere as affected by root-induced chemical changes: a review" (PDF). Plant and Soil. 237 (2): 173–95. doi:10.1023/A:1013351617532. Retrieved 19 May 2019.
477. ^ Chichester, Fredrick Wesley; Harward, Moyle E. & Youngberg, Chester T. (1970). "pH dependent ion exchange properties of soils and clays from Mazama pumice". Clays and Clay Minerals. 18 (2): 81–90. Bibcode:1970CCM....18...81C. doi:10.1346/CCMN.1970.0180203.
478. ^ Robertson, Bryan. "pH requirements of freshwater aquatic life" (PDF). Retrieved 26 May 2019.
479. ^ Chang, Raymond, ed. (2010). Chemistry (PDF) (10th ed.). New York, New York: McGraw-Hill. p. 663. ISBN 9780073511092. Retrieved 26 May 2019.
480. ^ Singleton, Peter L.; Edmeades, Doug C.; Smart, R. E. & Wheeler, David M. (2001). "The many ways of making anionic clays" (PDF). Journal of Chemical Sciences. 113 (5–6): 671–80. doi:10.1007/BF02708799. Retrieved 27 April 2019.
481. ^ Läuchli, André & Grattan, Steve R. (2012). "Soil pH extremes" (PDF). In Shabala, Sergey (ed.). Plant stress physiology (1st ed.). Wallingford, United Kingdom: CAB International. pp. 194–209. ISBN 978-1845939953. Retrieved 2 June 2019.
482. ^ Donahue, Miller & Shickluna 1977, pp. 116–17.
483. ^ Calmano, Wolfgang; Hong, Jihua & Förstner, Ulrich (1993). "Binding and mobilization of heavy metals in contaminated sediments affected by pH and redox potential" (PDF). Water Science and Technology. 28 (8–9): 223–35. doi:10.2166/wst.1993.0622. Retrieved 9 June 2019.
484. ^ Ren, Xiaoya; Zeng, Guangming; Tang, Lin; Wang, Jingjing; Wan, Jia; Liu, Yani; Yu, Jiangfang; Yi, Huan; Ye, Shujing & Deng, Rui (2018). "Sorption, transport and biodegradation: an insight into bioavailability of persistent organic pollutants in soil" (PDF). Science of the Total Environment. 610–611: 1154–63. Bibcode:2018ScTEn.610.1154R. doi:10.1016/j.scitotenv.2017.08.089. PMID 28847136. Retrieved 9 June 2019.
485. ^ Ponge, Jean-François (2003). "Humus forms in terrestrial ecosystems: a framework to biodiversity" (PDF). Soil Biology and Biochemistry. 35 (7): 935–45. CiteSeerX 10.1.1.467.4937. doi:10.1016/S0038-0717(03)00149-4. Retrieved 9 June 2019.
486. ^ Fujii, Kazumichi (2003). "Soil acidification and adaptations of plants and microorganisms in Bornean tropical forests". Ecological Research. 29 (3): 371–81. doi:10.1007/s11284-014-1144-3.
487. ^ Kauppi, Pekka; Kämäri, Juha; Posch, Maximilian & Kauppi, Lea (1986). "Acidification of forest soils: model development and application for analyzing impacts of acidic deposition in Europe" (PDF). Ecological Modelling. 33 (2–4): 231–53. doi:10.1016/0304-3800(86)90042-6. Retrieved 10 June 2019.
488. ^ Andriesse, J. P. (1969). "A study of the environment and characteristics of tropical podzols in Sarawak (East-Malaysia)" (PDF). Geoderma. 2 (3): 201–27. Bibcode:1969Geode...2..201A. doi:10.1016/0016-7061(69)90038-X. Retrieved 10 June 2019.
489. ^ Rengasamy, Pichu (2006). "World salinization with emphasis on Australia" (PDF). Journal of Experimental Botany. 57 (5): 1017–23. doi:10.1093/jxb/erj108. Retrieved 16 June 2019.
490. ^ Arnon, Daniel I. & Johnson, Clarence M. (1942). "Influence of hydrogen ion concentration on the growth of higher plants under controlled conditions". Plant Physiology. 17 (4): 525–39. doi:10.1104/pp.17.4.525. PMC 438054. PMID 16653803.
491. ^ Chaney, Rufus L.; Brown, John C. & Tiffin, Lee O. (1972). "Obligatory reduction of ferric chelates in iron uptake by soybeans". Plant Physiology. 50 (2): 208–13. doi:10.1104/pp.50.2.208. PMC 366111. PMID 16658143.
492. ^ Donahue, Miller & Shickluna 1977, pp. 116–19.
493. ^ Ahmad, Sagheer; Ghafoor, Abdul; Qadir, Manzoor & Aziz, M. Abbas (2006). "Amelioration of a calcareous saline-sodic soil by gypsum application and different crop rotations" (PDF). International Journal of Agriculture and Biology. 8 (2): 142–46. Retrieved 16 June 2019.
494. ^ McFee, William W.; Kelly, J. M. & Beck, R. H. (1976). "Acid precipitation effects on soil pH and base saturation of exchange sites" (PDF). USDA Forest Service, Northeastern Research Station, General Technical Reports. NE-23 (3): 725–35. Bibcode:1977WASP....7..401M. CiteSeerX 10.1.1.549.37. doi:10.1007/BF00284134. Retrieved 23 June 2019.
495. ^ Farina, Martin Patrick W.; Sumner, Malcolm E.; Plank, C. O. & Letzsch, W. Stephen (1980). "Exchangeable aluminum and pH as indicators of lime requirement for corn" (PDF). Soil Science Society of America Journal. 44 (5): 1036–41. Bibcode:1980SSASJ..44.1036F. doi:10.2136/sssaj1980.03615995004400050033x. Retrieved 30 June 2019.
496. ^ Donahue, Miller & Shickluna 1977, pp. 119–20.
497. ^ Sposito, Garrison; Skipper, Neal T.; Sutton, Rebecca; Park, Sun-Ho; Soper, Alan K. & Greathouse, Jeffery A. (1999). "Surface geochemistry of the clay minerals" (PDF). Proceedings of the National Academy of Sciences of the United States of America. 96 (7): 3358–64. Bibcode:1999PNAS...96.3358S. doi:10.1073/pnas.96.7.3358. PMC 34275. PMID 10097044. Retrieved 7 July 2019.
498. ^ Sparks, Donald L. "Soil buffering and acidic and basic soils" (PDF). University of California, Department of Land, Air, and Water Resources. Retrieved 7 July 2019.
499. ^ Ulrich, Bernhard (1983). "Soil acidity and its relations to acid deposition". In Ulrich, Bernhard; Pankrath, Jürgen (eds.). Effects of accumulation of air pollutants in forest ecosystems (1st ed.). Dordrecht, The Netherlands: D. Reidel Publishing Company. pp. 127–46. ISBN 978-94-009-6985-8.
500. ^ Donahue, Miller & Shickluna 1977, pp. 120–21.
501. ^ a b Dean 1957, p. 80.
502. ^ Russel 1957, pp. 123–25.
503. ^ a b Brady, Nyle C.; Weil, Ray R. (2008). The nature and properties of soils (14th ed.). Upper Saddle River: Pearson.
504. ^ Van der Ploeg, Rienk R.; Böhm, Wolfgang & Kirkham, Mary Beth (1999). "On the origin of the theory of mineral nutrition of plants and the Law of the Minimum". Soil Science Society of America Journal. 63 (5): 1055–62. Bibcode:1999SSASJ..63.1055V. CiteSeerX 10.1.1.475.7392. doi:10.2136/sssaj1999.6351055x.
505. ^ Knecht, Magnus F. & Göransson, Anders (2004). "Terrestrial plants require nutrients in similar proportions". Tree Physiology. 24 (4): 447–60. doi:10.1093/treephys/24.4.447. PMID 14757584.
506. ^ Dean 1957, pp. 80–81.
507. ^ a b c d Roy, R. N.; Finck, Arnold; Blair, Graeme J.; Tandon, Hari Lal Singh (2006). "Chapter 4: Soil fertility and crop production" (PDF). Plant nutrition for food security: a guide for integrated nutrient management. Rome, Italy: Food and Agriculture Organization of the United Nations. pp. 43–90. ISBN 978-92-5-105490-1. Retrieved 21 July 2019.
508. ^ Parfitt, Roger L.; Giltrap, Donna J. & Whitton, Joe S. (1995). "Contribution of organic matter and clay minerals to the cation exchange capacity of soil" (PDF). Communications in Soil Science and Plant Analysis. 26 (9–10): 1343–55. doi:10.1080/00103629509369376. Retrieved 28 July 2019.
509. ^ Hajnos, Mieczyslaw; Jozefaciuk, Grzegorz; Sokołowska, Zofia; Greiffenhagen, Andreas & Wessolek, Gerd (2003). "Water storage, surface, and structural properties of sandy forest humus horizons" (PDF). Journal of Plant Nutrition and Soil Science. 166 (5): 625–34. doi:10.1002/jpln.200321161. Retrieved 28 July 2019.
510. ^ Donahue, Miller & Shickluna 1977, pp. 123–31.
511. ^ Donahue, Miller & Shickluna 1977, p. 125.
512. ^ Föhse, Doris; Claassen, Norbert & Jungk, Albrecht (1991). "Phosphorus efficiency of plants. II. Significance of root radius, root hairs and cation-anion balance for phosphorus influx in seven plant species" (PDF). Plant and Soil. 132 (2): 261–72. doi:10.1007/BF00010407. Retrieved 4 August 2019.
513. ^ Barber, Stanley A.; Walker, J. M. & Vasey, Edfred H. (1963). "Mechanisms for movement of plant nutrients from soil and fertilizer to plant root". Journal of Agricultural and Food Chemistry. 11 (3): 204–07. doi:10.1021/jf60127a017.
514. ^ Lawrence, Gregory B.; David, Mark B. & Shortle, Walter C. (1995). "A new mechanism for calcium loss in forest floor soils" (PDF). Nature. 378 (6553): 162–65. Bibcode:1995Natur.378..162L. doi:10.1038/378162a0. Retrieved 11 August 2019.
515. ^ Kramers, Hendrik Anthony (1940). "Brownian motion in a field of force and the diffusion model of chemical reactions" (PDF). Physica. 7 (4): 284–304. Bibcode:1940Phy.....7..284K. doi:10.1016/S0031-8914(40)90098-2. Retrieved 11 August 2019.
516. ^ Lin, Sijie; Reppert, Jason; Hu, Qian; Hudson, Joan S.; Reid, Michelle L.; Ratnikova, Tatsiana A.; Rao, Apparao M.; Luo, Hong & Ke, Pu Chun (2009). "Uptake, translocation, and transmission of carbon nanomaterials in rice plants" (PDF). Small. 5 (10): 1128–32. doi:10.1002/smll.200801556. Retrieved 11 August 2019.
517. ^ a b Donahue, Miller & Shickluna 1977, p. 126.
518. ^ "Plant nutrition". Northern Arizona University. Archived from the original on 14 May 2013. Retrieved 18 April 2019.
519. ^ Matimati, Ignatious; Verboom, G. Anthony & Cramer, Michael D. (2014). "Nitrogen regulation of transpiration controls mass-flow acquisition of nutrients". Journal of Experimental Botany. 65 (1): 159–68. doi:10.1093/jxb/ert367. PMC 3883293. PMID 24231035.
520. ^ Mengel, Dave. "Roots, growth and nutrient uptake" (PDF). Purdue University, Agronomy Department. Retrieved 18 April 2019.
521. ^ Sattelmacher, Burkhard (2001). "The apoplast and its significance for plant mineral nutrition". New Phytologist. 149 (2): 167–92. doi:10.1046/j.1469-8137.2001.00034.x.
522. ^ Hinsinger, Philippe; Plassard, Claude; Tang, Caixian & Jaillard, Benoît (2003). "Origins of root-mediated pH changes in the rhizosphere and their responses to environmental constraints: a review" (PDF). Plant and Soil. 248 (1): 43–59. doi:10.1023/A:1022371130939. Retrieved 18 August 2019.
523. ^ Chapin, F. Stuart III; Vitousek, Peter M. & Van Cleve, Keith (1986). "The nature of nutrient limitation in plant communities". American Naturalist. 127 (1): 48–58. doi:10.1086/284466. JSTOR 2461646.
524. ^ Alam, Syed Manzoor (1999). "Nutrient uptake by plants under stress conditions" (PDF). In Pessarakli, Mohammad (ed.). Handbook of plant and crop stress (2nd ed.). New York, New York: Marcel Dekker. pp. 285–313. ISBN 978-0824719487. Retrieved 1 September 2019.
525. ^ Donahue, Miller & Shickluna 1977, pp. 123–28.
526. ^ Rasmussen, Jim & Kuzyakov, Yakov (2009). "Carbon isotopes as proof for plant uptake of organic nitrogen: relevance of inorganic carbon uptake" (PDF). Soil Biology and Biochemistry. 41 (7): 1586–87. doi:10.1016/j.soilbio.2009.03.006. Retrieved 8 September 2019.
527. ^ Fitter, Alastair H.; Graves, Jonathan D.; Watkins, N. K.; Robinson, David & Scrimgeour, Charlie (1998). "Carbon transfer between plants and its control in networks of arbuscular mycorrhizas". Functional Ecology. 12 (3): 406–12. doi:10.1046/j.1365-2435.1998.00206.x.
528. ^ Manzoni, Stefano; Trofymow, John A.; Jackson, Robert B. & Porporato, Amilcare (2010). "Stoichiometric controls on carbon, nitrogen, and phosphorus dynamics in decomposing litter" (PDF). Ecological Monographs. 80 (1): 89–106. doi:10.1890/09-0179.1. Retrieved 15 September 2019.
529. ^ Teskey, Robert O.; Saveyn, An; Steppe, Kathy & McGuire, Mary Ann (2007). "Origin, fate and significance of CO2 in tree stems". New Phytologist. 177 (1): 17–32. doi:10.1111/j.1469-8137.2007.02286.x. PMID 18028298.
530. ^ Billings, William Dwight & Godfrey, Paul Joseph (1967). "Photosynthetic utilization of internal carbon dioxide by hollow-stemmed plants". Science. 158 (3797): 121–23. Bibcode:1967Sci...158..121B. doi:10.1126/science.158.3797.121. JSTOR 1722393. PMID 6054809.
531. ^ Wadleigh 1957, p. 41.
532. ^ Broadbent 1957, p. 153.
533. ^ Vitousek, Peter M. (1984). "Litterfall, nutrient cycling, and nutrient limitation in tropical forests" (PDF). Ecology. 65 (1): 285–98. doi:10.2307/1939481. JSTOR 1939481. Retrieved 29 September 2019.
534. ^ Donahue, Miller & Shickluna 1977, p. 128.
535. ^ Forde, Bryan G. & Clarkson, David T. (1999). "Nitrate and ammonium nutrition of plants: physiological and molecular perspectives" (PDF). Advances in Botanical Research. 30 (C): 1–90. doi:10.1016/S0065-2296(08)60226-8. Retrieved 29 September 2019.
536. ^ Hodge, Angela; Campbell, Colin D. & Fitter, Alastair H. (2001). "An arbuscular mycorrhizal fungus accelerates decomposition and acquires nitrogen directly from organic material" (PDF). Nature. 413 (6853): 297–99. Bibcode:2001Natur.413..297H. doi:10.1038/35095041. PMID 11565029. Retrieved 29 September 2019.
537. ^ Burke, Ingrid C.; Yonker, Caroline M.; Parton, William J.; Cole, C. Vernon; Flach, Klaus & Schimel, David S. (1989). "Texture, climate, and cultivation effects on soil organic matter content in U.S. grassland soils" (PDF). Soil Science Society of America Journal. 53 (3): 800–05. Bibcode:1989SSASJ..53..800B. doi:10.2136/sssaj1989.03615995005300030029x. Retrieved 6 October 2019.
538. ^ Enríquez, Susana; Duarte, Carlos M. & Sand-Jensen, Kaj (1993). "Patterns in decomposition rates among photosynthetic organisms: the importance of detritus C:N:P content" (PDF). Oecologia. 94 (4): 457–71. Bibcode:1993Oecol..94..457E. doi:10.1007/BF00566960. PMID 28313985. Retrieved 6 October 2019.
539. ^ Tiessen, Holm; Stewart, John W. B. & Bettany, Jeff R. (1982). "Cultivation effects on the amounts and concentration of carbon, nitrogen, and phosphorus in grassland soils" (PDF). Agronomy Journal. 74 (5): 831–35. doi:10.2134/agronj1982.00021962007400050015x. Retrieved 13 October 2019.
540. ^ Philippot, Laurent; Hallin, Sara & Schloter, Michael (2007). "Ecology of denitrifying prokaryotes in agricultural soil". In Sparks, Donald L. (ed.). Advances in agronomy, Volume 96. Amsterdam, The Netherlands: Elsevier. pp. 249–305. CiteSeerX 10.1.1.663.4557. ISBN 978-0-12-374206-3.
541. ^ Doran, John W. (1987). "Microbial biomass and mineralizable nitrogen distributions in no-tillage and plowed soils" (PDF). Biology and Fertility of Soils. 5 (1): 68–75. doi:10.1007/BF00264349. Retrieved 13 October 2019.
542. ^ Mahvi, Amir H.; Nouri, Jafar; Babaei, Ali A. & Nabizadeh, Ramin (2005). "Agricultural activities impact on groundwater nitrate pollution" (PDF). International Journal of Environmental Science and Technology. 2 (1): 41–47. doi:10.1007/BF03325856. Retrieved 20 October 2019.
543. ^ Scherer, Heinrich W.; Feils, E. & Beuters, Patrick (2014). "Ammonium fixation and release by clay minerals as influenced by potassium" (PDF). Plant, Soil and Environment. 60 (7): 325–31. doi:10.17221/202/2014-PSE. Retrieved 20 October 2019.
544. ^ Barak, Phillip; Jobe, Babou O.; Krueger, Armand R.; Peterson, Lloyd A. & Laird, David A. (1997). "Effects of long-term soil acidification due to nitrogen fertilizer inputs in Wisconsin" (PDF). Plant and Soil. 197 (1): 61–69. doi:10.1023/A:1004297607070. Retrieved 27 October 2019.
545. ^ Van Egmond, Klaas; Bresser, Ton & Bouwman, Lex (2002). "The European nitrogen case" (PDF). Ambio. 31 (2): 72–78. doi:10.1579/0044-7447-31.2.72. Retrieved 27 October 2019.
546. ^ Allison 1957, pp. 85–94.
547. ^ Broadbent 1957, pp. 152–55.
548. ^ Donahue, Miller & Shickluna 1977, pp. 128–31.
549. ^ Recous, Sylvie & Mary, Bruno (1990). "Microbial immobilization of ammonium and nitrate in cultivated soils" (PDF). Soil Biology and Biochemistry. 22 (7): 913–22. doi:10.1016/0038-0717(90)90129-N. Retrieved 3 November 2019.
550. ^ Verhoef, Herman A. & Brussaard, Lijbert (1990). "Decomposition and nitrogen mineralization in natural and agro-ecosystems: the contribution of soil animals" (PDF). Biogeochemistry. 11 (3): 175–211. doi:10.1007/BF00004496. Retrieved 3 November 2019.
551. ^ Chen, Baoqing; Liu, EnKe; Tian, Qizhuo; Yan, Changrong & Zhang, Yanqing (2014). "Soil nitrogen dynamics and crop residues: a review" (PDF). Agronomy for Sustainable Development. 34 (2): 429–42. doi:10.1007/s13593-014-0207-8. Retrieved 3 November 2019.
552. ^ Griffin, Timothy S.; Honeycutt, Charles W. & He, Zhijun (2002). "Effects of temperature, soil water status, and soil type on swine slurry nitrogen transformations" (PDF). Biology and Fertility of Soils. 36 (6): 442–46. doi:10.1007/s00374-002-0557-2. Retrieved 24 November 2019.
553. ^ Donahue, Miller & Shickluna 1977, pp. 129–30.
554. ^ Donahue, Miller & Shickluna 1977, p. 145.
555. ^ Lodwig, Emma; Hosie, Arthur H. F.; Bourdès, Alexandre; Findlay, Kim; Allaway, David; Karunakaran, Ramakrishnan; Downie, J. Allan & Poole, Philip S. (2003). "Amino-acid cycling drives nitrogen fixation in the legume–Rhizobium symbiosis" (PDF). Nature. 422 (6933): 722–26. doi:10.1038/nature01527. PMID 12700763. Retrieved 10 November 2019.
556. ^ Donahue, Miller & Shickluna 1977, pp. 128–29.
557. ^ Hill, R. D.; Rinker, Robert G. & Wilson, H. Dale (1980). "Atmospheric nitrogen fixation by lightning". Journal of the Atmospheric Sciences. 37 (1): 179–92. doi:10.1175/1520-0469(1980)037<0179:ANFBL>2.0.CO;2.
558. ^ Allison 1957, p. 87.
559. ^ Ferris, Howard; Venette, Robert C.; Van der Meulen, Hans R. & Lau, Serrine S. (1998). "Nitrogen mineralization by bacterial-feeding nematodes: verification and measurement" (PDF). Plant and Soil. 203 (2): 159–71. doi:10.1023/A:1004318318307. Retrieved 17 November 2019.
560. ^ Violante, Antonio; de Cristofaro, Annunziata; Rao, Maria A. & Gianfreda, Liliana (1995). "Physicochemical properties of protein-smectite and protein-Al(OH)x-smectite complexes" (PDF). Clay Minerals. 30 (4): 325–36. doi:10.1180/claymin.1995.030.4.06. Retrieved 24 November 2019.
561. ^ Vogel, Cordula; Mueller, Carsten W.; Höschen, Carmen; Buegger, Franz; Heister, Katja; Schulz, Stefanie; Schloter, Michael & Kögel-Knabner, Ingrid (2014). "Submicron structures provide preferential spots for carbon and nitrogen sequestration in soils" (PDF). Nature Communications. 5 (2947): 1–7. doi:10.1038/ncomms3947. PMC 3896754. PMID 24399306. Retrieved 24 November 2019.
562. ^ Ruamps, Léo Simon; Nunan, Naoise & Chenu, Claire (2011). "Microbial biogeography at the soil pore scale" (PDF). Soil Biology and Biochemistry. 43 (2): 280–86. doi:10.1016/j.soilbio.2010.10.010. Retrieved 1 December 2019.
563. ^ Quiquampoix, Hervé & Burns, Richard G. (2007). "Interactions between proteins and soil mineral surfaces: environmental and health consequences" (PDF). Elements. 3 (6): 401–06. doi:10.2113/GSELEMENTS.3.6.401. Retrieved 24 November 2019.
564. ^ Nieder, Rolf; Benbi, Dinesh K. & Scherer, Heinrich W. (2011). "Fixation and defixation of ammonium in soils: a review" (PDF). Biology and Fertility of Soils. 47 (1): 1–14. doi:10.1007/s00374-010-0506-4. Retrieved 8 December 2019.
565. ^ a b Kramer, Sasha B.; Reganold, John P.; Glover, Jerry D.; Bohannan, Brendan J.M. & Mooney, Harold A. (2006). "Reduced nitrate leaching and enhanced denitrifier activity and efficiency in organically fertilized soils" (PDF). Proceedings of the National Academy of Sciences of the United States of America. 103 (12): 4522–27. doi:10.1073/pnas.0600359103. PMC 1450204. PMID 16537377. Retrieved 8 December 2019.
566. ^ Robertson, G. Philip (1989). "Nitrification and denitrification in humid tropical ecosystems: potential controls on nitrogen retention". In Proctor, John (ed.). Mineral nutrients in tropical forest and savanna ecosystems (PDF). Cambridge, Massachusetts: Blackwell Scientific. pp. 55–69. ISBN 978-0632025596. Retrieved 15 December 2019.
567. ^ Parkin, Timothy B. & Robinson, Joseph A. (1989). "Stochastic models of soil denitrification" (PDF). Applied and Environmental Microbiology. 55 (1): 72–77. PMC 184056. PMID 16347838. Retrieved 15 December 2019.
568. ^ Donahue, Miller & Shickluna 1977, p. 130.
569. ^ Rao, Desiraju L.N. & Batra, Lalit (1983). "Ammonia volatilization from applied nitrogen in alkali soils" (PDF). Plant and Soil. 70 (2): 219–28. doi:10.1007/BF02374782. Retrieved 15 December 2019.
570. ^ a b Donahue, Miller & Shickluna 1977, p. 131.
571. ^ Lallouette, Vincent; Magnier, Julie; Petit, Katell & Michon, Janik (2014). "Agricultural practices and nitrates in aquatic environments" (PDF). The Brief. 11 (December): 1–16. Retrieved 15 December 2019.
572. ^ Choudhury, Abu T.M.A. & Kennedy, Ivan R. (2005). "Nitrogen fertilizer losses from rice soils and control of environmental pollution problems" (PDF). Communications in Soil Science and Plant Analysis. 36 (11–12): 1625–39. doi:10.1081/css-200059104. Retrieved 15 December 2019.
573. ^ Roth, Tobias; Kohli, Lukas; Rihm, Beat & Achermann, Beat (2013). "Nitrogen deposition is negatively related to species richness and species composition of vascular plants and bryophytes in Swiss mountain grassland" (PDF). Agriculture, Ecosystems and Environment. 178: 121–26. doi:10.1016/j.agee.2013.07.002. Retrieved 15 December 2019.
574. ^ Vitousek, Peter M. (1984). "Litterfall, nutrient cycling, and nutrient limitation in tropical forests" (PDF). Ecology. 65 (1): 285–98. doi:10.2307/1939481. Retrieved 22 December 2019.
575. ^ Kucey, Reg M.N. (1983). "Phosphate-solubilizing bacteria and fungi in various cultivated and virgin Alberta soils" (PDF). Canadian Journal of Soil Science. 63 (4): 671–78. doi:10.4141/cjss83-068. Retrieved 22 December 2019.
576. ^ Khorassani, Reza; Hettwer, Ursula; Ratzinger, Astrid; Steingrobe, Bernd; Karlovsky, Petr & Claassen, Norbert (2011). "Citramalic acid and salicylic acid in sugar beet root exudates solubilize soil phosphorus" (PDF). BMC Plant Biology. 11 (121): 1–8. doi:10.1186/1471-2229-11-121. Retrieved 22 December 2019.
577. ^ Duponnois, Robin; Colombet, Aline; Hien, Victor & Thioulouse, Jean (2005). "The mycorrhizal fungus Glomus intraradices and rock phosphate amendment influence plant growth and microbial activity in the rhizosphere of Acacia holosericea" (PDF). Soil Biology and Biochemistry. 37 (8): 1460–68. doi:10.1016/j.soilbio.2004.09.016. Retrieved 22 December 2019.
578. ^ Syers, John Keith; Johnston, A. Edward & Curtin, Denis (2008). Efficiency of soil and fertilizer phosphorus use: reconciling changing concepts of soil phosphorus behaviour with agronomic information (PDF). Rome, Italy: Food and Agriculture Organization of the United Nations. ISBN 978-92-5-105929-6. Retrieved 29 December 2019.
579. ^ Lambert, Raphaël; Grant, Cynthia & Sauvé, Sébastien (2007). "Cadmium and zinc in soil solution extracts following the application of phosphate fertilizers" (PDF). Science of the Total Environment. 378 (3): 293–305. doi:10.1016/j.scitotenv.2007.02.008. Retrieved 5 January 2020.
580. ^ Terry, Norman & Ulrich, Albert (1973). "Effects of phosphorus deficiency on the photosynthesis and respiration of leaves of sugar beet" (PDF). Plant Physiology. 51 (1): 43–47. doi:10.1104/pp.51.1.43. Retrieved 5 January 2020.
581. ^ Pallas, James E. Jr; Michel, B.E. & Harris, D.G. (1967). "Photosynthesis, transpiration, leaf temperature, and stomatal activity of cotton plants under varying water potentials" (PDF). Plant Physiology. 42 (1): 76–88. doi:10.1104/pp.42.1.76. Retrieved 12 January 2020.
582. ^ Meena, Vijay Singh; Maurya, Bihari Ram; Verma, Jai Prakash; Aeron, Abhinav; Kumar, Ashok; Kim, Kangmin & Bajpai, Vivek K. (2015). "Potassium solubilizing rhizobacteria (KSR): isolation, identification, and K-release dynamics from waste mica" (PDF). Ecological Engineering. 81: 340–47. doi:10.1016/j.ecoleng.2015.04.065. Retrieved 12 January 2020.
583. ^ Donahue, Miller & Shickluna 1977, pp. 134–35.
584. ^ Reitemeier 1957, pp. 101–04.
585. ^ Donahue, Miller & Shickluna 1977, pp. 135–36.
586. ^ a b Donahue, Miller & Shickluna 1977, p. 136.
587. ^ Jordan & Reisenauer 1957, p. 107.
588. ^ Holmes & Brown 1957, pp. 111.
589. ^ Sherman 1957, p. 135.
590. ^ Seatz & Jurinak 1957, p. 115.
591. ^ Reuther 1957, p. 128.
592. ^ Russel 1957, p. 121.
593. ^ Stout & Johnson 1957, p. 146.
594. ^ Stout & Johnson 1957, p. 141.
595. ^ Donahue, Miller & Shickluna 1977, pp. 136–37.
596. ^ Stout & Johnson 1957, p. 107.
597. ^ Faria Pereira, B.F. "Nutrients and Nonessential Elements in Soil after 11 Years of Wastewater Irrigation". ACSESS Digital Library. Retrieved 17 January 2018.
598. ^ Pimentel, D.; et al. (1995). "Environmental and economic costs of soil erosion and conservation benefits". Science. 267 (24): 1117–22. Bibcode:1995Sci...267.1117P. doi:10.1126/science.267.5201.1117. PMID 17789193.
599. ^ a b Foth, Henry D. (1984). Fundamentals of soil science. New York: Wiley. p. 151. ISBN 978-0-471-88926-7.
600. ^ Gilluly, Waters, Woodford (1975). Principles of Geology (4th ed.). W.H. Freeman. p. 216. ISBN 978-0-7167-0269-6.CS1 maint: multiple names: authors list (link)
601. ^ Verkaik, Eric; Jongkind, Anne G.; Berendse, Frank (2006). "Short-term and long-term effects of tannins on nitrogen mineralization and litter decomposition in kauri (Agathis australis (D. Don) Lindl.) forests". Plant and Soil. 287 (1–2): 337–45. doi:10.1007/s11104-006-9081-8.
602. ^ Fierer, N.; Schimel, Joshua P.; Cates, Rex G.; Zou, Jiping (2001). "Influence of balsam poplar tannin fractions on carbon and nitrogen dynamics in Alaskan taiga floodplain soils". Soil Biology and Biochemistry. 33 (12–13): 1827–39. doi:10.1016/S0038-0717(01)00111-0.
603. ^ Wagai, Rota; Mayer, Lawrence M.; Kitayama, Kanehiro; Knicker, Heike (2008). "Climate and parent material controls on organic matter storage in surface soils: A three-pool, density-separation approach" (PDF). Geoderma. 147 (1–2): 23–33. Bibcode:2008Geode.147...23W. doi:10.1016/j.geoderma.2008.07.010. hdl:10261/82461.
604. ^ Minayeva, T. Yu.; Trofimov, S. Ya.; Chichagova, O.A.; Dorofeyeva, E.I.; Sirin, A.A.; Glushkov, I.V.; Mikhailov, N.D.; Kromer, B. (2008). "Carbon accumulation in soils of forest and bog ecosystems of southern Valdai in the Holocene". Biology Bulletin. 35 (5): 524–32. doi:10.1134/S1062359008050142.
605. ^ Sanchez, Pedro A. (1976). Properties and management of soils in the tropics. New York: Wiley. ISBN 978-0-471-75200-4.
606. ^ a b Paul, E.A. (1997). Soil organic matter in temperate agroecosystems : long-term experiments in North America. Boca Raton: CRC Press. p. 80. ISBN 978-0-8493-2802-2.
607. ^ Retallack, G.J. (1990). Soils of the past : an introduction to paleopedology. Boston: Unwin Hyman. p. 32. ISBN 978-0-04-445757-2.
608. ^ Buol, S.W. (1990). Soil genesis and classification. Ames, Iowa: Iowa State University Press. p. 36. doi:10.1081/E-ESS. ISBN 978-0-8138-2873-2.
609. ^ IUSS Working Group WRB (2014). World Reference Base for Soil Resources 2014. International soil classification system for naming soils and creating legends for soil maps (PDF) (3rd ed.). Rome: FAO. ISBN 978-92-5-108370-3. Retrieved 29 August 2014.[permanent dead link]
610. ^ "Archived copy" (PDF). Archived from the original (PDF) on 30 June 2014. Retrieved 8 October 2013.CS1 maint: archived copy as title (link) Soils of the European Union by the EU Institute for Environment and Sustainability. Accessed on 8 October 2013
611. ^ The Soil Orders Archived 12 January 2010 at the Wayback Machine, Department of Environmental Sciences, University of Virginia, retrieved 23 October 2012.
612. ^ Donahue, Miller & Shickluna 1977, pp. 411–32.
613. ^ Leake, Simon; Haege, Elke (2014). Soils for Landscape Development. CSIRO Publishing. ISBN 978-0-643-10964-3.
614. ^ Kopittke, Peter M.; Menzies, Neal W.; Wang, Peng; McKenna, Brigid A.; Lombi, Enzo (1 November 2019). "Soil and the intensification of agriculture for global food security". Environment International. 132: 105078. doi:10.1016/j.envint.2019.105078. ISSN 0160-4120. PMID 31400601.
615. ^ Ponge, Jean-François (2003). "Humus forms in terrestrial ecosystems: a framework to biodiversity" (PDF). Soil Biology and Biochemistry. 35 (7): 935–45. CiteSeerX 10.1.1.467.4937. doi:10.1016/S0038-0717(03)00149-4. Archived from the original on 29 January 2016.
616. ^ De Deyn, Gerlinde B.; Van der Putten, Wim H. (2005). "Linking aboveground and belowground diversity". Trends in Ecology & Evolution. 20 (11): 625–33. doi:10.1016/j.tree.2005.08.009. PMID 16701446.
617. ^ Hansen, J.; et al. (2008). "Target atmospheric CO2: Where should humanity aim?". Open Atmospheric Science Journal. 2 (1): 217–31. arXiv:0804.1126. Bibcode:2008OASJ....2..217H. doi:10.2174/1874282300802010217.
618. ^ Lal, R. (11 June 2004). "Soil Carbon Sequestration Impacts on Global Climate Change and Food Security". Science. 304 (5677): 1623–27. Bibcode:2004Sci...304.1623L. doi:10.1126/science.1097396. PMID 15192216.
619. ^ Blakeslee, Thomas R. (24 February 2010). "Greening Deserts for Carbon Credits". Renewable Energy World.com. Archived from the original on 1 November 2012. Retrieved 23 October 2012.
620. ^ Setz, EZF; Enzweiler J; Solferini VN; Amendola MP; Berton RS (1999). "Geophagy in the golden-faced saki monkey (Pithecia pithecia chrysocephala) in the Central Amazon" (PDF). Journal of Zoology. 247 (1): 91–103. doi:10.1111/j.1469-7998.1999.tb00196.x.
621. ^ Kohne, John Maximilian; Koehne, Sigrid; Simunek, Jirka (2009). "A review of model applications for structured soils: a) Water flow and tracer transport" (PDF). Journal of Contaminant Hydrology. 104 (1–4): 4–35. Bibcode:2009JCHyd.104....4K. CiteSeerX 10.1.1.468.9149. doi:10.1016/j.jconhyd.2008.10.002. PMID 19012994. Archived from the original (PDF) on 7 November 2017. Retrieved 1 November 2017.
622. ^ Diplock, EE; Mardlin DP; Killham KS; Paton GI (2009). "Predicting bioremediation of hydrocarbons: laboratory to field scale". Environmental Pollution. 157 (6): 1831–40. doi:10.1016/j.envpol.2009.01.022. PMID 19232804.
623. ^ Moeckel, Claudia; Nizzetto, Luca; Di Guardo, Antonio; Steinnes, Eiliv; Freppaz, Michele; Filippa, Gianluca; Camporini, Paolo; Benner, Jessica; Jones, Kevin C. (2008). "Persistent organic pollutants in boreal and montane soil profiles: distribution, evidence of processes and implications for global cycling". Environmental Science and Technology. 42 (22): 8374–80. Bibcode:2008EnST...42.8374M. doi:10.1021/es801703k. PMID 19068820.
624. ^ Rezaei, Khalil; Guest, Bernard; Friedrich, Anke; Fayazi, Farajollah; Nakhaei, Mohamad; Aghda, Seyed Mahmoud Fatemi; Beitollahi, Ali (2009). "Soil and sediment quality and composition as factors in the distribution of damage at the December 26, 2003, Bam area earthquake in SE Iran (M (s)=6.6)". Journal of Soils and Sediments. 9: 23–32. doi:10.1007/s11368-008-0046-9.
625. ^ Johnson, D.L.; Ambrose, S.H.; Bassett, T.J.; Bowen, M.L.; Crummey, D.E.; Isaacson, J.S.; Johnson, D.N.; Lamb, P.; Saul, M.; Winter-Nelson, A. E. (1997). "Meanings of environmental terms". Journal of Environmental Quality. 26 (3): 581–89. doi:10.2134/jeq1997.00472425002600030002x.
626. ^ Ballabio, Cristiano; Panagos, Panos; Lugato, Emanuele; Huang, Jen-How; Orgiazzi, Alberto; Jones, Arwyn; Fernández-Ugalde, Oihane; Borrelli, Pasquale; Montanarella, Luca (15 September 2018). "Copper distribution in European topsoils: An assessment based on LUCAS soil survey". Science of the Total Environment. 636: 282–298. Bibcode:2018ScTEn.636..282B. doi:10.1016/j.scitotenv.2018.04.268. ISSN 0048-9697. PMID 29709848.
627. ^ Jones, j. a. a. (1976). "Soil piping and stream channel initiation". Water Resources Research. 7 (3): 602–10. Bibcode:1971WRR.....7..602J. doi:10.1029/WR007i003p00602.
628. ^ Dooley, Alan (June 2006). "Sandboils 101: Corps has experience dealing with common flood danger". Engineer Update. US Army Corps of Engineers. Archived from the original on 18 April 2008. Retrieved 14 May 2008.
629. ^ ILRI (1989). "Effectiveness and Social/Environmental Impacts of Irrigation Projects: a Review" (PDF). In: Annual Report 1988 of the International Institute for Land Reclamation and Improvement (ILRI). Wageningen, The Netherlands. pp. 18–34. Archived (PDF) from the original on 19 February 2009.
630. ^ Drainage Manual: A Guide to Integrating Plant, Soil, and Water Relationships for Drainage of Irrigated Lands. Interior Dept., Bureau of Reclamation. 1993. ISBN 978-0-16-061623-5.
631. ^ "Free articles and software on drainage of waterlogged land and soil salinity control". Archived from the original on 16 August 2010. Retrieved 28 July 2010.
632. ^ International Water Management Institute (2010). "Improving soils and boosting yields in Thailand" (PDF). Success Stories (2). doi:10.5337/2011.0031. Archived (PDF) from the original on 7 June 2012.
633. ^ "Provide for your garden's basic needs ... and the plants will take it from there". USA Weekend. 10 March 2011. Archived from the original on 9 February 2013.

Sources

- Donahue, Roy Luther; Miller, Raymond W.; Shickluna, John C. (1977). Soils: An Introduction to Soils and Plant Growth. Prentice-Hall. ISBN 978-0-13-821918-5.
- "Arizona Master Gardener". Cooperative Extension, College of Agriculture, University of Arizona. Retrieved 27 May 2013.
- Stefferud, Alfred, ed. (1957). Soil: The Yearbook of Agriculture 1957. United States Department of Agriculture. OCLC 704186906.
  - Kellogg. "We Seek; We Learn". In Stefferud (1957).
  - Simonson. "What Soils Are". In Stefferud (1957).
  - Russell. "Physical Properties". In Stefferud (1957).
  - Richards & Richards. "Soil Moisture". In Stefferud (1957).
  - Wadleigh. "Growth of Plants". In Stefferud (1957).
  - Allaway. "pH, Soil Acidity, and Plant Growth". In Stefferud (1957).
  - Coleman & Mehlich. "The Chemistry of Soil pH". In Stefferud (1957).
  - Dean. "Plant Nutrition and Soil Fertility". In Stefferud (1957).
  - Allison. "Nitrogen and Soil Fertility". In Stefferud (1957).
  - Olsen & Fried. "Soil Phosphorus and Fertility". In Stefferud (1957).
  - Reitemeier. "Soil Potassium and Fertility". In Stefferud (1957).
  - Jordan & Reisenauer. "Sulfur and Soil Fertility". In Stefferud (1957).
  - Holmes & Brown. "Iron and Soil Fertility". In Stefferud (1957).
  - Seatz & Jurinak. "Zinc and Soil Fertility". In Stefferud (1957).
  - Russel. "Boron and Soil Fertility". In Stefferud (1957).
  - Reuther. "Copper and Soil Fertility". In Stefferud (1957).
  - Sherman. "Manganese and Soil Fertility". In Stefferud (1957).
  - Stout & Johnson. "Trace Elements". In Stefferud (1957).
  - Broadbent. "Organic Matter". In Stefferud (1957).
  - Clark. "Living Organisms in the Soil". In Stefferud (1957).
  - Flemming. "Soil Management and Insect Control". In Stefferud (1957).

## Further reading[edit]

- Soil-Net.com A free schools-age educational site teaching about soil and its importance.
- Adams, J.A. 1986. Dirt. College Station, Texas: Texas A&M University Press ISBN 0-89096-301-0
- Certini, G., Scalenghe, R. 2006. Soils: Basic concepts and future challenges. Cambridge Univ Press, Cambridge.
- David R. Montgomery, Dirt: The Erosion of Civilizations, ISBN 978-0-520-25806-8
- Faulkner, Edward H. 1943. Plowman's Folly. New York, Grosset & Dunlap. ISBN 0-933280-51-3
- LandIS Free Soilscapes Viewer Free interactive viewer for the Soils of England and Wales
- Jenny, Hans. 1941. Factors of Soil Formation: A System of Quantitative Pedology
- Logan, W.B. 1995. Dirt: The ecstatic skin of the earth. ISBN 1-57322-004-3
- Mann, Charles C. September 2008. " Our good earth" National Geographic Magazine
- "97 Flood". USGS. Archived from the original on 24 June 2008. Retrieved 8 July 2008. Photographs of sand boils.
- Soil Survey Division Staff. 1999. Soil survey manual. Soil Conservation Service. U.S. Department of Agriculture Handbook 18.
- Soil Survey Staff. 1975. Soil Taxonomy: A basic system of soil classification for making and interpreting soil surveys. USDA-SCS Agric. Handb. 436. United States Government Printing Office, Washington, DC.
- Soils (Matching suitable forage species to soil type), Oregon State University
- Gardiner, Duane T. "Lecture 1 Chapter 1 Why Study Soils?". ENV320: Soil Science Lecture Notes. Texas A&M University-Kingsville. Archived from the original on 9 February 2018. Retrieved 7 January 2019.
- Janick, Jules. 2002. Soil notes, Purdue University
- LandIS Soils Data for England and Wales a pay source for GIS data on the soils of England and Wales and soils data source; they charge a handling fee to researchers.

## External links[edit]

| Wikiversity has learning resources about Soil Formation

| The Wikibook Historical Geology has a page on the topic of: Soils and paleosols

- Short video explaining soil basics
- The Soil Water Compendium (soil water content sensors explained)
- Global Soil Partnership
- FAO Soils Portal
- World Reference Base for Soil Resources
- ISRIC – World Soil Information (ICSU World Data Centre for Soils)
- World Soil Library and Maps
- Wossac the world soil survey archive and catalogue
- Canadian Society of Soil Science
- Soil Science Society of America
- USDA-NRCS Web Soil Survey
- European Soil Portal (wiki)
- National Soil Resources Institute UK
- Plant and Soil Sciences eLibrary
- Copies of the reference 'Soil: The Yearbook of Agriculture 1957' in multiple formats

Retrieved from "https://en.wikipedia.org/w/index.php?title=Soil&oldid=935554462"
Categories:

- Soil
- Land management
- Horticulture and gardening
- Granularity of materials
- Natural materials
- Natural resources

Hidden categories:

- CS1 French-language sources (fr)
- CS1 German-language sources (de)
- CS1: long volume value
- Pages with DOIs inactive as of 2019 December
- CS1 errors: missing periodical
- CS1 maint: multiple names: authors list
- All articles with dead external links
- Articles with dead external links from December 2017
- Articles with permanently dead external links
- CS1 maint: archived copy as title
- Webarchive template wayback links
- Wikipedia indefinitely move-protected pages
- Articles with short description
- All articles with unsourced statements
- Articles with unsourced statements from June 2017
- Articles with unsourced statements from January 2018
- Articles with unsourced statements from November 2019
- Commons category link is on Wikidata
- Use dmy dates from June 2019
- Wikipedia articles with GND identifiers
- Wikipedia articles with LCCN identifiers
- Wikipedia articles with NDL identifiers